<?php

/**
 * Services
 *
 * Services controller class
 *
 * web-GFC : Gestion de Flux Citoyens (https://adullact.net/projects/webgfc)
 *
 * PHP version 7
 * @author Stéphane Sampaio
 * @copyright Initié par ADULLACT - Développé par ADULLACT Projet
 * @link http://adullact.org/
 * @license http://www.cecill.info/licences/Licence_CeCILL_V2-fr.txt CeCiLL v2
 *
 * @package		app
 * @subpackage		Controller
 */
class ServicesController extends AppController {

    /**
     * Controller name
     *
     * @access public
     * @var string
     */
    public $name = 'Services';

    /**
     * Controller uses
     *
     * @access public
     * @var array
     */
    public $uses = array('Service', 'Daro');

    /**
     * Controller helpers
     *
     * @access public
     * @var array
     */
    public $helpers = array('DataAcl.DataAcl');

    /**
     * Gestion des services (interface graphique)
     *
     * @logical-group Services
     * @user-profile Admin
     *
     * @access public
     * @return void
     */
    public function index() {
        $this->set('ariane', array(
            '<a href="environnement/index/0/admin">' . __d('menu', 'Administration', true) . '</a>',
            __d('menu', 'gestionServices', true)
        ));
    }

    /**
     * Récupération de la liste des services (ajax)
     *
     * @logical-group Services
     * @user-profile Admin
     *
     * @access public
     * @return void
     */
    public function getServices() {
        $services_tmp = $this->Service->find("threaded", array('contain' => array($this->Service->Desktop->alias), 'order' => 'Service.name'));
        $services = array();
        foreach ($services_tmp as $item) {
            $item['right_edit'] = true;
            $item['right_delete'] = true;
            $services[] = $item;
        }
        $this->set('services', $services);
        $this->set('nbItem', $this->Service->find('count'));
    }

    //TODO: supprimer les fonctions commentées
//	public function view($id) {
//		$service = $this->Service->find(
//				'first', array(
//			'contain' => array(
//				'Collectivite',
//				'User',
//			),
//			'conditions' => array('Service.id' => $id)
//				)
//		);
//		if (empty($service)) {
//			throw new NotFoundException();
//		}
//		$this->set(compact('service'));
//	}

    /**
     * Ajout d'un service
     *
     * @logical-group Services
     * @user-profile Admin
     *
     * @access public
     * @return void
     */
    public function add() {
        if (!empty($this->request->data)) {
            $this->Jsonmsg->init();
            $this->Service->create($this->request->data);
            $this->Service->begin();
            if ($this->Service->save()) {
                $this->Service->commit();
                $this->Jsonmsg->valid();
            } else {
                $this->Service->rollback();
            }
            $this->Jsonmsg->send();
        }
        $services = $this->Service->find('list', array('order' => 'Service.name ASC'));
//        $services = $this->Service->reorder(array('id' => null, 'field' => 'name', 'order' => 'ASC', 'verify' => true));
//        $services = $this->Service->generateTreeList(null, null, null, '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;');
        $this->set('services', $services);
    }

    /**
     * Edition d'un service (interface graphique)
     *
     * @logical-group Services
     * @user-profile Admin
     *
     * @access public
     * @param integer $id identifiant du service
     * @return void
     */
    public function edit($id = null) {
        if ($id != null) {
            $this->set('id', $id);
        }
    }

    /**
     * Edition des informations d'un service
     *
     * @logical-group Services
     * @user-profile Admin
     *
     * @access public
     * @param integer $id identifiant du service
     * @return void
     */
    public function setInfos($id = null) {
        if (!empty($this->request->data['Service'])) {
            $this->Jsonmsg->init();
            $this->Service->create();
            $saved = $this->Service->save($this->request->data);

            if (!empty($saved)) {
                $this->Jsonmsg->valid();
            }
            $this->Jsonmsg->send();
        } else {
            $this->request->data = $this->Service->find('first', array(
                'recursive' => -1,
                'contain' => array('Init'),
                'conditions' => array('Service.id' => $id)
            ));
            $services = $this->Service->find('list', array('conditions' => array('Service.id !=' => $id, 'OR' => array('Service.parent_id !=' => $id, 'Service.parent_id' => '')), 'order' => 'Service.name ASC'));
            $this->set('services', $services);
            $inits = $this->Service->Init->getDesktopsByUser('init');
            $this->set('inits', $inits);
        }
    }

    /**
     * Edition de la liste des habilitations de sous-types
     *
     * @logical-group Services
     * @logical-group Gestion des habilitations
     * @user-profile Admin
     *
     * @access public
     * @param integer $id identifiant du service
     * @return void
     */
    public function setDroitsData($id = null) {
        if (!empty($this->request->data)) {
            $this->Jsonmsg->init();
            if ($this->request->data['Acl']['Type'] == 'DataAcl') {
                if ($this->DataAcl->setRights($this->request->data['Requester'], $this->request->data['Rights'])) {
                    $this->Jsonmsg->valid();
                }
            }
            $this->Jsonmsg->send();
        } else {
            $this->Service->id = $id;
            $daro = $this->Service->node();
            $dataRights = $this->DataAcl->getRightsGrid($daro[0], array(), array('actions' => array('read'), 'models' => array('Type', 'Soustype')));
            $this->set('dataRights', $dataRights);
            $this->set('id', $id);
        }
    }

    /**
     * Edition de la liste des habilitations de méta-données
     *
     * @logical-group Services
     * @logical-group Gestion des habilitations
     * @user-profile Admin
     *
     * @access public
     * @param integer $id identifiant du service
     * @return void
     */
    public function setDroitsMeta($id = null) {
        //mise a jour des droits sur les meta donnees
        if (!empty($this->request->data)) {
            $this->Jsonmsg->init();
            if ($this->request->data['Acl']['Type'] == 'DataAcl') {
                if ($this->DataAcl->setRights($this->request->data['Requester'], $this->request->data['Rights'])) {
                    $this->Jsonmsg->valid();
                }
            }
            $this->Jsonmsg->send();
        } else {
            $this->Service->id = $id;
            $daro = $this->Service->node();
            $dataRights = $this->DataAcl->getRightsGrid($daro[0], array(), array('actions' => array('read', 'update'), 'models' => array('Metadonnee')));
            $this->set('dataRights', $dataRights);
            $this->set('id', $id);
        }
    }

    /**
     * Suppression d'un service
     *
     * @logical-group Services
     * @user-profile Admin
     *
     * @access public
     * @param integer $id identifiant du service
     * @return void
     */
    public function delete($id = null) {
        $this->Jsonmsg->init(__d('default', 'delete.error'));
        $valid = false;
        //s'il y a des utilisateurs dasn ce service, on ne peut pas le supprimer
        $user = $this->Service->getUsers($id);

        if (!count($user) > 0) {
            $servicesEnfants = $this->Service->find(
                    'all', array(
                'conditions' => array(
                    'Service.parent_id' => $id
                ),
                'contain' => false
                    )
            );

            $servicesEnfants = Hash::extract($servicesEnfants, '{n}.Service.id');

            $success = true;
            if (!empty($servicesEnfants)) {
                $success = false;
                foreach ($servicesEnfants as $i => $enfantId) {
                    $this->Service->delete($enfantId);
                    $success = true;
                }
            }

            if ($success && $this->Service->delete($id)) {
                $this->Jsonmsg->valid(__d('default', 'delete.ok'));
            }
        } else {
            $this->Jsonmsg->error(__d('service', 'delete.userlinked'));
        }
        $this->Jsonmsg->send();
    }

}

?>