<?php

App::import('Sanitize');
App::uses('Folder', 'Utility');
App::uses('File', 'Utility');

/**
 * Flux
 *
 * Courriers controller class
 *
 * web-GFC : Gestion de Flux Citoyens (https://adullact.net/projects/webgfc)
 *
 * PHP version 7
 * @author Stéphane Sampaio
 * @copyright Initié par ADULLACT - Développé par ADULLACT Projet
 * @link http://adullact.org/
 * @license http://www.cecill.info/licences/Licence_CeCILL_V2-fr.txt CeCiLL v2
 *
 * @package		app
 * @subpackage		Controller
 */
class CourriersController extends AppController {

    /**
     * Controller name
     *
     * @var array
     */
    public $name = 'Courriers';

    /**
     * Controller uses
     *
     * @var array
     */
    public $uses = array('Courrier');

    /**
     * Controller components
     *
     * @var array
     */
    public $components = array('Email', 'DataAuthorized', 'Cmis', 'Conversion');

    /**
     * Controller helpers
     *
     * @var array
     */
    public $helpers = array('Notification', 'GFCComment');

    protected function _setOptions() {
        // Informations sur les organismes
        $this->set(
                'organismes', $this->Courrier->Organisme->find(
                        'all', array(
                    'conditions' => array('Organisme.active' => true),
                    'order' => array('Organisme.name ASC'),
                    'contain' => array(
                        'Contact' => array(
                            'order' => 'Contact.nom ASC'
                        )
                    ),
                    'recursive' => -1
                        )
                )
        );

        // Informations sur les adresses en BDD
        $this->set(
                'bans', $this->Courrier->Organisme->Ban->find(
                        'all', array(
                    'order' => array('Ban.id ASC'),
                    'contain' => array(
                        'Bancommune' => array(
                            'order' => 'Bancommune.name ASC'
                        )
                    ),
                    'recursive' => -1
                        )
                )
        );

        // Valeur de l'organisme par défaut
        $this->set('sansOrganisme', Configure::read('Sansorganisme.id'));
        // Valeur du contact par défaut
        $this->set('sansContact', Configure::read('Sanscontact.id'));

        // Informations sur les carnets d'adresse
        $this->set('addressbooks', $this->Courrier->Organisme->Addressbook->find('list', array('conditions' => array('Addressbook.active' => true), 'order' => 'Addressbook.name ASC', 'recursive' => -1)));
        $this->set('orgs', $this->Courrier->Organisme->find('list', array('conditions' => array('Organisme.active' => true), 'order' => 'Organisme.name ASC', 'recursive' => -1)));
        $options = array();
        $options = $this->Courrier->Organisme->Addressbook->listTypesVoie();

//        $civilite = array('Monsieur' => 'Monsieur', 'Madame' => 'Madame', 'Monsieur et Madame' => 'Monsieur et Madame');
        $civilite = array(1 => 'Monsieur', 2 => 'Madame', 3 => 'Monsieur et Madame');

        $this->set(compact('options', 'civilite'));

        $this->set('activites', $this->Courrier->Organisme->Activite->find('list', array('order' => array('Activite.name ASC'), 'conditions' => array('Activite.active' => true), 'recursive' => -1)));
        if (Configure::read('Conf.SAERP')) {
            $this->set('operations', $this->Courrier->Organisme->Operation->find('list', array('order' => array('Operation.name ASC'), 'conditions' => array('Operation.active' => true), 'recursive' => -1)));
            $this->set('events', $this->Courrier->Organisme->Contact->Event->find('list', array('order' => array('Event.name ASC'), 'conditions' => array('Event.active' => true), 'recursive' => -1)));
            $this->set('fonctions', $this->Courrier->Organisme->Contact->Fonction->find('list', array('order' => array('Fonction.name ASC'), 'conditions' => array('Fonction.active' => true), 'recursive' => -1)));
        }
    }

    /**
     *
     */
    public function beforeFilter() {
        parent::beforeFilter();
        $this->Auth->allow('acquisition', 'getContext', 'validEtapeLastCol', 'ajaxformtype', 'traitementlot', 'execTraitementlot', 'refusparlot', 'sendcopylot', 'deletelot', 'detachelot');
//        $this->Auth->allow('acquisition');
    }

    /**
     * Vérifie si un flux est présent dans les bannettes de tous les rôles d'un utilisateur
     *
     * @access private
     * @param array $flux
     * @param integer $desktopId si défini, la vérification se fait pour le rôle correspondant à cet identifiant
     * @return integer
     */
    private function _inBannette($flux, $desktopId = null) {
        if ($desktopId != null) {
            $desktops = array($desktopId);
        } else {
            $desktops = $this->SessionTools->getDesktopList();
        }
        $querydata = array(
            'conditions' => array(
                'Bancontenu.courrier_id' => $flux['Courrier']['id'],
                'Bancontenu.desktop_id' => $desktops,
                'Bancontenu.etat' => '1'
            ),
            'recursive' => -1
        );
        $result = $this->Courrier->Bancontenu->find('first', $querydata);
        return !empty($result);
    }

    /**
     * Vérifie si un flux est présent dans la bannette "pour copie" de tous les rôles d'un utilisateur
     *
     * @access private
     * @param array $flux
     * @param integer $desktopId si défini, la vérification se fait pour le rôle correspondant à cet identifiant
     * @return integer
     */
    private function _inBannetteCopy($flux, $desktopId = null) {
        if ($desktopId != null) {
            $desktops = array($desktopId);
        } else {
            $desktops = $this->SessionTools->getDesktopList();
        }
        $querydata = array(
            'conditions' => array(
                'Bancontenu.courrier_id' => $flux['Courrier']['id'],
                'Bancontenu.desktop_id' => $desktops,
                'Bancontenu.bannette_id' => BAN_COPY,
                'Bancontenu.etat' => 1
            ),
            'recursive' => -1
        );
        $result = $this->Courrier->Bancontenu->find('first', $querydata);
        return !empty($result);
    }

    /**
     * Vérifie si un flux est présent dans les bannettes de tous les rôles d'un utilisateur avec un statut 2 (historique)
     *
     * @access private
     * @param array $flux
     * @param integer $desktopId si défini, la vérification se fait pour le rôle correspondant à cet identifiant
     * @return integer
     */
    private function _inHistorique($flux, $desktopId = null) {
        if ($desktopId != null) {
            $desktops = array($desktopId);
        } else {
            $desktops = $this->SessionTools->getDesktopList();
        }

        $querydata = array(
            'conditions' => array(
                'Bancontenu.courrier_id' => $flux['Courrier']['id'],
                'Bancontenu.desktop_id' => $desktops,
                'Bancontenu.etat' => array('0', '2')
            ),
            'recursive' => -1
        );
        $result = $this->Courrier->Bancontenu->find('first', $querydata);
        return !empty($result);
    }

    /**
     * Vérifie si l'utilisateur à le droit d'accèder au flux parent du flux réponse
     *
     * @access private
     * @param array $flux
     * @param integer $desktopId
     * @return boolean
     */
    private function _isAuthorizedResponse($flux, $desktopId = null) {
        $newFlux = $this->Courrier->find('first', array('conditions' => array('Courrier.parent_id' => $flux['Courrier']['id']), 'recursive' => -1));
        return ($this->_inBannette($newFlux, $desktopId) || $this->_inHistorique($newFlux, $desktopId));
    }

    /**
     * Visualisation / Edition d'un flux (interface graphique)
     *
     * @logical-group Flux
     * @logical-group Visualisation d'un flux
     * @logical-group Edition d'un flux
     * @user-profile User
     *
     * @access public
     * @param integer $id identifiant du flux
     * @param integer $desktopId identifiant du rôle de l'utilisateur
     * @param integer $tab numéro de l'onglet à réouvrir une fois les modifications effectuées (javascript)
     * @throws NotFoundException
     * @return void
     */
    public function view($id, $desktopId = null, $tab = null, $mode = null) {

//        debug($this->Courrier->isInRetard($id));
        $this->Courrier->recursive = -1;
        $qdCourrier = array(
            'fields' => array_merge(
                    $this->Courrier->fields(), $this->Courrier->Soustype->fields()
            ),
            'conditions' => array(
                'Courrier.id' => $id
            ),
            'joins' => array(
                $this->Courrier->join('Soustype')
            ),
            'recursive' => -1
        );

        $courrier = $this->Courrier->find('first', $qdCourrier);

        if (empty($courrier)) {
            throw new NotFoundException();
        }

        $fromTask = Configure::read('fromTask');

// echo '<pre>';var_dump($this->Courrier->createRefus($courrier));echo '</pre>';

        $fromMesServices = false;
        $fluxMesServices = $this->Session->read('Auth.User.Courrier.mesServices');

// Ajout du contrôle sur le profil Admin. Si l'utilisateur est Admin alors il voit tout
        $secondaryDesktops = $this->Session->read('Auth.User.SecondaryDesktops');
        $desktopName = Hash::extract($secondaryDesktops, '{n}.Group.name');

        $isAdmin = false;
        $groupName = $this->Session->read('Auth.User.Desktop.Group');
        if (in_array('Admin', $desktopName) || !empty($groupName) && $groupName['name'] == 'Admin') {
            $isAdmin = true;
        }
        $isUserInit = false;
        if (in_array('Initiateur', $desktopName) || $groupName['name'] == 'Initiateur') {
            $isUserInit = true;
        }
        $this->set('isUserInit', $isUserInit);

        $isUserDisp = false;
        if (in_array('Aiguilleur', $desktopName) || $groupName['name'] == 'Aiguilleur') {
            $isUserDisp = true;
        }
        $this->set('isUserDisp', $isUserDisp);

        $isUserDoc = false;
        if (in_array('Documentaliste', $desktopName) || $groupName['name'] == 'Documentaliste') {
            $isUserDoc = true;
        }
        $this->set('isUserDoc', $isUserDoc);

        if (!empty($fluxMesServices)) {
            if (in_array($id, $fluxMesServices) && !in_array($desktopId, $this->SessionTools->getDesktopList())) {
                $fromMesServices = true;
            }
        }
        $fromHistorique = preg_match('#historique$#', @$_SERVER['HTTP_REFERER']);

        $viewParentMode = false;


        $fromMesCopies = false;
        $fluxMesCopies = $this->Session->read('Auth.User.Courrier.mesCopies');
//        debug($this->SessionTools->getDesktopList());
//        debug($id);
        if (!empty($fluxMesCopies)) {
            if (in_array($id, $fluxMesCopies) /* && !in_array($desktopId, $this->SessionTools->getDesktopList()) */) {
                $fromMesCopies = true;
            }
        }


        $fromBannetteCopy = $this->_inBannetteCopy($courrier);
        $ariane = array(
            '<a href="/environnement/index/0">' . __d('menu', 'Courrier') . '</a>',
            '<a href="/environnement/index/0">' . __d('courrier', 'View Courrier') . '</a>',
            $courrier['Courrier']['name']
        );
        $parent = array();
        if (!empty($courrier['Courrier']['parent_id'])) {
            $qdParent = array(
                'fields' => array(
                    'Courrier.id',
                    'Courrier.name'
                ),
                'conditions' => array(
                    'Courrier.id' => $courrier['Courrier']['parent_id']
                ),
                'recursive' => -1
            );
            $parent = $this->Courrier->find('first', $qdParent);
            $ariane = array(
                '<a href="/environnement/index/0">' . __d('menu', 'Courrier') . '</a>',
                '<a href="/environnement/index/0">' . __d('courrier', 'View Courrier') . '</a>',
                '<a href="/courriers/historiqueGlobal/' . $parent['Courrier']['id'] . '">' . $parent['Courrier']['name'] . '</a>',
                $courrier['Courrier']['name']
            );
        }


// En cas de refus 
        $fluxRefus = array();
        if (!empty($courrier['Courrier']['ref_ancien'])) {
            $qdFluxRefus = array(
                'fields' => array(
                    'Courrier.id',
                    'Courrier.name'
                ),
                'conditions' => array(
                    'Courrier.id' => $courrier['Courrier']['ref_ancien']
                ),
                'recursive' => -1
            );
            $fluxRefus = $this->Courrier->find('first', $qdFluxRefus);
        }
        $this->set('fluxRefus', $fluxRefus);

//

        $sortant = false;
        if (isset($courrier['Soustype']['entrant']) && $courrier['Soustype']['entrant'] == 0) {
            $sortant = true;
        }
        $this->set('sortant', $sortant);
        $this->set('parent', $parent);
        $this->set('ariane', $ariane);
        $this->set('courrier', $courrier);
        $this->set('mainDoc', $this->Courrier->getLightMainDoc($courrier['Courrier']['id']));

//on verifie si le courrier est un courrier cloturé
        $isClosed = $this->Courrier->isClosed($courrier['Courrier']['id']);
        $this->set('isClosed', $isClosed);

//on verifie si le courrier est un courrier refusé
        $this->set('isRefused', $this->Courrier->isRefused($courrier['Courrier']['id']));

//on determine si le courrier est dans un circuit
        $this->set('inCircuit', $this->Courrier->isInCircuit($courrier['Courrier']['id']));
//on determine si le courrier est a l etape de fin
        $endCircuit = false;
        if ($this->Session->read('Auth.User.Env.actual.name') != 'disp') {
            $etape = $this->Courrier->Traitement->whichIsNext($courrier['Courrier']['id']);
            if (!empty($etape) && $this->Courrier->Traitement->Circuit->Etape->estDerniereEtape($etape['Etape']['id'])) {
                $endCircuit = true;
            }
        }
        $this->set('endCircuit', $endCircuit);

        if (empty($desktopId)) {
            $desktopId = $this->Session->read('Auth.User.Desktop.id');
        }

        if (!$fromHistorique && !$fromMesServices /* && !$fromTask */) {
//On enleve les notifications concernant ce flux
            $this->Courrier->Notifieddesktop->Notification->setReadByDesktopCourrier($desktopId, $courrier['Courrier']['id']);
            $this->Courrier->Bancontenu->setRead($courrier['Courrier']['id'], $desktopId);
        }


        $desktopUserId = $this->Session->read('Auth.User.Courrier.Desktop.id');
        $desktopManagerId = $this->Courrier->Desktop->DesktopDesktopmanager->field('desktopmanager_id', array('DesktopDesktopmanager.desktop_id' => $desktopUserId));
        $isUserInCircuit = false;
        if ($this->Session->read('Auth.User.Env.actual.name') != 'disp') {
            $traitement = $this->Courrier->Traitement->find(
                    'first', array(
                'fields' => array('circuit_id'),
                'conditions' => array('Traitement.target_id' => $courrier['Courrier']['id']),
                'contain' => false
                    )
            );
            if (!empty($traitement)) {
                $circuitId = $traitement['Traitement']['circuit_id'];
                $isUserInCircuit = $this->Courrier->Traitement->Circuit->userInCircuit($desktopManagerId, $circuitId);
            }
        }
        $this->set(compact('isUserInCircuit'));


        $userDesktops = $this->getSessionAllDesktops();
        if (in_array($desktopId, array_keys($userDesktops))) {
            $this->Session->write('Auth.User.Courrier.Desktop.id', $desktopId);
            $aro = array('model' => 'Desktop', 'foreign_key' => $desktopId);
        } else if ($fromHistorique || $fromMesServices || $fromTask) {
            $aro = array('model' => 'Desktop', 'foreign_key' => $this->Session->read('Auth.User.Desktop.id'));
        } else {
            throw new ForbiddenException();
        }

        $rights = array(
            'getInfos' => $this->Acl->check($aro, 'controllers/Courriers/getInfos'),
            'getMeta' => $this->Acl->check($aro, 'controllers/Courriers/getMeta'),
            'getTache' => $this->Acl->check($aro, 'controllers/Courriers/getTache'),
            'getAffaire' => $this->Acl->check($aro, 'controllers/Courriers/getAffaire'),
            'getFlowControls' => $this->Acl->check($aro, 'controllers/Courriers/getFlowControls'),
            'setInfos' => $this->Acl->check($aro, 'controllers/Courriers/setInfos'),
            'setMeta' => $this->Acl->check($aro, 'controllers/Courriers/setMeta'),
            'setTache' => $this->Acl->check($aro, 'controllers/Courriers/setTache'),
            'setAffaire' => $this->Acl->check($aro, 'controllers/Courriers/setAffaire'),
            'getArs' => $this->Acl->check($aro, 'controllers/Courriers/getArs'),
            'getRelements' => $this->Acl->check($aro, 'controllers/Courriers/getRelements'),
            'getDocuments' => $this->Acl->check($aro, 'controllers/Courriers/getDocuments'),
            'getCircuit' => $this->Acl->check($aro, 'controllers/Courriers/getCircuit'),
            'edit' => true
        );
//        if (!$rights['setInfos']){
//            $rights['editSetInfos'] = false;
//        }
//        if (!$rights['setAffaire']){
//            $rights['editSetAffaire'] = false;
//        }
        if (!$rights['setInfos'] && !$rights['setMeta'] && !$rights['setTache'] && !$rights['setAffaire']) {
            $rights['edit'] = false;
        }
        
        if($isAdmin) {
            $rights['getFlowControls'] = true;
        }
        $desktopsInBancontenu = $this->Courrier->Bancontenu->find(
            'all',
            array(
                'conditions' => array(
                    'Bancontenu.courrier_id' => $id,
                    'Bancontenu.desktop_id' => $desktopId
                ),
                'contain' => array(
                    'Desktop'
                ),
                'recursive' => -1,
                'order' => 'Bancontenu.created ASC'
            )
        );
        // Si le flux n'est pas dans la bannette des flux en copie du bureau ayant accèsq au flux, alors on autorise la modification
        if( !empty( $desktopsInBancontenu) ) {
            if( $desktopsInBancontenu[0]['Bancontenu']['bannette_id'] != BAN_COPY ) {
                $fromBannetteCopy = false;
                $fromMesCopies = false;
            }
        }
        
        $viewOnlyTabs = array(
            'getInfos' => ($rights['getInfos'] && !$rights['setInfos']) || $isClosed || $fromHistorique || $fromBannetteCopy || $fromTask,
            'getTache' => ($rights['getTache'] && !$rights['setTache']) || $isClosed || $fromHistorique || $fromBannetteCopy || $fromTask,
            'getMeta' => ($rights['getMeta'] && !$rights['setMeta']) || $isClosed || $fromHistorique || $fromBannetteCopy || $fromTask,
            'getAffaire' => ($rights['getAffaire'] && !$rights['setAffaire']) || $isClosed || $fromHistorique || $fromBannetteCopy || $fromTask
        );

        $this->Session->delete('Auth.User.Courrier.viewOnlyTabs');
        $this->Session->write('Auth.User.Courrier.viewOnlyTabs', $viewOnlyTabs);

        // Le circuit possède-t-il comme prochaine étape une délégation vers le parapheur ?
        $isDelegatedToParapheur = false;
        if ($this->Session->read('Auth.User.Env.actual.name') != 'disp') {
            $circuit = $this->getCircuit($id);
            $IdCircuit = Hash::get($this->viewVars, 'circuit.Circuit.id');
            $isDelegatedToParapheur = $this->Courrier->Traitement->Circuit->hasEtapeDelegation($IdCircuit);
        }

        $this->set('isDelegatedToParapheur', $isDelegatedToParapheur);

        $this->set('fromTask', $fromTask);
        $this->set('fromBannetteCopy', $fromBannetteCopy);
        $this->set('fromMesServices', $fromMesServices);
        $this->set('fromMesCopies', $fromMesCopies);
        $this->set('fromHistorique', $fromHistorique);
        $this->set('rights', $rights);
        $this->set('tab', $tab);
// debug($this->Session->read('Auth.User.Courrier'));
        $this->set('desktopidactuel', $this->Session->read('Auth.User.Courrier.Desktop.id'));
        $this->set('envactuel', $this->Session->read('Auth.User.Env.actual.name'));
//        debug( $this->Session->read( 'Auth.User.Env' ) );
        $viewOnly = $this->Session->read('Auth.User.Courrier.viewOnlyTabs.getInfos');
        $this->set('viewOnly', $viewOnly);
        if ($mode != null) {
            $this->set('mode', $mode);
        }

        $nbComment = 0;
        $ownerId = $this->SessionTools->getDesktopList();
        $nbComment = $this->Courrier->Comment->getNumberOfCommentByCourrierId($id, $ownerId);
        $this->set('nbComment', $nbComment);
        $this->set('sansContact', Configure::read('Sanscontact.id'));

        if (isset($mode) && $mode = 'edit') {
            $initMode = "edit";
        } else if ($fromMesCopies) {
            $initMode = "view";
        } else {
            if (!$viewOnly && $rights['edit'] && !$isClosed && !$fromHistorique && !$fromMesCopies && !$fromTask && !$fromMesServices) {
                $initMode = "edit";
            } else {
                $initMode = "view";
            }
        }

        $this->set('initMode', $initMode);
        $conn = $this->Session->read('Auth.User.connName');
        $this->loadModel('Collectivite');
        $this->set('collectivite', $this->Collectivite->find('first', array('conditions' => array('Collectivite.conn' => $conn))));
        
        $this->set('desktopId', $desktopId );
        
//        $this->log( "L'utilisateur ". $this->Session->read('Auth.User.username'). " a consulté le flux ".$courrier['Courrier']['reference']." le ".date('d/m/Y à H:i:s'), LOG_WARNING );

        $this->loadModel('Journalevent');
        $datasSession = $this->Session->read('Auth.User');
        $msg = "L'utilisateur ". $this->Session->read('Auth.User.username'). " a consulté le flux ".$courrier['Courrier']['reference']." le ".date('d/m/Y à H:i:s');
        $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $courrier);
    }

    /**
     * @logical-group Flux
     * @logical-group Edition d'un flux
     *
     * @logical-used-by Flux > Edition d'un flux
     * @userProfile User
     *
     * Edition d'un flux (uniquement pour la gestion des habilitations
     *
     * @access public
     * @return void
     */
//FIXME: supprimer cette fonction et trouver une méthode pour indiquer le droit d'édition dans la gestion des ACL
    public function edit(/* $id = null */) {
    }

    /**
     * Création d'un flux
     *
     * @logical-group Flux
     * @logical-group Création d'un flux
     * @user-profile User
     *
     * @param type $desktopId
     * @throws ForbiddenException
     * @return void
     */
    public function add($desktopId, $serviceId, $tab = null) {

        $aro = array('model' => 'Desktop', 'foreign_key' => $desktopId);
        $rights = array(
            'createInfos' => $this->Acl->check($aro, 'controllers/Courriers/createInfos'),
            'setInfos' => $this->Acl->check($aro, 'controllers/Courriers/setInfos'),
            'setMeta' => $this->Acl->check($aro, 'controllers/Courriers/setMeta'),
            'setTache' => $this->Acl->check($aro, 'controllers/Courriers/setTache'),
            'setAffaire' => $this->Acl->check($aro, 'controllers/Courriers/setAffaire'),
            'getArs' => $this->Acl->check($aro, 'controllers/Courriers/getArs'),
            'getRelements' => $this->Acl->check($aro, 'controllers/Courriers/getRelements'),
            'getDocuments' => $this->Acl->check($aro, 'controllers/Courriers/getDocuments'),
//			'setCircuit' => $this->Acl->check($aro, 'controllers/Courriers/setCircuit'),
            'getCircuit' => $this->Acl->check($aro, 'controllers/Courriers/getCircuit')
        );

        if (!$rights['createInfos'] /* || !$rights['setQualification'] */) {
            throw new ForbiddenException();
        }

        $this->set('fluxId', '');
        $this->set('rights', $rights);
        $this->Session->write('Auth.User.Courrier.Desktop.id', $desktopId);
        $this->Session->write('Auth.User.Courrier.Service.id', $serviceId);
        $fromMesServices = false;
        $this->set('fromMesServices', $fromMesServices);
        $this->set('tab', $tab);
        $this->set('sansContact', Configure::read('Sanscontact.id'));
    }

    /**
     * Accès à l'onglet "Informations" (ajax)
     *
     * @logical-group Flux
     * @logical-group Visualisation d'un flux
     * @user-profile User
     *
     * @access public
     * @param integer $id
     * @throws NotFoundException
     * @return void
     */
    public function getInfos($id = null) {
        $querydata = array(
            'conditions' => array(
                'Courrier.id' => $id
            ),
            'contain' => array(
                'Organisme',
                'Contact',
                'Soustype' => array(
                    'Type'
                ),
                'Affairesuivie',
                'Origineflux'
            )
        );

        if (Configure::read('Conf.SAERP')) {
            $querydataSAERP = array(
                'contain' => array(
                    'Marche',
                    'Ordreservice',
                    'Pliconsultatif'
                )
            );
            $querydata['contain'] = array_merge($querydata['contain'], $querydataSAERP['contain']);
        }

        $flux = $this->Courrier->find('first', $querydata);

        $contactinfosTreated = array();
        $organismeTreated = array();

        if (!empty($flux['Courrier']['organisme_id'])) {
            $organisme = $this->Courrier->Organisme->find('first', array(
                'fields' => array_merge(
                        $this->Courrier->Organisme->fields(), $this->Courrier->Organisme->Ban->fields(), $this->Courrier->Organisme->Bancommune->fields()
                ),
                'conditions' => array(
                    'Organisme.id' => $flux['Courrier']['organisme_id'],
                    'Organisme.active' => true
                ),
                'joins' => array(
                    $this->Courrier->Organisme->join('Ban', array('type' => 'LEFT OUTER')),
                    $this->Courrier->Organisme->join('Bancommune', array('type' => 'LEFT OUTER'))
                ),
                'contain' => false,
                'recursive' => -1
            ));
//debug($organisme);
            $return = array();
            if (!empty($organisme)) {
                $oInfos = array();
                foreach ($organisme['Organisme'] as $key => $val) {
                    if ($val != '' && $val != 'active' && $key != 'addressbook_id' && $key != 'ban_id' && $key != 'bancommune_id') {
                        $oInfos[$key != 'id' ? __d('organisme', 'Organisme.' . $key) : $key] = $val;
                    }
                }

                $bInfos = array();
                foreach ($organisme['Ban'] as $key => $val) {
                    if ($val != '' && $val != 'active' && $key != 'created' && $key != 'modified') {
                        $bInfos[$key != 'id' ? __d('ban', 'Ban.' . $key) : $key] = $val;
                    }
                }
                $bcInfos = array();
                foreach ($organisme['Bancommune'] as $key => $val) {
                    if ($val != '' && $val != 'active' && $key != 'created' && $key != 'modified' && $key != 'ban_id') {
                        $bcInfos[$key != 'id' ? __d('bancommune', 'Bancommune.' . $key) : $key] = $val;
                    }
                }
//debug($oInfos);
                $organismeTreated = array(
                    'Organisme' => ( $oInfos + $bInfos + $bcInfos)
                );
            }
        }

        if (!empty($flux['Courrier']['contact_id'])) {
            $contact = $this->Courrier->Contact->find('first', array(
                'fields' => array_merge(
                        $this->Courrier->Contact->fields(), $this->Courrier->Contact->Ban->fields(), $this->Courrier->Contact->Bancommune->fields()
                ),
                'conditions' => array(
                    'Contact.id' => $flux['Courrier']['contact_id'],
                    'Contact.active' => true
                ),
                'joins' => array(
                    $this->Courrier->Contact->join('Ban', array('type' => 'LEFT OUTER')),
                    $this->Courrier->Contact->join('Bancommune', array('type' => 'LEFT OUTER'))
                ),
                'contain' => false,
                'recursive' => -1
            ));

            if (!empty($contact)) {
                $cInfos = array();
                $civiliteOptions = array(
                    '1' => 'Monsieur',
                    '2' => 'Madame',
                    '3' => 'Monsieur et Madame'
                );
                foreach ($contact['Contact'] as $key => $val) {
                    if ($val != '' && $val != 'active' && $val != 'addressbook_id' && $key != 'organisme_id' && $key != 'organisme_name' && $key != 'carnet_name' && $key != 'ville' && $key != 'ban_id' && $key != 'bancommune_id') {
                        if ($key == 'civilite') {
                            $cInfos['civilite'] = $civiliteOptions[$val];
                        } else {
                            $cInfos[$key != 'id' && $key != 'name' ? __d('contact', 'Contact.' . $key) : $key] = $val;
                        }
                    }
                }

                $cbInfos = array();
                foreach ($contact['Ban'] as $key => $val) {
                    if ($val != '' && $val != 'active' && $key != 'created' && $key != 'modified') {
                        $cbInfos[$key != 'id' ? __d('ban', 'Ban.' . $key) : $key] = $val;
                    }
                }
                $cbcInfos = array();
                foreach ($contact['Bancommune'] as $key => $val) {
                    if ($val != '' && $val != 'active' && $key != 'created' && $key != 'modified' && $key != 'ban_id') {
                        $cbcInfos[$key != 'id' ? __d('bancommune', 'Bancommune.' . $key) : $key] = $val;
                    }
                }

                $contactinfosTreated = array(
                    'Contactinfo' => ( $cInfos + $cbInfos + $cbcInfos )
                );
            }
        }

        $this->set('contactinfosTreated', $contactinfosTreated);
        $this->set('organismeTreated', $organismeTreated);

        // Liste des bureaux en copie
        $desktopsCopie = array();
        if (!empty($id)) {
            $desktopsCopie = $this->Courrier->Bancontenu->find(
                    'all', array(
                'conditions' => array(
                    'Bancontenu.courrier_id' => $id,
                    'Bancontenu.bannette_id' => BAN_COPY
                ),
                'contain' => array(
                    'Desktop'
                ),
                'recursive' => -1,
                'order' => 'Bancontenu.created ASC'
                    )
            );
        }
        $this->set('desktopsCopie', $desktopsCopie);


//debug($flux); 
        if (empty($flux)) {
            throw new NotFoundException();
        }

        $this->set('types', $this->Courrier->Soustype->Type->find('list'));
        $this->set('soustypes', $this->Courrier->Soustype->find('all', array('recursive' => -1)));
        $this->set('flux', $flux);
        $this->set('viewOnly', $this->Session->read('Auth.User.Courrier.viewOnlyTabs.getInfos'));
        
        $users = $this->Courrier->Desktop->User->find(
            'all',
            array(
                'contain' => false,
                'recursive' => -1,
                'contain' => array(
                    'Desktop'
                ),
                'order' => 'User.nom ASC'
            )
        );
        foreach( $users as $user) {
            $allDesktops[$user['Desktop']['id']] = $user['User']['nom'].' '.$user['User']['prenom'];
        } 
//        $allDesktops = $this->Courrier->Desktop->getDesktopsByService('all');
//        ksort($allDesktops);
//        debug($allDesktops);
        $this->set('allDesktops', $allDesktops);

        // Liste des acteurs
        $bannettes = $this->Courrier->Bancontenu->find(
                'all', array(
            'conditions' => array(
                'Bancontenu.courrier_id' => $id
            ),
            'contain' => array(
                'Desktop' => array(
                    'SecondaryUser',
                    'User',
                    'Group',
                    'Desktopmanager',
                ),
                'Bannette'
            ),
            'order' => array('Bancontenu.modified ASC', 'Desktop.name ASC')
                )
        );
//debug($bannettes);
//select date from wkf_visas where traitement_id in (select id from wkf_traitements where target_id=courrier_id) ;
        $traitement = $this->Courrier->Traitement->find('first', array(
            'fields' => array(
                'Traitement.id',
                'Traitement.circuit_id',
                'Traitement.numero_traitement'
            ),
            'conditions' => array(
                'Traitement.target_id' => $id
            ),
            'contain' => false,
            'recursive' => -1
        ));
        $traitement_id = Hash::get($traitement, 'Traitement.id');

        $visas = $this->Courrier->Traitement->Visa->find(
                'all', array(
            'fields' => array_merge(
                    $this->Courrier->Traitement->Visa->fields(), $this->Courrier->Traitement->Visa->Desktopmanager->fields()
            ),
            'conditions' => array(
                'Visa.traitement_id' => $traitement_id,
                'Visa.action' => array('OK', 'IL')
            ),
            'contain' => array(
                'Desktopmanager' => array(
                    'Desktop'
                )
            ),
            'recursive' => -1,
            'order' => 'Visa.numero_traitement ASC'
                )
        );
        $this->set('visas', $visas);

        $validated = array();
        foreach ($visas as $v => $visa) {
            $validated[$visa['Visa']['trigger_id']] = $visa['Visa']['date'];
        }

        foreach ($bannettes as $b => $bannette) {
            foreach ($bannette['Desktop']['Desktopmanager'] as $dKey => $desktopmanager) {
                if (isset($validated[$desktopmanager['id']])) {
                    $bannettes[$b]['Bancontenu']['validated'] = $validated[$desktopmanager['id']];
                }
            }

            // Si le flux n'est pas lu, on n'affiche pas la date de modification, ni celle de validation
            if ($bannette['Bancontenu']['read'] == false) {
                $bannettes[$b]['Bancontenu']['validated'] = '';
                $bannettes[$b]['Bancontenu']['modified'] = '';
            }
        }
        $this->set('bannettes', $bannettes);

        if (Configure::read('Conf.SAERP')) {
            $marches_tmp = $this->Courrier->Marche->find(
                'all',
                array(
                    'joins' => array(
                        $this->Courrier->Marche->join('Operation')
                    ),
                    'conditions' => array(
                        'Marche.active' => true,
                        'Operation.active' => true
                    ),
                    'fields' => array(
                        'Marche.id',
                        'Marche.numero',
                        'Marche.titulaire'
                    ),
                    'contain' => false,
                    'order' => array('Marche.name ASC')
                )
            );  
            foreach( $marches_tmp as $m => $values) {
                $marches[$values['Marche']['id']] = $values['Marche']['numero']." - ".$values['Marche']['titulaire'];
            }
            $this->set(compact('marches'));

            $typesdocument = array(
                'OS' => 'Ordre de service',
                'PLI' => 'Pli',
                'LC' => 'Lettre de commandes',
                'LN' => 'Lettre de notification'
            );
            $this->set(compact('typesdocument'));
            $this->set('originesflux', $this->Courrier->Origineflux->find('list', array('conditions' => array('Origineflux.active' => true), 'order' => array('Origineflux.name ASC'))));
        }
    }

    /**
     * Récupération du schéma du circuit emprunté par le flux
     *
     * @logical-group Flux
     * @logical-group Context
     * @user-profile User
     *
     * @access public
     * @param integer $id
     * @throws NotFoundException
     * @return void
     */
    public function getCircuit($fluxId) {
//		if (empty($fluxId)) {
//			throw new BadMethodCallException();
//		}

        $qdCircuit = array(
            'fields' => array(
                'Circuit.id',
                'Circuit.nom'
            ),
            'conditions' => array(
                'Courrier.id' => $fluxId
            ),
            'contain' => false,
            'joins' => array(
                $this->Courrier->join($this->Courrier->Soustype->alias),
                $this->Courrier->Soustype->join($this->Courrier->Soustype->Circuit->alias),
            )
        );
        $circuit = $this->Courrier->find('first', $qdCircuit);

        $etapes = null;
        $visas = null;
        if (!empty($circuit)) {
            //definition de l identifiant du circuit
            $circuitId = $circuit['Circuit']['id'];

            //recuperation de la structure initiale du circuit
            $qdEtapes = array(
                'fields' => array(
                    'Etape.nom',
                    'Etape.type',
                    'Etape.ordre',
                    'Etape.description'
                ),
                'contain' => array(
                    'Composition.type_validation',
                    'Composition.trigger_id',
                    'Composition.soustype',
                    'Composition' => array(
                        CAKEFLOW_TRIGGER_MODEL => array('fields' => CAKEFLOW_TRIGGER_FIELDS)
                    )
                ),
                'conditions' => array(
                    'Etape.circuit_id' => $circuitId
                ),
                'order' => 'Etape.ordre'
            );
            $etapes = $this->Courrier->Traitement->Circuit->Etape->find('all', $qdEtapes);
//debug($etapes);
            // Ajout du cas où aucune composition mais on alimente la compo par les données stockées en aramétrage // SAERP
            if (Configure::read('Conf.SAERP')) {
                //@TODO: lire les infos associées au type / sous-type SAAERP (cf OPs) !!!!
                $courrier = $this->Courrier->find('first', array(
                    'fields' => array_merge(
                            $this->Courrier->fields(), $this->Courrier->Soustype->fields(), $this->Courrier->Soustype->Type->fields(), $this->Courrier->Soustype->Type->Operation->fields()
                    ),
                    'conditions' => array(
                        'Courrier.id' => $fluxId
                    ),
                    'joins' => array(
                        $this->Courrier->join('Soustype'),
                        $this->Courrier->Soustype->join('Type'),
                        $this->Courrier->Soustype->Type->join('Operation')
                    ),
                    'recursive' => -1
                ));
                //$type = $courrier['Type'];

                if (!empty($courrier['Operation'])) {
                    $sousoperation = $this->Courrier->Soustype->Type->Operation->Sousoperation->find('first', array(
                        'conditions' => array(
                            'Sousoperation.soustype_id' => $courrier['Soustype']['id']
                        ),
                        'contain' => false
                    ));
//debug($sousoperation);
//                    $operationCompo = 0;
                    if (isset($sousoperation) && !empty($sousoperation)) {
                        $sousoperationName = $sousoperation['Sousoperation']['name'];
                    }
                    if (!empty($sousoperation) && $sousoperationName != Configure::read('Soustype.Fantome')) {
                        $sousoperationId = $sousoperation['Sousoperation']['id'];


                        $operationCompo = array();
                        $operationsCompos = $this->Courrier->Soustype->Type->Operation->Sousoperation->DesktopmanagerSousoperation->find(
                                'all', array(
                            'conditions' => array(
                                'DesktopmanagerSousoperation.sousoperation_id' => $sousoperationId
                            ),
                            'contain' => false,
                            'order' => array('DesktopmanagerSousoperation.ordre ASC')
                                )
                        );
                        foreach ($operationsCompos as $i => $compo) {
                            $operationCompo[$compo['DesktopmanagerSousoperation']['ordre']][] = $operationsCompos[$i];
                        }

                        $associations = array();
                        if (!empty($operationCompo)) {
                            foreach ($operationCompo as $n => $op) {
                                $intitulesagentsIds = Hash::extract($op, '{n}.DesktopmanagerSousoperation.intituleagent_id');
                                // ajout des associations entre OP, poste et bureaux
                                $associations[$n] = $this->Courrier->Soustype->Type->Operation->Intituleagentbyoperation->find(
                                        'all', array(
                                    'conditions' => array(
                                        'Intituleagentbyoperation.operation_id' => $courrier['Operation']['id'],
                                        'Intituleagentbyoperation.intituleagent_id' => $intitulesagentsIds
                                    ),
                                    'contain' => array(
                                        'Desktopmanager'
                                    )
                                        )
                                );
//    debug($associations);
                            }
                        }
                    }
                }
                $newetapes = array();
                foreach ($etapes as $k => $etape) {
                    $newetapes[$etape['Etape']['ordre']] = $etapes[$k];
                }

                foreach ($newetapes as $e => $etape) {
                    $desktopmanagerId = array();
                    $desktopmanagerName = array();
                    if (isset($associations) && !empty($associations)) {
                        foreach ($associations as $a => $association) {
                            foreach ($association as $v => $val) {
                                $desktopmanagerId[$a][$v] = $val['Desktopmanager']['id'];
                                $desktopmanagerName[$a][$v] = $val['Desktopmanager']['name'];
                            }
                        }
                    }
                    if (empty($etape['Composition'])) {
//debug($etape);
//debug($operationCompo[$e]);
                        if (isset($operationCompo) && $operationCompo != null) {
                            //FIXME: les compos ne sont pas "parfaites"
                            if (count($etapes) == count($operationCompo)) {
                                $compoTemp = array();
                                foreach ($operationCompo[$e] as $key => $info) {
                                    $compoTemp[$key]['etape_id'] = $etape['Etape']['id']; // id de l'étape
                                    $compoTemp[$key]['trigger_id'] = $desktopmanagerId[$e][$key]; // id du bureau
                                    $compoTemp[$key]['Desktopmanager']['name'] = $desktopmanagerName[$e][$key]; // Nom du bureau
                                    $compoTemp[$key]['type_validation'] = 'V';
                                }
                                $etapes[$e - 1]['Composition'] = $compoTemp;
                            } else {
                                
                            }
                        }
                    }
                }
            }
//debug($etapes);
//die();
            //recuperation du traitement du circuit
            $qdVisas = array(
                'fields' => array(
                    'Traitement.id',
                    'Traitement.target_id',
                    'Traitement.numero_traitement',
                    'Traitement.treated',
                    'Visa.etape_type',
                    'Visa.etape_nom',
                    'Visa.etape_id',
                    'Visa.trigger_id',
                    'Visa.action',
                    'Visa.numero_traitement',
                    'Etape.description',
                    'Etape.id',
//                    'Desktop.name',
                    CAKEFLOW_TRIGGER_MODEL . "." . CAKEFLOW_TRIGGER_FIELDS
                ),
                'contain' => false,
                'joins' => array(
                    array(
                        'table' => 'wkf_visas',
                        'alias' => 'Visa',
                        'type' => 'right',
                        'conditions' => array(
                            'Visa.traitement_id = Traitement.id'
                        )
                    ),
                    array(
                        'table' => 'wkf_etapes',
                        'alias' => 'Etape',
                        'type' => 'right',
                        'conditions' => array(
                            'Etape.id = Visa.etape_id'
                        )
                    ),
                    $this->Courrier->Traitement->Circuit->Traitement->Visa->join(CAKEFLOW_TRIGGER_MODEL)
                ),
                'conditions' => array(
                    'Traitement.target_id' => $fluxId
                ),
                'order' => array(
                    'Traitement.target_id',
                    'Visa.numero_traitement',
                    'Visa.id'
                )
            );
            $visas = $this->Courrier->Traitement->find('all', $qdVisas);
        }
//debug($visas);
        $compiledVisas = array();
        $compiledVisasRef = array();
        foreach ($visas as $kVisa => $visa) {
//debug($visa);
//die();
            if (in_array($visa['Visa']['numero_traitement'], $compiledVisasRef)) {
                $key = array_search($visa['Visa']['numero_traitement'], $compiledVisasRef);
                $compiledVisas[$key]['Composition'][] = array(
                    CAKEFLOW_TRIGGER_MODEL => array(
                        'name' => $visa[CAKEFLOW_TRIGGER_MODEL][CAKEFLOW_TRIGGER_FIELDS],
                        'action' => $visa['Visa']['action']
                    )
                );
            } else {
                $compiledVisasRef[$kVisa] = $visa['Visa']['numero_traitement'];
                $visa['Composition'] = array(
                    array(
                        CAKEFLOW_TRIGGER_MODEL => array(
                            'name' => $visa[CAKEFLOW_TRIGGER_MODEL][CAKEFLOW_TRIGGER_FIELDS],
                            'action' => $visa['Visa']['action']
                        )
                    )
                );
                $compiledVisas[$kVisa] = $visa;
            }
        }

        if( !Configure::read('Conf.SAERP') ) {
            // On masque les descriptions des étapes du circuit ajoutées par la fonction d'envoi avec ou sans AR.
            if( count($visas) >= 2 ) {
                for( $v=1; $v <= count($visas)-1; $v++ ) {
                    // si le flux est issu d'une étape précédente du type IL ou IP (envoi avec ou sans AR)
                    if ( in_array( $compiledVisas[$v]['Visa']['action'],  array( 'RI', 'OK' ) ) &&  in_array( $compiledVisas[$v-1]['Visa']['action'], array( 'IL', 'IP' ) )  ){
                        // on ne prend pas de description pour cette novuelle étape
                        $compiledVisas[$v]['Etape']['description'] = '';
                    }

                    // si le flux est issu d'une étape avec AR
                    if( $v == count($visas)-2) {
                        // si le flux est issu d'une étape précédente du type IL ou IP (envoi avec ou sans AR)
                        if ( in_array( $compiledVisas[$v]['Visa']['action'],  array( 'RI', 'OK' ) )  &&  in_array( $compiledVisas[$v-1]['Visa']['action'], array('RI', 'OK') ) ) {
                            // on ne prend pas de description pour cette novuelle étape
                            $compiledVisas[$v]['Etape']['description'] = '';
                        }   
                    }
                }
            }
        }
        
        
        $this->loadModel('Connecteur');
        $hasParapheurActif = $this->Connecteur->find(
            'first',
            array(
                'conditions' => array(
                    'Connecteur.name ILIKE' => '%Parapheur%'
                ),
                'contain' => false
            )
        );
        if( !empty( $hasParapheurActif )) {
            $soustypes = $this->Courrier->Traitement->Circuit->Etape->listeSousTypesParapheur($hasParapheurActif);
        }
        else {
            $soustypes = array();
        }
        $this->set( 'soustypes', $soustypes);
//debug($compiledVisas);
        $this->set('circuit', $circuit);
        $this->set('etapes', $etapes);
        $this->set('visas', $compiledVisas);
        $this->set('viewOnly', $this->Session->read('Auth.User.Courrier.viewOnlyTabs.getCircuit'));
    }

    /**
     * Accès à l'onglet "Méta-données" (ajax)
     *
     * @logical-group Flux
     * @logical-group Visualisation d'un flux
     * @user-profile User
     *
     * @access public
     * @param integer $fluxId identifiant du flux

     * @return void
     */
    public function getMeta($fluxId) {
//		if (!is_integer($fluxId) || $fluxId <= 0) {
//			throw new BadMethodCallException();
//		}

        $this->set('metas', $this->DataAuthorized->getAuthMetadonnees(array('fluxId' => $fluxId)));
        $this->set('viewOnly', $this->Session->read('Auth.User.Courrier.viewOnlyTabs.getMeta'));
    }

    /**
     * Accès à l'onglet "Tâches" (ajax)
     *
     * @logical-group Flux
     * @logical-group Visualisation d'un flux
     * @user-profile User
     *
     * @access public
     * @param integer $id identifiant du flux

     * @throws NotFoundException
     * @return void
     */
    public function getTache($fluxId) {
//		if (!is_integer($fluxId) || $fluxId <= 0) {
//			throw new BadMethodCallException();
//		}

        $qd = array(
            'conditions' => array(
                'Courrier.id' => $fluxId
            )
        );
        $courrier = $this->Courrier->find('first', $qd);
        if (empty($courrier)) {
            throw new NotFoundException();
        }
        $this->set('canAddTask', !empty($courrier['Courrier']['soustype_id']));

        $querydata = array(
            'contain' => array(
                $this->Courrier->Tache->Desktop->alias
            ),
            'conditions' => array(
                "Tache.courrier_id" => $fluxId
            ),
            'order' => array(
                'Tache.created'
            )
        );
        $taches_tmp = $this->Courrier->Tache->find('all', $querydata);

        $taches = array();
//on verifie que l utilisateur fasse partie des personnes pouvant valider la tache
        $userDesktops = $this->SessionTools->getDesktopList();
        foreach ($taches_tmp as $tache) {
//calcul du retard
            $retard = false;
            if ($tache['Tache']['statut'] != 2) {
                $tmpTime = preg_split('# #', $tache['Tache']['created']);
                $tmpTime1 = preg_split('#-#', $tmpTime[0]);
                if ($tache['Tache']['delai_unite'] == 0) {
                    $endTime = mktime(0, 0, 0, $tmpTime1[1], $tmpTime1[2] + $tache['Tache']['delai_nb'], $tmpTime1[0]);
                } else if ($tache['Tache']['delai_unite'] == 1) {
                    $endTime = mktime(0, 0, 0, $tmpTime1[1], $tmpTime1[2] + (7 * $tache['Tache']['delai_nb']), $tmpTime1[0]);
                } else if ($tache['Tache']['delai_unite'] == 2) {
                    $endTime = mktime(0, 0, 0, $tmpTime1[1] + $tache['Tache']['delai_nb'], $tmpTime1[2], $tmpTime1[0]);
                }
                if ($endTime < mktime()) {
                    $retard = true;
                }
            }
            $tache['retard'] = $retard;

            $tache['canGrab'] = false;
            $tache['canRelease'] = false;
            $tache['canValid'] = false;

            if ($tache['Tache']['statut'] == 0) {
                if (count($tache['Desktop']) == 1) {
                    if (in_array($tache['Desktop'][0]['id'], $userDesktops)) {
                        $tache['canValid'] = true;
                    }
                } else if (count($tache['Desktop'] > 1)) {
                    foreach ($tache['Desktop'] as $dktp) {
                        if (in_array($dktp['id'], $userDesktops)) {
                            $tache['canGrab'] = true;
                        }
                    }
                }
            } else if ($tache['Tache']['statut'] == 1) {
                if (in_array($tache['Tache']['act_desktop_id'], $userDesktops)) {
                    $tache['canValid'] = true;
                    $tache['canRelease'] = true;
                }
            }

            if ($retard) {
                array_unshift($taches, $tache);
            } else {
                array_push($taches, $tache);
            }
        }
        $this->set('taches', $taches);
        $this->set('userDesktops', $userDesktops);
        $this->set('viewOnly', $this->Session->read('Auth.User.Courrier.viewOnlyTabs.getTache'));
    }

    /**
     * Accès à l'onglet "Dossiers/Affaires" (ajax)
     *
     * @logical-group Flux
     * @logical-group Visualisation d'un flux
     * @user-profile User
     *
     * @access public
     * @param integer $fluxId identifiant du flux

     * @throws NotFoundException
     * @return void
     */
    public function getAffaire($fluxId) {
//		if (!is_integer($fluxId) || $fluxId <= 0) {
//			throw new BadMethodCallException();
//		}

        $querydata = array(
            'contain' => array(
                'Affaire' => array(
                    'Dossier'
                )
            ),
            'conditions' => array(
                'Courrier.id' => $fluxId
            )
        );
        $courrier = $this->Courrier->find('first', $querydata);

        if (!empty($courrier)) {
            $this->set('courrier', $courrier);
            $this->set('viewOnly', $this->Session->read('Auth.User.Courrier.viewOnlyTabs.getAffaire'));
        } else {
            throw new NotFoundException();
        }
    }

    /**
     * Accès à l'onglet "Informations" (ajax)
     *
     * @logical-group Flux
     * @logical-group Création d'un flux
     * @user-profile User
     *
     * @access public
     * @return void
     */
    public function createInfos() {
        if (!empty($this->request->data)) {
            $this->Courrier->begin();

            $valid = false;
            
            $desktopCreatorId = $this->Session->read('Auth.User.Courrier.Desktop.id');
            
            $secondaryDesktops = $this->Session->read('Auth.User.SecondaryDesktops');
            $groupId = Hash::extract($secondaryDesktops, '{n}.Group.id');
            $desktopId = Hash::extract($secondaryDesktops, '{n}.id');
            // Si le bureau secondaire est de type Valideur Editeur, Valideur ou Documentaliste
            if ( in_array( $groupId, array( 3 ) ) ) {
                $desktopCreatorId = $desktopId;
            }

            $this->request->data['Courrier']['user_creator_id'] = $this->Session->read('Auth.User.id');
            $this->request->data['Courrier']['desktop_creator_id'] = $desktopCreatorId;
            $this->request->data['Courrier']['service_creator_id'] = $this->Session->read('Auth.User.Courrier.Service.id');

if( in_array( $this->request->data['Courrier']['desktop_creator_id'], array( 95, 96) ) ) {
      $this->log( 'Mme Jolly : ', LOG_ERROR );
      $this->log( $this->Session->read('Auth.User.Courrier'), LOG_ERROR );
}

            if (empty($this->request->data['Courrier']['reference'])) {
//                $this->request->data['Courrier']['reference'] = $this->Courrier->genRef($this->request->data['Courrier']['soustype_id']);
                $this->request->data['Courrier']['reference'] = $this->Courrier->genRef2($this->request->data);
            }
            if (!empty($this->request->data['Courrier']['soustype_id'])) {
                $this->request->data['Courrier']['direction'] = $this->Courrier->Soustype->field('Soustype.entrant', array('Soustype.id' => $this->request->data['Courrier']['soustype_id']));
            }
            if (!isset($this->request->data['Courrier']['contact_id']) || empty($this->request->data['Courrier']['contact_id'])) {
                $this->request->data['Courrier']['contact_id'] = Configure::read('Sanscontact.id');
            }
//si champ datereception/date est vide(version 2.0)
            if (empty($this->request->data['Courrier']['datereception'])) {
                $this->request->data['Courrier']['datereception'] = date("d/m/y");
            }

            if (empty($this->request->data['Courrier']['date'])) {
                $this->request->data['Courrier']['date'] = date("d/m/y");
            }

///
            if (!empty($this->request->data['Courrier']['ContactId'])) {
                $org = $this->Courrier->Organisme->find('first', array(
                    'conditions' => array(
                        'Organisme.id' => $this->request->data['Courrier']['ContactId'],
                        'Organisme.name' => $this->request->data['Courrier']['ContactName'],
                        'Organisme.active' => true
                    ),
                    'recursive' => -1
                ));
                if (!empty($org)) {
                    $this->request->data['Courrier']['typecontact'] = 'organisme';
                    $this->request->data['Courrier']['organisme_id'] = $this->request->data['Courrier']['ContactId'];
                    $this->request->data['Courrier']['contact'] = $this->request->data['Courrier']['contact'];
                } else {
                    $this->request->data['Courrier']['typecontact'] = 'citoyen';
                    $this->request->data['Courrier']['contact'] = $this->request->data['Courrier']['contact'];
                }
            }
            
            // Ajouté pour la ville d'Angoulême
            if( in_array( $this->request->data['Courrier']['desktop_creator_id'], array( 95, 96) ) ) {
                $this->log( 'Mme Jolly : ', LOG_ERROR );
                $this->log( $this->request->data, LOG_ERROR );
            }
            
            $this->Courrier->create($this->request->data);
            $saved = $this->Courrier->save();
            
            // on stocke qui à fait quoi quand
//            $this->log( "L'utilisateur ". $this->Session->read('Auth.User.username')." (".$this->request->data['Courrier']['desktop_creator_id'].") a créé le flux ".$this->request->data['Courrier']['reference']." le ".date('d-M-Y à H:i:s'), LOG_WARNING );

            $this->loadModel('Journalevent');
            $datasSession = $this->Session->read('Auth.User');
            $msg = "L'utilisateur ". $this->Session->read('Auth.User.username')." (".$this->request->data['Courrier']['desktop_creator_id'].") a créé le flux ".$this->request->data['Courrier']['reference']." le ".date('d/m/Y à H:i:s');
            $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $this->request->data);
                
            if (!empty($saved)) {
                $newCourrierId = $this->Courrier->id;

                // SAERP
                if (Configure::read('Conf.SAERP')) {
                    if (!empty($this->request->data['Courrier']['marche_id'])) {
                        if ($this->request->data['Courrier']['typedocument'] == 'OS' /* && $this->request->data['Courrier']['direction'] == '0' */) {
                            $this->request->data['Ordreservice']['marche_id'] = $this->request->data['Courrier']['marche_id'];
                            if($this->request->data['Courrier']['direction'] == '0' ) {
                                $this->request->data['Ordreservice']['name'] = $this->request->data['Ordreservice']['numero'];
                            }
                            else {
                                $this->request->data['Ordreservice']['name'] = $this->request->data['Ordreservice']['numero'] = ' ';
                            }
                            $this->request->data['Ordreservice']['organisme_id'] = $this->request->data['Courrier']['organisme_id'];
                            $this->request->data['Ordreservice']['courrier_id'] = $newCourrierId;
                            $this->Courrier->Marche->Ordreservice->create();
                            $this->Courrier->Marche->Ordreservice->save($this->request->data['Ordreservice']);
                        }
                    }
                    if (!empty($this->request->data['Courrier']['consultation_id'])) {
                        if ($this->request->data['Courrier']['typedocument'] == 'PLI') {
                            $consultation = $this->Courrier->Consultation->find('first', array(
                                'conditions' => array(
                                    'Consultation.id' => $this->request->data['Courrier']['consultation_id']
                                ),
                                'contain' => false
                            ));
                            $this->request->data['Pliconsultatif']['consultation_id'] = $this->request->data['Courrier']['consultation_id'];


                            $this->request->data['Pliconsultatif']['name'] = $consultation['Consultation']['numero'] . ' - ' . $this->request->data['Pliconsultatif']['numero'];
                            $this->request->data['Pliconsultatif']['courrier_id'] = $newCourrierId;
                            if (!empty($this->request->data['Courrier']['organisme_id'])) {
                                $this->request->data['Pliconsultatif']['organisme_id'] = $this->request->data['Courrier']['organisme_id'];
                            }
                            $this->Courrier->Consultation->Pliconsultatif->create();
                            $this->Courrier->Consultation->Pliconsultatif->save($this->request->data['Pliconsultatif']);
                        }
                    }
                }

                if ($this->Courrier->Bancontenu->add($this->Session->read('Auth.User.Courrier.Desktop.id'), BAN_DOCS, $newCourrierId, true)) {
                    $valid = true;
                }
            }

            if ($valid) {

                $this->Jsonmsg->valid(__d('courrier', 'Courrier.create_ok'));
                $this->Jsonmsg->json['newCourrierId'] = $newCourrierId;
                $this->Jsonmsg->json['debug'] = $saved;
                $this->Courrier->commit();
            } else {
                $this->Courrier->rollback();
            }

            $this->Jsonmsg->send();
        } else {
            $users = $this->Courrier->Desktop->User->find(
                'all',
                array(
                    'contain' => false,
                    'recursive' => -1,
                    'contain' => array(
                        'Desktop'
                    ),
                    'order' => 'User.nom ASC'
                )
            );
            foreach( $users as $user) {
                $allDesktops[$user['Desktop']['id']] = $user['User']['nom'].' '.$user['User']['prenom'];
            }
            
//            $allDesktops = $this->Courrier->Desktop->getDesktopsByService('all');
//            ksort($allDesktops);
            $this->set('allDesktops', $allDesktops);
            $this->set('isInCircuit', false);
            if (Configure::read('Use.AuthRights') && !Configure::read('Conf.SAERP')) {
//                $this->set('types', $this->DataAuthorized->getAuthTypes(array('withSoustypes' => true)));
                $types = $this->DataAuthorized->getAuthTypes(array('withSoustypes' => true));
                $newTypes = Hash::map($types, "{n}", array($this, '__getType'));
                $newSoustypes = Hash::map($types, "{n}", array($this, '__getSousType'));
                foreach ($newTypes as $key => $value) {
                    $typeOptions[$value['id']] = $value['name'];
                }
                foreach ($newSoustypes as $key => $value) {
                    if (isset($value) && !empty($value)) {
                        $soustype = array();
                        foreach ($value as $keySoustype => $valueSoustype) {
                            $soustype[$valueSoustype['id']] = $valueSoustype['name'];
                        }
                        if (!empty($value[0])) {
                            $soustypeOptions[$value[0]['type_id']] = $soustype;
                        }
                    }
                }
                $this->set('typeOptions', $typeOptions);
                $this->set('soustypeOptions', $soustypeOptions);
            } else {
//                $this->set('types', $this->Courrier->Soustype->Type->find('all', array('contain' => array('Soustype' => array('conditions' => array('Soustype.active' => true), 'order' => 'Soustype.name ASC')), 'order' => array('Type.name ASC'), 'conditions' => array('Type.active' => 1), 'recursive' => -1)));
                $types = $this->Courrier->Soustype->Type->find('all', array('contain' => array('Soustype' => array('conditions' => array('Soustype.active' => true), 'order' => 'Soustype.name ASC')), 'order' => array('Type.name ASC'), 'conditions' => array('Type.active' => 1), 'recursive' => -1));
                $newTypes = Hash::map($types, "{n}", array($this, '__getType'));
                $newSoustypes = Hash::map($types, "{n}", array($this, '__getSousType'));
                foreach ($newTypes as $key => $value) {
                    $typeOptions[$value['id']] = $value['name'];
                }
                foreach ($newSoustypes as $key => $value) {
                    if (isset($value) && !empty($value)) {
                        $soustype = array();
                        foreach ($value as $keySoustype => $valueSoustype) {
                            $soustype[$valueSoustype['id']] = $valueSoustype['name'];
                        }
                        $soustypeOptions[$value[0]['type_id']] = $soustype;
                    }
                }
                $this->set('typeOptions', $typeOptions);
                $this->set('soustypeOptions', $soustypeOptions);
//                $this->set('types', $this->Courrier->Soustype->Type->find('list', array('order' => array('Type.name ASC'), 'conditions' => array('Type.active' => 1), 'recursive' => -1)));
            }

            $this->set('contactname', !empty($this->request->data['Contact']) ? $this->request->data['Contact']['name'] : "");
            $this->set('origineflux', $this->Courrier->Origineflux->find('list', array('conditions' => array('Origineflux.active' => true), 'order' => array('Origineflux.name ASC'))));

            // Informations sur les organismes
            $organismes = $this->Courrier->Organisme->find('all', array(
                'conditions' => array('Organisme.active' => true),
                'order' => array('Organisme.name ASC'),
                'contain' => array(
                    'Contact' => array(
                        'conditions' => array('Contact.active' => true),
                        'order' => 'Contact.nom ASC'
                    )
                )
            ));
            $newOrganismes = Hash::map($organismes, "{n}", array($this, '__getOrganisme'));
            $newContacts = Hash::map($organismes, "{n}", array($this, '__getContact'));
            foreach ($newOrganismes as $key => $value) {
                if( Configure::read('Conf.SAERP') ) {
                    $organismOptions[$value['id']] = $value['name'].' ('.$value['ville'].') ';
                }
                else {
                    $organismOptions[$value['id']] = $value['name'];
                }
            }

            foreach ($newContacts as $key => $value) {
                if (isset($value) && !empty($value)) {
                    $contact = array();
                    foreach ($value as $keyContact => $valueContact) {
                        $contact[$valueContact['id']] = $valueContact['nom'] . ' ' . $valueContact['prenom'];
                        if( $valueContact['nom'] == '0Sans contact') {
                            $contact[$valueContact['id']] = $valueContact['name'];
                        }
                    }
                    $contactOptions[$value[0]['organisme_id']] = $contact;
                }
            }
            $this->set('organismOptions', $organismOptions);
            $this->set('contactOptions', $contactOptions);






// Valeur de l'organisme par défaut
            $this->set('sansOrganisme', Configure::read('Sansorganisme.id'));
// Valeur du contact par défaut
            $this->set('sansContact', Configure::read('Sanscontact.id'));



            $organisme = $this->Courrier->Organisme->find('first', array(
                'fields' => array_merge(
                        $this->Courrier->Organisme->fields(), $this->Courrier->Organisme->Ban->fields(), $this->Courrier->Organisme->Bancommune->fields()
                ),
                'conditions' => array(
                    'Organisme.id' => Configure::read('Sansorganisme.id'),
                    'Organisme.active' => true
                ),
                'joins' => array(
                    $this->Courrier->Organisme->join('Ban', array('type' => 'LEFT OUTER')),
                    $this->Courrier->Organisme->join('Bancommune', array('type' => 'LEFT OUTER'))
                ),
                'contain' => false,
                'recursive' => -1
            ));
//debug($organisme);
            $return = array();
            if (!empty($organisme)) {
                $oInfos = array();
                foreach ($organisme['Organisme'] as $key => $val) {
                    if ($val != '' && $val != 'active' && $key != 'addressbook_id' && $key != 'ban_id' && $key != 'bancommune_id') {
                        $oInfos[$key != 'id' ? __d('organisme', 'Organisme.' . $key) : $key] = $val;
                    }
                }

                $bInfos = array();
                foreach ($organisme['Ban'] as $key => $val) {
                    if ($val != '' && $val != 'active' && $key != 'created' && $key != 'modified') {
                        $bInfos[$key != 'id' ? __d('ban', 'Ban.' . $key) : $key] = $val;
                    }
                }
                $bcInfos = array();
                foreach ($organisme['Bancommune'] as $key => $val) {
                    if ($val != '' && $val != 'active' && $key != 'created' && $key != 'modified' && $key != 'ban_id') {
                        $bcInfos[$key != 'id' ? __d('bancommune', 'Bancommune.' . $key) : $key] = $val;
                    }
                }
//debug($oInfos);
                $organismeTreated = array(
                    'Organisme' => ( $oInfos + $bInfos + $bcInfos)
                );
                $this->set('organismeTreated', $organismeTreated);
            }

            if (Configure::read('Conf.SAERP')) {
                $marches_tmp = $this->Courrier->Marche->find(
                    'all',
                    array(
                        'joins' => array(
                            $this->Courrier->Marche->join('Operation')
                        ),
                        'conditions' => array(
                            'Marche.active' => true,
                            'Operation.active' => true
                        ),
                        'fields' => array(
                            'Marche.id',
                            'Marche.numero',
                            'Marche.titulaire'
                        ),
                        'contain' => false,
                        'order' => array('Marche.name ASC')
                    )
                );  
                foreach( $marches_tmp as $m => $values) {
                    $marches[$values['Marche']['id']] = $values['Marche']['numero']." - ".$values['Marche']['titulaire'];
                }
                $this->set(compact('marches'));

                $typesdocument = array(
                    'OS' => 'Ordre de service',
                    'LN' => 'Lettre de notification',
                    'LC' => 'Lettre de commandes',
                    'PLI' => 'Pli'
                );
                $this->set(compact('typesdocument'));
                $marcheconsult = array(
                    'marche' => 'Marché',
                    'consultation' => 'Consultation',
                    'none' => 'Aucun des deux'
                );
                $this->set(compact('marcheconsult'));

                $consultations = $this->Courrier->Consultation->find('list', array(
                    'joins' => array(
                        $this->Courrier->Consultation->join('Operation')
                    ),
                    'conditions' => array(
                        'Consultation.active' => true,
                        'Operation.active' => true
                    ),
                    'fields' => array(
                        'Consultation.numero'
                    ),
                    'order' => array('Consultation.name ASC')
                ));
                $this->set(compact('consultations'));
            }
        }

        $conn = $this->Session->read('Auth.User.connName');
        $this->loadModel('Collectivite');
        $this->set('collectivite', $this->Collectivite->find('first', array('conditions' => array('Collectivite.conn' => $conn))));
//        debug($this->request->data);
    }

    /**
     * Accès à l'onglet "Informations" (ajax)
     *
     * @logical-group Flux
     * @logical-group Edition d'un flux
     * @user-profile User
     *
     * @access public
     * @param integer $id identifiant du flux
     * @return void
     */
    public function setInfos($id = null) {
//enregistrement des données
        if (!empty($this->request->data)) {
            $msg = 'Onglet ' . __d('courrier', 'Informations') . ' : ';
            $this->Jsonmsg->init($msg . __d('default', 'save.error'));

            if (empty($this->request->data['Courrier']['reference'])) {
                $this->request->data['Courrier']['reference'] = $this->Courrier->genRef2($this->request->data);
            }
            if (!empty($this->request->data['Courrier']['soustype_id'])) {
                $this->request->data['Courrier']['direction'] = $this->Courrier->Soustype->field('Soustype.entrant', array('Soustype.id' => $this->request->data['Courrier']['soustype_id']));
            }
            if (!empty($this->request->data['Courrier']['objet'])) {
                $this->request->data['Courrier']['objet'] = str_replace(array("<p>", "</p>", "<br />"), "\t", quoted_printable_decode($this->request->data['Courrier']['objet']));
            }
//debug( $this->request->data);
//die();
// SAERP
            if (Configure::read('Conf.SAERP')) {
                if (!empty($this->request->data['Courrier']['marche_id'])) {
                    $courrier = $this->Courrier->find(
                            'first', array(
                        'conditions' => array(
                            'Courrier.id' => $id
                        ),
                        'contain' => false
                            )
                    );
                    $direction = $courrier['Courrier']['direction'];
                    $ordreservice = $this->Courrier->Ordreservice->find(
                            'first', array(
                        'conditions' => array(
                            'Ordreservice.courrier_id' => $id
                        ),
                        'contain' => false
                            )
                    );

                    if ($this->request->data['Courrier']['typedocument'] == 'OS' /* && $direction == '0' */) {
                        if (empty($ordreservice['Ordreservice']['id'])) {
                            $this->request->data['Ordreservice']['marche_id'] = $this->request->data['Courrier']['marche_id'];
                            if( $direction == '0' ) {
                                $this->request->data['Ordreservice']['name'] = $this->request->data['Ordreservice']['numero'];
                            }
                            else {
                                $this->request->data['Ordreservice']['name'] = $this->request->data['Ordreservice']['numero'] = ' ';
                            }
//                            $this->request->data['Ordreservice']['name'] = $this->request->data['Ordreservice']['numero'];
                            $this->request->data['Ordreservice']['organisme_id'] = $this->request->data['Courrier']['organisme_id'];
                            //                        $this->request->data['Ordreservice']['courrier_id'] = $id;
                            $this->request->data['Ordreservice']['courrier_id'] = $this->request->data['Courrier']['id'];
                            $this->Courrier->Marche->Ordreservice->create();
                            $this->Courrier->Marche->Ordreservice->save($this->request->data['Ordreservice']);
                        } else {
                            $this->request->data['Ordreservice']['marche_id'] = $this->request->data['Courrier']['marche_id'];
                            if( $direction == '0' ) {
                                $this->request->data['Ordreservice']['name'] = $this->request->data['Ordreservice']['numero'];
                            }
                            else {
                                $this->request->data['Ordreservice']['name'] = $this->request->data['Ordreservice']['numero'] = ' ';
                            }
//                            $this->request->data['Ordreservice']['name'] = $ordreservice['Ordreservice']['numero'];
                            $this->request->data['Ordreservice']['organisme_id'] = $this->request->data['Courrier']['organisme_id'];
                            $this->request->data['Ordreservice']['courrier_id'] = $id;
                            $this->request->data['Ordreservice']['id'] = $ordreservice['Ordreservice']['id'];
                            $this->Courrier->Marche->Ordreservice->save($this->request->data['Ordreservice']);
                        }
                    }
                }
                if (!empty($this->request->data['Courrier']['consultation_id'])) {
                    if ($this->request->data['Courrier']['typedocument'] == 'PLI') {
                        $consultation = $this->Courrier->Consultation->find(
                                'first', array(
                            'conditions' => array(
                                'Consultation.id' => $this->request->data['Courrier']['consultation_id']
                            ),
                            'contain' => false
                                )
                        );
                        $this->request->data['Pliconsultatif']['consultation_id'] = $this->request->data['Courrier']['consultation_id'];


                        $this->request->data['Pliconsultatif']['name'] = $consultation['Consultation']['numero'] . ' - ' . $this->request->data['Pliconsultatif']['numero'];
                        $this->request->data['Pliconsultatif']['courrier_id'] = $id;
//                        $this->request->data['Pliconsultatif']['courrier_id'] = $this->request->data['Courrier']['id'];
                        if (!empty($this->request->data['Courrier']['organisme_id'])) {
                            $this->request->data['Pliconsultatif']['organisme_id'] = $this->request->data['Courrier']['organisme_id'];
                        }
//debug($this->request->data);
//die();
                        $this->Courrier->Consultation->Pliconsultatif->create();
                        $this->Courrier->Consultation->Pliconsultatif->save($this->request->data['Pliconsultatif']);
                    }
                }
            }
           
            // si l'admin modifie le bancontenu pour repositionner le flux
            if( !empty( $this->request->data['Bancontenu']['desktop_id'] ) ) {
                $this->Courrier->repositionneFlux( $this->request->data['Courrier']['id'], $this->request->data['Bancontenu']['desktop_id']);
            }

            $this->Courrier->create($this->request->data);
            if ($this->Courrier->save()) {
                
                // on stocke qui à fait quoi quand
//                $this->log( "L'utilisateur ". $this->Session->read('Auth.User.username')." (".$this->Session->read('Auth.User.Courrier.Desktop.id').") a modifié le flux ".$this->request->data['Courrier']['reference']." le ".date('d/m/Y à H:i:s'), LOG_WARNING );
                
                $this->loadModel('Journalevent');
                $datasSession = $this->Session->read('Auth.User');
                $msg = "L'utilisateur ". $this->Session->read('Auth.User.username')." a modifié le flux ".$this->request->data['Courrier']['reference']." le ".date('d/m/Y à H:i:s');
                $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $this->request->data);
                
                // En cas de modification d'une information sur le flux, on met à jour la date de modification de la table bancontenus pour le profil étant intervenu
                $this->Courrier->Bancontenu->updateAll(
                    array(
                        'Bancontenu.modified' => "'".date( 'Y-m-d H:i:s')."'"
                    ),
                    array(
                        'Bancontenu.courrier_id' => $this->request->data['Courrier']['id'],
                        'Bancontenu.desktop_id' =>  $this->Session->read('Auth.User.Courrier.Desktop.id')
                    )
                );

                $this->Jsonmsg->valid($msg . __d('default', 'save.ok'));
            }
            $isInCircuit = $this->Courrier->isInCircuit($this->request->data['Courrier']['id']);
            
            $this->Jsonmsg->json['loadContext'] = 'reload';
            $this->Jsonmsg->json['newCourrierId'] = $id;
            if( !$isInCircuit ) {
                $this->Jsonmsg->json['newCourrierDelaiNb'] = $this->Courrier->Soustype->field('Soustype.delai_nb', array('Soustype.id' => $this->request->data['Courrier']['soustype_id']));
                $this->Jsonmsg->json['newCourrierDelaiUnite'] = $this->Courrier->Soustype->field('Soustype.delai_unite', array('Soustype.id' => $this->request->data['Courrier']['soustype_id']));
                $this->Jsonmsg->json['newCourrierSoustypeSens'] = $this->Courrier->Soustype->field('Soustype.entrant', array('Soustype.id' => $this->request->data['Courrier']['soustype_id']));
            }
            else {
                $this->Jsonmsg->json['newCourrierSoustypeSens'] = 'empty';
            }
            $this->Jsonmsg->send();
        } else {
            $qd = array(
                'fields' => array_merge(
                    $this->Courrier->fields(),
                    $this->Courrier->Organisme->fields(),
                    $this->Courrier->Soustype->fields(),
                    $this->Courrier->Soustype->Type->fields()
                ),
                'conditions' => array(
                    'Courrier.id' => $id
                ),
                'joins' => array(
                    $this->Courrier->join('Organisme', array('type' => 'LEFT OUTER')),
                    $this->Courrier->join('Soustype', array('type' => 'LEFT OUTER')),
                    $this->Courrier->Soustype->join('Type', array('type' => 'LEFT OUTER'))
                ),
                'recursive' => -1,
                'contain' => false
            );
            
            if( Configure::read('Conf.SAERP') ) {
                $qd['fields'] = array_merge(
                    $qd['fields'],
                    $this->Courrier->Marche->fields(),
                    $this->Courrier->Marche->Ordreservice->fields(),
                    $this->Courrier->Consultation->Pliconsultatif->fields()
                );
                $qd['joins'] = array_merge(
                    $qd['joins'],
                    array(
                        $this->Courrier->join('Marche', array('type' => 'LEFT OUTER')),
                        $this->Courrier->join('Consultation', array('type' => 'LEFT OUTER')),
                        $this->Courrier->join('Ordreservice', array('type' => 'LEFT OUTER')),
                        $this->Courrier->join('Pliconsultatif', array('type' => 'LEFT OUTER'))
                    )
                );
            }

            $this->request->data = $this->Courrier->find('first', $qd);

            $contactinfosTreated = array();
            $organismeTreated = array();

            if (!empty($this->request->data['Courrier']['organisme_id'])) {
                $organisme = $this->Courrier->Organisme->find(
                    'first',
                    array(
                        'fields' => array_merge(
                                $this->Courrier->Organisme->fields(), $this->Courrier->Organisme->Ban->fields(), $this->Courrier->Organisme->Bancommune->fields()
                        ),
                        'conditions' => array(
                            'Organisme.id' => $this->request->data['Courrier']['organisme_id'],
                            'Organisme.active' => true
                        ),
                        'joins' => array(
                            $this->Courrier->Organisme->join('Ban', array('type' => 'LEFT OUTER')),
                            $this->Courrier->Organisme->join('Bancommune', array('type' => 'LEFT OUTER'))
                        ),
                        'contain' => false,
                        'recursive' => -1
                    )
                );
//debug($organisme);
                $return = array();
                if (!empty($organisme)) {
                    $oInfos = array();
                    foreach ($organisme['Organisme'] as $key => $val) {
                        if ($val != '' && $val != 'active' && $key != 'addressbook_id' && $key != 'ban_id' && $key != 'bancommune_id') {
                            $oInfos[$key != 'id' ? __d('organisme', 'Organisme.' . $key) : $key] = $val;
                        }
                    }

                    $bInfos = array();
                    foreach ($organisme['Ban'] as $key => $val) {
                        if ($val != '' && $val != 'active' && $key != 'created' && $key != 'modified') {
                            $bInfos[$key != 'id' ? __d('ban', 'Ban.' . $key) : $key] = $val;
                        }
                    }
                    $bcInfos = array();
                    foreach ($organisme['Bancommune'] as $key => $val) {
                        if ($val != '' && $val != 'active' && $key != 'created' && $key != 'modified' && $key != 'ban_id') {
                            $bcInfos[$key != 'id' ? __d('bancommune', 'Bancommune.' . $key) : $key] = $val;
                        }
                    }
//debug($oInfos);
                    $organismeTreated = array(
                        'Organisme' => ( $oInfos + $bInfos + $bcInfos)
                    );
                }
            }

            if (!empty($this->request->data['Courrier']['contact_id'])) {
                $contact = $this->Courrier->Contact->find(
                    'first',
                    array(
                        'fields' => array_merge(
                                $this->Courrier->Contact->fields(), $this->Courrier->Contact->Ban->fields(), $this->Courrier->Contact->Bancommune->fields()
                        ),
                        'conditions' => array(
                            'Contact.id' => $this->request->data['Courrier']['contact_id'],
                            'Contact.active' => true
                        ),
                        'joins' => array(
                            $this->Courrier->Contact->join('Ban', array('type' => 'LEFT OUTER')),
                            $this->Courrier->Contact->join('Bancommune', array('type' => 'LEFT OUTER'))
                        ),
                        'contain' => false,
                        'recursive' => -1
                    )
                );

                if (!empty($contact)) {
                    $cInfos = array();
                    $civiliteOptions = array(
                        '1' => 'Monsieur',
                        '2' => 'Madame',
                        '3' => 'Monsieur et Madame'
                    );
                    foreach ($contact['Contact'] as $key => $val) {
                        if ($val != '' && $val != 'active' && $val != 'addressbook_id' && $key != 'organisme_id' && $key != 'organisme_name' && $key != 'carnet_name' && $key != 'ville' && $key != 'ban_id' && $key != 'bancommune_id') {
                            if ($key == 'civilite') {
                                $cInfos['civilite'] = $civiliteOptions[$val];
                            } else {
                                $cInfos[$key != 'id' && $key != 'name' ? __d('contact', 'Contact.' . $key) : $key] = $val;
                            }
                        }
                    }

                    $cbInfos = array();
                    foreach ($contact['Ban'] as $key => $val) {
                        if ($val != '' && $val != 'active' && $key != 'created' && $key != 'modified') {
                            $cbInfos[$key != 'id' ? __d('ban', 'Ban.' . $key) : $key] = $val;
                        }
                    }
                    $cbcInfos = array();
                    foreach ($contact['Bancommune'] as $key => $val) {
                        if ($val != '' && $val != 'active' && $key != 'created' && $key != 'modified' && $key != 'ban_id') {
                            $cbcInfos[$key != 'id' ? __d('bancommune', 'Bancommune.' . $key) : $key] = $val;
                        }
                    }
//debug($contact);
                    if (Configure::read('Conf.SAERP')) {
                        if (!empty($contact['Contact']['observations'])) {
                            $cInfos['Observations'] = preg_replace("/[\n\r]/", "", $contact['Contact']['observations']);
                        }
                        if (!empty($contact['Contact']['fonction_id'])) {
                            $fonctions = $this->Courrier->Organisme->Contact->Fonction->find('list', array('order' => array('Fonction.name ASC'), 'conditions' => array('Fonction.active' => true), 'recursive' => -1));
                            $cInfos['Fonction'] = Hash::get($fonctions, $contact['Contact']['fonction_id']);
                        }
                    }
                    $contactinfosTreated = array(
                        'Contactinfo' => ( $cInfos + $cbInfos + $cbcInfos )
                    );
                }
            }
//            debug($contactinfosTreated);
            $this->set('organismeid', !empty($this->request->data['Courrier']['organisme_id']) ? $this->request->data['Courrier']['organisme_id'] : "");
            $this->set('contactid', !empty($this->request->data['Courrier']['contact_id']) ? $this->request->data['Courrier']['contact_id'] : "");
            
            $this->set('soustypeid', !empty($this->request->data['Courrier']['soustype_id']) ? $this->request->data['Courrier']['soustype_id'] : "");

            if (!empty($this->request->data['Courrier']['soustype_id'])) {
                $type = $this->Courrier->Soustype->find(
                        'first', array(
                    'conditions' => array(
                        'Soustype.id' => $this->request->data['Courrier']['soustype_id']
                    ),
                    'contain' => false
                        )
                );
                $typeId = $type['Soustype']['type_id'];
                $this->set('typeId', $typeId);
            }

            $this->set('contactinfos', $contactinfosTreated);
            $this->set('organismeinfos', $organismeTreated);
            $isInCircuit = $this->Courrier->isInCircuit($this->request->data['Courrier']['id']);
            $this->set('isInCircuit', $isInCircuit);
            // Si on n'est aps en mode SAERP et que le flux n'est pas  encore inséré
            if (Configure::read('Use.AuthRights') && !Configure::read('Conf.SAERP') && !$isInCircuit) {
                $types = $this->DataAuthorized->getAuthTypes(array('withSoustypes' => true));
                $newTypes = Hash::map($types, "{n}", array($this, '__getType'));
                $newSoustypes = Hash::map($types, "{n}", array($this, '__getSousType'));
                foreach ($newTypes as $key => $value) {
                    $typeOptions[$value['id']] = $value['name'];
                }

                foreach ($newSoustypes as $key => $value) {
                    if (isset($value) && !empty($value)) {
                        $soustype = array();
                        foreach ($value as $keySoustype => $valueSoustype) {
                            $soustype[$valueSoustype['id']] = $valueSoustype['name'];
                        }
                        if (!empty($value[0])) {
                            $soustypeOptions[$value[0]['type_id']] = $soustype;
                        }
                    }
                }
                $this->set('typeOptions', $typeOptions);
                $this->set('soustypeOptions', $soustypeOptions);
            }
            // si on est dans le cas de la SAERP
            else if(Configure::read('Conf.SAERP') && !$isInCircuit ) {
                $types = $this->Courrier->Soustype->Type->find('all', array('contain' => array('Soustype' => array('conditions' => array('Soustype.active' => true), 'order' => 'Soustype.name ASC')), 'order' => array('Type.name ASC'), 'conditions' => array('Type.active' => 1), 'recursive' => -1));
                $newTypes = Hash::map($types, "{n}", array($this, '__getType'));
                $newSoustypes = Hash::map($types, "{n}", array($this, '__getSousType'));
                foreach ($newTypes as $key => $value) {
                    $typeOptions[$value['id']] = $value['name'];
                }

                foreach ($newSoustypes as $key => $value) {
                    if (isset($value) && !empty($value)) {
                        $soustype = array();
                        foreach ($value as $keySoustype => $valueSoustype) {
                            $soustype[$valueSoustype['id']] = $valueSoustype['name'];
                        }
                        $soustypeOptions[$value[0]['type_id']] = $soustype;
                    }
                }
                $this->set('typeOptions', $typeOptions);
                $this->set('soustypeOptions', $soustypeOptions);
            }
            // sinon le flux est dans un circuit alors on cherche les infos deuis le sous-type déjà associé au flux
            else {
                $soustype = $this->Courrier->Soustype->find(
                    'first',
                    array(
                        'fields' => array_merge(
                            $this->Courrier->Soustype->fields(),
                            $this->Courrier->Soustype->Type->fields()
                        ),
                        'conditions' => array(
                            'Soustype.id' => $this->request->data['Courrier']['soustype_id']
                        ),
                        'joins' => array(
                            $this->Courrier->Soustype->join('Type')
                        ),
                        'recursive' => -1,
                        'contain' => false
                    )
                );
//debug($soustype);
                $typeOptions[$soustype['Soustype']['type_id']] = $soustype['Type']['name'];
                $soustypeSelected[$soustype['Soustype']['id']] = $soustype['Soustype']['name'];
                $soustypeOptions[$soustype['Soustype']['type_id']] = $soustypeSelected;
                $this->set('typeOptions', $typeOptions);
                $this->set('soustypeOptions', $soustypeOptions);
                
            }


            $users = $this->Courrier->Desktop->User->find(
                'all',
                array(
                    'contain' => false,
                    'recursive' => -1,
                    'contain' => array(
                        'Desktop'
                    ),
                    'order' => 'User.nom ASC'
                )
            );
            foreach( $users as $user) {
                $allDesktops[$user['Desktop']['id']] = $user['User']['nom'].' '.$user['User']['prenom'];
            }            
//            $allDesktops = $this->Courrier->Desktop->getDesktopsByService('all');
//            ksort($allDesktops);
//debug($allDesktops);
            $this->set('allDesktops', $allDesktops);            
            $this->set('origineflux', $this->Courrier->Origineflux->find('list', array('conditions' => array('Origineflux.active' => true), 'order' => array('Origineflux.name ASC'))));

// Liste des bureaux en copie
            $desktopsCopie = array();
            if (!empty($id)) {
                $desktopsCopie = $this->Courrier->Bancontenu->find(
                        'all', array(
                    'conditions' => array(
                        'Bancontenu.courrier_id' => $id,
                        'Bancontenu.bannette_id' => BAN_COPY
                    ),
                    'contain' => array(
                        'Desktop'
                    ),
                    'recursive' => -1,
                    'order' => 'Bancontenu.created ASC'
                        )
                );
            }
//debug($desktopsCopie);
            $this->set('desktopsCopie', $desktopsCopie);
        }
        $this->set('envactuel', $this->Session->read('Auth.User.Env.actual.name'));

        // Select pour les organismes et les contacts
        $organismes = $this->Courrier->Organisme->find('all', array(
            'conditions' => array('Organisme.active' => true),
            'order' => array('Organisme.name ASC'),
            'contain' => array(
                'Contact' => array(
                    'conditions' => array('Contact.active' => true),
                    'order' => 'Contact.nom ASC'
                )
            )
        ));
        $newOrganismes = Hash::map($organismes, "{n}", array($this, '__getOrganisme'));
        $newContacts = Hash::map($organismes, "{n}", array($this, '__getContact'));
        foreach ($newOrganismes as $key => $value) {
            if( Configure::read('Conf.SAERP') ) {
                $organismOptions[$value['id']] = $value['name'].' ('.$value['ville'].') ';
            }
            else {
                $organismOptions[$value['id']] = $value['name'];
            }
        }
        
        foreach ($newContacts as $key => $value) {
            if (isset($value) && !empty($value)) {
                $contact = array();
                foreach ($value as $keyContact => $valueContact) {
                    $contact[$valueContact['id']] = $valueContact['nom'] . ' ' . $valueContact['prenom'];
                    if( $valueContact['nom'] == '0Sans contact') {
                        $contact[$valueContact['id']] = $valueContact['name'];
                    }
                }
                $contactOptions[$value[0]['organisme_id']] = $contact;
            }
        }
        $this->set('organismOptions', $organismOptions);
        $this->set('contactOptions', $contactOptions);

        // Valeur de l'organisme par défaut
        $this->set('sansOrganisme', Configure::read('Sansorganisme.id'));

        // Valeur du contact par défaut
        $this->set('sansContact', Configure::read('Sanscontact.id'));

        // Cycle de vie du flux : Liste des acteurs
        $bannettes = $this->Courrier->Bancontenu->find(
            'all',
            array(
                'conditions' => array(
                    'Bancontenu.courrier_id' => $id
                ),
                'contain' => array(
                    'Desktop' => array(
                        'SecondaryUser',
                        'User',
                        'Group',
                        'Desktopmanager',
                    ),
                    'Bannette'
                ),
                'order' => array('Bancontenu.modified ASC', 'Desktop.name ASC')
            )
        );

//select date from wkf_visas where traitement_id in (select id from wkf_traitements where target_id=courrier_id) ;
        $traitement = $this->Courrier->Traitement->find('first', array(
            'fields' => array(
                'Traitement.id',
                'Traitement.circuit_id',
                'Traitement.numero_traitement'
            ),
            'conditions' => array(
                'Traitement.target_id' => $id
            ),
            'contain' => false,
            'recursive' => -1
        ));
        $traitement_id = Hash::get($traitement, 'Traitement.id');

        $visas = $this->Courrier->Traitement->Visa->find(
            'all',
            array(
                'fields' => array_merge(
                        $this->Courrier->Traitement->Visa->fields(), $this->Courrier->Traitement->Visa->Desktopmanager->fields()
                ),
                'conditions' => array(
                    'Visa.traitement_id' => $traitement_id,
                    'Visa.action' => array('OK', 'IL')
                ),
                'contain' => array(
                    'Desktopmanager' => array(
                        'Desktop'
                    )
                ),
                'recursive' => -1,
                'order' => 'Visa.numero_traitement ASC'
            )
        );
        $this->set('visas', $visas);

        $validated = array();
        foreach ($visas as $v => $visa) {
            $validated[$visa['Visa']['trigger_id']] = $visa['Visa']['date'];
        }

        foreach ($bannettes as $b => $bannette) {
            foreach ($bannette['Desktop']['Desktopmanager'] as $dKey => $desktopmanager) {
                if (isset($validated[$desktopmanager['id']])) {
                    $bannettes[$b]['Bancontenu']['validated'] = $validated[$desktopmanager['id']];
                }
            }
                        
            // Si le flux n'est pas lu, on n'affiche pas la date de modification, ni celle de validation
            if ($bannette['Bancontenu']['read'] == false) {
                $bannettes[$b]['Bancontenu']['validated'] = '';
                $bannettes[$b]['Bancontenu']['modified'] = '';
            }
        }
        $this->set('bannettes', $bannettes);

        if (Configure::read('Conf.SAERP')) {
            $marches_tmp = $this->Courrier->Marche->find(
                'all',
                array(
                    'joins' => array(
                        $this->Courrier->Marche->join('Operation')
                    ),
                    'conditions' => array(
                        'Marche.active' => true,
                        'Operation.active' => true
                    ),
                    'fields' => array(
                        'Marche.id',
                        'Marche.numero',
                        'Marche.titulaire'
                    ),
                    'contain' => false,
                    'order' => array('Marche.name ASC')
                )
            );  
            foreach( $marches_tmp as $m => $values) {
                $marches[$values['Marche']['id']] = $values['Marche']['numero']." - ".$values['Marche']['titulaire'];
            }
            $this->set(compact('marches'));
            
            $typesdocument = array(
                'OS' => 'Ordre de service',
                'LN' => 'Lettre de notification',
                'LC' => 'Lettre de commandes',
                'PLI' => 'Pli'
            );
            $this->set(compact('typesdocument'));

            $valueNumberOs = 1;
            if (!empty($this->request->data['Courrier']['marche_id'])) {
                $marche = $this->Courrier->Marche->find('first', array(
                    'conditions' => array(
                        'Marche.id' => $this->request->data['Courrier']['marche_id']
                    ),
                    'contain' => array(
                        'Ordreservice' => array(
                            'order' => array('Ordreservice.numero ASC')
                        )
                    )
                ));
//debug($marche);
//die();
                if (count($marche['Ordreservice']) > 0) {
                    $valueNumberOs = $marche['Ordreservice'][count($marche['Ordreservice']) - 1]['numero'] + 1;
                } else {
                    $valueNumberOs = 1;
                }

                $os = $this->Courrier->Ordreservice->find( 'first', array('conditions' => array('Ordreservice.courrier_id' => $this->request->data['Courrier']['id']), 'contain' => false ) );
                if(!empty($os)) {
                    $valueNumberOs = $os['Ordreservice']['numero'];
                }

                $osEntrant = $this->request->data['Courrier']['direction'];
                if( $osEntrant == '1' ) {
                    $valueNumberOs = ' ';
                }
            }
            $this->set('valueNumberOs', $valueNumberOs);

            if (!empty($this->request->data['Courrier']['consultation_id'])) {
                $consultation = $this->Courrier->Consultation->find(
                        'first', array(
                    'conditions' => array(
                        'Consultation.id' => $this->request->data['Courrier']['consultation_id']
                    ),
                    'contain' => array(
                        'Pliconsultatif' => array(
                            'order' => array('Pliconsultatif.numero ASC')
                        )
                    )
                        )
                );
                $valueNumberPli = $consultation['Pliconsultatif'][count($consultation['Pliconsultatif']) - 1]['numero'] + 1;
                $this->set(compact('valueNumberPli'));
            }
            $marcheconsult = array(
                'marche' => 'Marché',
                'consultation' => 'Consultation',
                'none' => 'Aucun des deux'
            );
            $this->set(compact('marcheconsult'));

            $consultations = $this->Courrier->Consultation->find('list', array(
                'joins' => array(
                    $this->Courrier->Consultation->join('Operation')
                ),
                'conditions' => array(
                    'Consultation.active' => true,
                    'Operation.active' => true
                ),
                'fields' => array(
                    'Consultation.numero'
                ),
                'order' => array('Consultation.name ASC')
            ));
            $this->set(compact('consultations'));
        }
        $this->request->data['Courrier']['date'] = date("d/m/Y", strtotime($this->request->data['Courrier']['date']));
        $this->request->data['Courrier']['datereception'] = date("d/m/Y", strtotime($this->request->data['Courrier']['datereception']));

        // Info sur l'étape en cours
        $circuit_id = Hash::get($traitement, 'Traitement.circuit_id');
        if (!empty($traitement) && !empty($circuit_id)) {
            $etape = $this->Courrier->Traitement->Circuit->Etape->find('first', array(
                'conditions' => array(
                    'Etape.circuit_id' => $circuit_id,
                    'Etape.ordre' => $traitement['Traitement']['numero_traitement']
                ),
                'contain' => false
            ));

            if (!empty($etape)) {
                $descriptionEtape = $etape['Etape']['description'];
            } else {
                $descriptionEtape = '';
            }
        } else {
            $descriptionEtape = '';
        }
        $this->set('descriptionEtape', $descriptionEtape);
        $conn = $this->Session->read('Auth.User.connName');
        $this->loadModel('Collectivite');
        $this->set('collectivite', $this->Collectivite->find('first', array('conditions' => array('Collectivite.conn' => $conn))));

        $profilActuel = $this->Session->read('Auth.User.Env.actual.group_id');
        $profilAutres = $this->Session->read('Auth.User.Env.secondary');
        $valuesProfils = Hash::extract( $profilAutres, '{n}');
        $isInit = 0;
        if( in_array('init', $valuesProfils ) || $profilActuel == INIT_GID ) {
            $isInit = 1;
        }
        $this->set('isInit', $isInit );
        
        $secondaryDesktops = $this->Session->read('Auth.User.SecondaryDesktops');
        $desktopName = Hash::extract($secondaryDesktops, '{n}.Group.name');
        $isAdmin = false;
        $groupName = $this->Session->read('Auth.User.Desktop.Group');
        if (in_array('Admin', $desktopName) || !empty($groupName) && $groupName['name'] == 'Admin') {
            $isAdmin = true;
            $desktopsAdmin = $this->Courrier->User->Desktop->find(
                'list',
                array(
                    'conditions' => array(
                        'Desktop.active' => true,
                        'Desktop.id <>' => -1
                    ),
                    'order' => array(
                        'Desktop.name'
                    )
                )
            );
            $this->set( 'desktopsAdmin', $desktopsAdmin);
        }
        $this->set( 'isAdmin', $isAdmin);
        
        
        $fromDisp = 0;
        if( $this->Session->read('Auth.User.Env.actual.group_id') == DISP_GID ) {
            $fromDisp = 1;
        }
        $this->set('fromDisp', $fromDisp );
//debug( $this->viewVars);
    }

    /**
     *
     * @param type $id
     */
    public function setComments($id) {
        $this->set('flux_id', $id);
        $soustype_id = $this->Courrier->field('soustype_id', array('Courrier.id' => $id));
        $this->set('canAddPrivateComment', !empty($soustype_id));
        $this->set('comments', $this->_getComments($id));
    }

    /**
     *
     * @param type $id
     */
    public function getComments($id) {
        $soustype_id = $this->Courrier->field('soustype_id', array('Courrier.id' => $id));
        $this->set('canAddPrivateComment', !empty($soustype_id));
        $this->set('comments', $this->_getComments($id));
    }

    /**
     *
     * @param type $id
     * @return type
     */
    private function _getComments($id) {

//querydata générique
        $qdComment = array(
            'fields' => array(
                'Comment.id',
                'Comment.created',
                'Comment.modified',
                'Comment.content',
                'Comment.objet',
                'Comment.private',
                'Owner.id',
                'Owner.name',
                'User.prenom',
                'User.nom',
//                'SecondaryUser.prenom',
//                'SecondaryUser.nom'
            ),
            'conditions' => array(
                'Comment.target_id' => $id,
//                'or' => array( //FIXME Arnaud
//                    'DesktopsUser.delegation' => false,
//                    'DesktopsUser.delegation' => null
//                )
            ),
            'order' => array('Comment.created desc'),
            'joins' => array(
                $this->Courrier->Comment->join($this->Courrier->Comment->Owner->alias),
                $this->Courrier->Comment->Owner->join($this->Courrier->Comment->Owner->User->alias),
                $this->Courrier->Comment->Owner->join($this->Courrier->Comment->Owner->DesktopsUser->alias),
                $this->Courrier->Comment->Owner->DesktopsUser->join($this->Courrier->Comment->Owner->DesktopsUser->SecondaryUser->alias)
            ),
            'contain' => false,
            'recursive' => -1
        );

//public
        $qdPublic = $qdComment;
        $qdPublic['conditions']['Comment.private'] = false;

//private
        $qdPrivate = $qdComment;
        $qdPrivate['conditions']['Comment.private'] = true;

        $readerPrivates = array_keys($this->Session->read('Auth.User.Env.secondary'));
        array_push($readerPrivates, $this->Session->read('Auth.User.Courrier.Desktop.id'));

        $sqParams = array(
            'alias' => 'comments_readers',
            'fields' => array(
                'comments_readers.comment_id'
            ),
            'conditions' => array(
                'comments_readers.reader_id' => $readerPrivates,
            ),
            'contain' => false,
            'recursive' => -1
        );
        $qdPrivate['conditions'][] = 'Comment.id IN (' . $this->Courrier->Comment->SCCommentReader->sq($sqParams) . ')';


//written
        $qdWritten = $qdComment;
        $qdWritten['conditions']['Owner.id'] = $this->SessionTools->getDesktopList();

        $return = array(
            'public' => $this->Courrier->Comment->find('all', $qdPublic),
            'private' => $this->Courrier->Comment->find('all', $qdPrivate),
            'written' => $this->Courrier->Comment->find('all', $qdWritten)
        );

        foreach( $return as $type => $comments ) {
            foreach( $comments as $key => $objet ) {
                if( isset($key) ){
                    $return[$type][$key]['Comment']['objet'] = preg_replace("/[\n\r]/", " ", $return[$type][$key]['Comment']['objet']);
                }
            }
        }
        for ($i = 0; $i < count($return['written']); $i++) {
            $found = $this->Courrier->Comment->find('first', array(
                'fields' => array(
                    'Comment.id',
                    'Comment.slug'
                ),
                'conditions' => array(
                    'Comment.id' => $return['written'][$i]['Comment']['id']
                ),
                'contain' => array(
                    'Reader' => array(
                        'fields' => array(
                            'Reader.name'
                        ),
                        'User' => array(
                            'fields' => array(
                                'User.id',
                                'User.prenom',
                                'User.nom'
                            )
                        ),
                        'SecondaryUser' => array(
                            'fields' => array(
                                'SecondaryUser.id',
                                'SecondaryUser.prenom',
                                'SecondaryUser.nom'
                            ),
                            'conditions' => array(
                                'or' => array(
                                    'DesktopsUser.delegation' => false,
                                    'DesktopsUser.delegation' => null
                                )
                            )
                        )
                    )
                )
                    )
            );

            $readers = array();
            foreach ($found['Reader'] as $reader) {
                $name = '';
                if (!empty($reader['User'][0]['nom']) && !empty($reader['User'][0]['prenom'])) {
                    $name .= $reader['User'][0]['nom'] . ' ' . $reader['User'][0]['prenom'];
                } else if (!empty($reader['SecondaryUser'][0]['nom']) && !empty($reader['SecondaryUser'][0]['prenom'])) {
                    $name .= $reader['SecondaryUser'][0]['nom'] . ' ' . $reader['SecondaryUser'][0]['prenom'];
                }
                $name .= (empty($name) ? '' : ' (') . $reader['name'] . (empty($name) ? '' : ')');
                $readers[] = array('id' => $reader['id'], 'name' => $name);
            }

            $return['written'][$i]['readers'] = $readers;
        }

        return $return;
    }

    /**
     *
     */
//TODO: supprimer les fonction commentées
    public function getContacts() {
        $querydata = array(
            'fields' => array(
                'Contact.id',
                'Contact.name',
                'Addressbook.name'
            ),
            'conditions' => array(
                'Addressbook.active' => true,
                'Contact.active' => true
            ),
            'contain' => false,
            'joins' => array(
                $this->Courrier->Contact->Addressbook->join($this->Courrier->Contact->alias)
            )
        );
        $this->set('contacts', $this->Courrier->Contact->Addressbook->find('list', $querydata));
    }

    /**
     * Récupération des boutons d'action concernant les circuits de traitement (ajax)
     *
     * @logical-group Flux
     * @logical-group CakeFlow
     * @user-profile User
     *
     * @param integer $fluxId identifiant du flux

     * @throws NotFoundException
     */
    public function getFlowControls($fluxId, $cpyOnly = false) {

        $this->Courrier->id = $fluxId;
        $courrier = $this->Courrier->find('first', array(
            'fields' => array(
                'Courrier.id',
                'Courrier.soustype_id',
                'Soustype.id',
                'Soustype.circuit_id',
                'Soustype.name',
                'Document.id'
            ),
            'conditions' => array(
                'Courrier.id' => $fluxId
            ),
            'joins' => array(
                $this->Courrier->join('Soustype', array('type' => 'LEFT OUTER')),
                $this->Courrier->join('Document', array('type' => 'LEFT OUTER'))
            ),
            'contain' => false
        ));

        if (empty($courrier)) {
            throw new NotFoundException();
        }

//TODO: verifier la pertinence de ce test
        $reponse = false;
        $stypeReponse = $this->Courrier->Soustype->find('first', array('conditions' => array('Soustype.parent_id' => $courrier['Courrier']['soustype_id']), 'contain ' => false));
        if (!empty($stypeReponse)) {
            $reponse = true;
        }

//TODO: verifier si besoin de isRefused
//        $isRefused = $this->Courrier->isRefused($courrier['Courrier']['id']);
        $isRefused = false;
        $isInCircuit = $this->Courrier->isInCircuit($courrier['Courrier']['id']);
        $isClosed = $this->Courrier->isClosed($courrier['Courrier']['id']);

        $rebond = false;
        $etapes = $this->Courrier->Traitement->Circuit->Etape->find('list', array('conditions' => array('Etape.circuit_id' => $courrier['Soustype']['circuit_id']), 'contain' => false));

        $nexts = $this->Courrier->Traitement->whoIsNext($courrier['Courrier']['id']);
        if (count($nexts) == 1 && !in_array($nexts[0], array_keys($etapes))) {
            $rebond = true;
        }

//on determine si le courrier est a l etape de fin
        $endCircuit = false;
        $endCircuitIsCollaborative = false;
        $endCircuitIsCollaborativeDerniereUtilisateur = false;
        if ($this->Courrier->cakeflowIsEnd($courrier['Courrier']['id'])) {
            $endCircuit = true;
        }
//debug($endCircuit);
        if ($endCircuit) {
            $last_etape_query = 'select max(E.ordre) from wkf_etapes E where E.circuit_id = ' . $courrier['Soustype']['circuit_id'] . ';';
            $last_etape_id = $this->Courrier->Traitement->Circuit->Etape->query($last_etape_query);
            $last_etape = $this->Courrier->Traitement->Circuit->Etape->find('first', array('conditions' => array('Etape.ordre' => $last_etape_id[0][0]['max'], 'Etape.circuit_id' => $courrier['Soustype']['circuit_id']), 'contain' => false));
            $traitement = $this->Courrier->Traitement->find(
                    'first', array(
                'conditions' => array(
                    'Traitement.circuit_id' => $last_etape['Etape']['circuit_id'],
                    'Traitement.target_id' => $courrier['Courrier']['id']
                ),
                'contain' => false,
                'recursive' => -1
                    )
            );
            $visas = $this->Courrier->Traitement->Visa->find('all', array(
                'fields' => array(
                    'Visa.action',
                    'Visa.trigger_id',
                    'Visa.id'
                ),
                'conditions' => array(
                    'Visa.traitement_id' => $traitement['Traitement']['id'],
                    'Visa.etape_id' => $last_etape['Etape']['id']
                ),
                'contain' => false,
                'recursive' => -1
            ));
            $list_visa = Hash::extract($visas, "{n}.Visa.action");
            $list_desktopId = Hash::extract($visas, "{n}.Visa.trigger_id");
            $listRi = array_count_values($list_visa);

            $endCircuitIsCollaborative = false;
            if (isset($listRi['RI']) && !empty($listRi['RI'])) {
                if ($last_etape['Etape']['type'] == 3 && $listRi['RI'] > 0) {
                    $endCircuitIsCollaborative = true;
                }
            }
            if ($traitement['Traitement']['numero_traitement'] > $last_etape['Etape']['ordre']) {
                $endCircuitIsCollaborative = false;
            }

//            $this->set('endCircuitIsCollaborative', $endCircuitIsCollaborative);
            $endCircuitIsCollaborativeDerniereUtilisateur = false;
            if ($endCircuitIsCollaborative && $listRi['RI'] == 1) {
                $this->set('list_desktopId', $list_desktopId);
                $endCircuitIsCollaborativeDerniereUtilisateur = true;
                $endCircuitIsCollaborative = false;
//                $this->set('endCircuitIsCollaborativeDerniereUtilisateur', true);
            }
        }

        $this->set('desktopsToSend', $this->Courrier->Desktop->getDesktopsByUser());

        $sendCpyCheck = $this->userAclCheck(array('model' => 'User', 'foreign_key' => $this->Session->read('Auth.User.id')), 'controllers/Courriers/sendcpy');
        $sendWkfCheck = $this->userAclCheck(array('model' => 'User', 'foreign_key' => $this->Session->read('Auth.User.id')), 'controllers/Courriers/sendwkf');


        $isUserInCircuit = false;
        $desktopUserId = $this->Session->read('Auth.User.Courrier.Desktop.id');
        if ($this->Session->read('Auth.User.Env.actual.name') != 'disp') {
            $traitement = $this->Courrier->Traitement->find(
                    'first', array(
                'fields' => array('circuit_id'),
                'conditions' => array('Traitement.target_id' => $courrier['Courrier']['id']),
                'contain' => false,
                'recursive' => -1
                    )
            );
            if (!empty($traitement)) {
                $circuitId = $traitement['Traitement']['circuit_id'];
                $desktopmanagersIds = $this->Courrier->Desktop->getDesktopManager($desktopUserId);
                $isUserInCircuit = $this->Courrier->Traitement->Circuit->userInCircuit($desktopmanagersIds, $circuitId);
            }
        }
        $this->set(compact('isUserInCircuit'));


    // Le circuit possède-t-il comme prochaine étape une délégation vers le parapheur ?
        $hasEtapeParapheur = $this->Courrier->Traitement->Circuit->hasEtapeDelegation($courrier['Soustype']['circuit_id']);
        $this->set(compact('hasEtapeParapheur'));

        $fairesuivre = true;
        if (empty($courrier['Document']['id'])) {
            $fairesuivre = false;
        }
        $this->set(compact('fairesuivre'));


// Autorisation de versement
        $isAuthVersGed = false;
        $isAuthVersGed = $this->userAclCheck(array('model' => 'User', 'foreign_key' => $this->Session->read('Auth.User.id')), 'controllers/Courriers/sendToGed');
        $this->set('isAuthVersGed', $isAuthVersGed);


// Le bureau actuel est-il celui de l'étape du circuit
        $desktopCurrentEtapeCircuit = false;
        $desktopIdInWkf = $this->Courrier->Traitement->whoIs($courrier['Courrier']['id'], 'current');

        $desktopmanagersIds = $this->Courrier->Desktop->getDesktopManager($desktopUserId);
        foreach ($desktopIdInWkf as $t => $val) {
            if (in_array($val, $desktopmanagersIds)) {
                $desktopCurrentEtapeCircuit[$t] = true;
            }
        }
//debug($desktopCurrentEtapeCircuit);
        if (is_array($desktopCurrentEtapeCircuit)) {
            $deskInCircuit = in_array(true, $desktopCurrentEtapeCircuit);
            if ($deskInCircuit) {
                $desktopCurrentEtapeCircuit = true;
            }
        }
        $this->set('desktopCurrentEtapeCircuit', $desktopCurrentEtapeCircuit);
        $this->set('endCircuitIsCollaborative', $endCircuitIsCollaborative);
        $this->set('endCircuitIsCollaborativeDerniereUtilisateur', $endCircuitIsCollaborativeDerniereUtilisateur);
//$this->set('etapes',$nexts);
        $this->set('sendwkf', $sendWkfCheck);
        $this->set('sendcpy', $sendCpyCheck);
        $this->set('rebond', $rebond);
        $this->set('reponse', $reponse);
        $this->set('courrier', $courrier);
        $this->set('isRefused', $isRefused);
        $this->set('isInCircuit', $isInCircuit);
        $this->set('isClosed', $isClosed);
        $this->set('endCircuit', $endCircuit);
        $this->set('cpyOnly', $cpyOnly && $sendCpyCheck);
        $this->set('desktopidactuel', $this->Session->read('Auth.User.Courrier.Desktop.id'));
//document principal
        $this->set('mainDoc', $this->Courrier->getMainDoc($courrier['Courrier']['id']));
        $this->set('SoustypeFantome', Configure::read('Soustype.Fantome'));
    }

    /**
     * Accès à l'onglet "Méta-données" (ajax)
     *
     * @logical-group Flux
     * @logical-flux Edition d'un flux
     * @user-profile User
     *
     * @access public
     * @param integer $fluxId identifiant du flux

     * @return void
     */
    public function setMeta($fluxId = null) {
//enregistrement des données
        if (!empty($this->request->data)) {
            $this->Courrier->Metadonnee->CourrierMetadonnee->begin();
            $msg = 'Onglet ' . __d('courrier', 'Metadonnees') . ' : ';
            $this->Jsonmsg->init($msg . __d('default', 'save.error'));
//preparation des metadonnee
            $success = true;
            $idsASupprimer = array();
            $aEnregistrer = array();
            $aMettreAJour = array();
//debug($this->request->data['CourrierMetadonnee']);
            foreach ($this->request->data['CourrierMetadonnee'] as $key => $values) {

                // Meta obligatoire devant être renseigné pour avancer dans le circuit
                $checkboxUnchecked = false;
                if ($this->Courrier->Metadonnee->field('Metadonnee.typemetadonnee_id', array('Metadonnee.id' => $values['metadonnee_id'])) == 3 && $values['valeur'] == 0) {
                    $checkboxUnchecked = true;
                }

                if (trim($values['valeur']) == '') {
                    if (!empty($values['id'])) {
                        $idsASupprimer[] = $values['id'];
                    }
                } else if ($this->_isExistMetaCourrier($values['courrier_id'], $values['metadonnee_id'])) {
                    $ancienValeur = $this->_getMetaValueExistMetaCourrier($values['courrier_id'], $values['metadonnee_id']);
                    if ($values['valeur'] != $ancienValeur) {
                        $aEnregistrer[] = $values;
                    } else {
                        $success = true;
                    }
                } else {
                    $aEnregistrer[] = $values;
                }
            }
            if (!empty($idsASupprimer)) {
                $success = $this->Courrier->Metadonnee->CourrierMetadonnee->deleteAll(array('CourrierMetadonnee.id' => $idsASupprimer)) && $success;
            }
            if (!empty($aEnregistrer)) {
                $success = $this->Courrier->Metadonnee->CourrierMetadonnee->saveAll($aEnregistrer) && $success;
            }

            if ($success) {
                $flux = $this->Courrier->find(
                    'first',
                    array(
                        'conditions' => array(
                            'Courrier.id' => $fluxId
                        ),
                        'contain' => false,
                        'recursive' => -1
                    )
                );
                $this->loadModel('Journalevent');
                $datasSession = $this->Session->read('Auth.User');
                $msg = "L'utilisateur ". $this->Session->read('Auth.User.username'). " a modifié le flux ".$flux['Courrier']['reference']." (ajout d'une méta-donnée) le ".date('d/m/Y à H:i:s');
                $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $flux);
                
                // En cas d'ajout de commentaire, on met à jour la date de modification de la table bancontenus pour le profil étant intervenu
                $this->Courrier->Bancontenu->updateAll(
                    array(
                        'Bancontenu.modified' => "'".date( 'Y-m-d H:i:s')."'"
                    ),
                    array(
                        'Bancontenu.courrier_id' => $fluxId,
                        'Bancontenu.desktop_id' => $this->Session->read('Auth.User.Courrier.Desktop.id')
                    )
                );
                
                $this->Courrier->Metadonnee->CourrierMetadonnee->commit();
                $this->Jsonmsg->json['newCourrierId'] = $fluxId;
                $this->Jsonmsg->valid($msg . __d('default', 'save.ok'));
            } else {
                $this->Courrier->Metadonnee->CourrierMetadonnee->rollback();
                $this->Jsonmsg->error($msg . __d('default', 'save.error'));
            }
            $this->Jsonmsg->send();
        } else { //affichage du formulaire
//			if (!is_integer($fluxId) || $fluxId <= 0) {
//				throw new BadMethodCallException();
//			}
//TODO: ameliorer la gestion des thesaurus
            $this->loadModel('Keywordlist');
            $this->loadModel('Keyword');
            $this->Keyword->recursive = -1;
            $this->Keywordlist->recursive = -1;

            $thesaurusList = $this->Keywordlist->find('all', array('conditions' => array('Keywordlist.active' => true)));
            $thesaurus_keywords = array();
            foreach ($thesaurusList as $item) {
                $thesaurus_keywords[] = array(
                    'keywordlist' => array(
                        'id' => $item['Keywordlist']['id'],
                        'nom' => $item['Keywordlist']['nom']
                    ),
                    'keywords' => $this->Keyword->generateTreeList(array('Keyword.keywordlist_id' => $item['Keywordlist']['id']))
                );
            }
            $this->set('thesaurus_keywords', $thesaurus_keywords);

// On récupère l'ID du sous type présent dans le flux
            $flux = $this->Courrier->find(
                    'first', array(
                'fields' => array('Soustype.id'),
                'conditions' => array(
                    'Courrier.id' => $fluxId
                ),
                'contain' => array(
                    'Soustype'
                )
                    )
            );
            $metasIdsBySoustype = array();
// Si un sous type est lié, on regarde la liste des méta données associées
            if (!empty($flux)) {
                $sousTypeId = $flux['Soustype']['id'];

                $metasBySoustype = $this->Courrier->Soustype->MetadonneeSoustype->find(
                        'all', array(
                    'conditions' => array(
                        'MetadonneeSoustype.soustype_id' => $sousTypeId
                    ),
                    'recursive' => -1
                        )
                );
//debug($metasBySoustype);
                if (!empty($metasBySoustype)) {
                    $metasIdsBySoustype = Hash::extract($metasBySoustype, '{n}.MetadonneeSoustype.metadonnee_id');
                }

                if (!empty($metasIdsBySoustype)) {
                    $metasIdsObligatoireBySoustype = array_combine($metasIdsBySoustype, Hash::extract($metasBySoustype, '{n}.MetadonneeSoustype.obligatoire'));
                }
            }


            $metas = $this->DataAuthorized->getAuthMetadonnees(array('action' => 'update'));

            $metas_values = $this->DataAuthorized->getAuthMetadonnees(array('action' => 'update', 'fluxId' => $fluxId));

            $compiledMetas = array();
            foreach ($metas as $meta) {
                if (!empty($metasIdsBySoustype)) {
//Si des métadonnées sont liées au sous-typr, on réduit la liste uniquement à ces métadonnées
                    if (in_array($meta['Metadonnee']['id'], $metasIdsBySoustype)) { // réduction de la liste des métadonnées selon le sous-type défini dans le flux
// ajout pour la notion de champ obligatoire sur la métadonnée pour le sous-type en question
                        if (!empty($metasIdsObligatoireBySoustype)) {
                            $meta['Metadonnee']['obligatoire'] = $metasIdsObligatoireBySoustype[$meta['Metadonnee']['id']];
                        }
                        foreach ($metas_values as $meta_value) {
                            if ($meta['Metadonnee']['id'] == $meta_value['Metadonnee']['id']) {
                                if (!empty($meta_value['CourrierMetadonnee'])) {
                                    $meta['CourrierMetadonnee'] = $meta_value['CourrierMetadonnee'];
                                }
                            }
                        }
                        $compiledMetas[] = $meta;
                    }
                } else {
//sinon, on affiche toutes les métadonnées
                    foreach ($metas_values as $meta_value) {
                        if ($meta['Metadonnee']['id'] == $meta_value['Metadonnee']['id']) {
                            if (!empty($meta_value['CourrierMetadonnee'])) {
                                $meta['CourrierMetadonnee'] = $meta_value['CourrierMetadonnee'];
                            }
                        }
                    }
                    $compiledMetas[] = $meta;
                }
            }
// debug($compiledMetas);
            $this->set('metas', $compiledMetas);
            $this->set('fluxId', $fluxId);
        }
    }

    protected function _isExistMetaCourrier($courrier_id, $metadonnee_id) {
        $count = $this->Courrier->Metadonnee->CourrierMetadonnee->find('count', array(
            'conditions' => array(
                "CourrierMetadonnee.courrier_id" => $courrier_id,
                "CourrierMetadonnee.metadonnee_id" => $metadonnee_id
            )
        ));
        return $count;
    }

    protected function _getMetaValueExistMetaCourrier($courrier_id, $metadonnee_id) {
        $res = $this->Courrier->Metadonnee->CourrierMetadonnee->field('valeur', array('CourrierMetadonnee.courrier_id' => $courrier_id, 'CourrierMetadonnee.metadonnee_id' => $metadonnee_id));
        return $res;
    }

    /**
     * Accès à l'onglet "Tâches" (ajax)
     *
     * @logical-group Flux
     * @logical-flux Edition d'un flux
     * @user-profile User
     *
     * @access public
     * @param integer $fluxId identifiant du flux

     * @throws NotFoundException
     * @return void
     */
    public function setTache($fluxId) {

        $qd = array(
            'recursive' => -1,
            'conditions' => array(
                'Courrier.id' => $fluxId
            )
        );

        $courrier = $this->Courrier->find('first', $qd);
        if (empty($courrier)) {
            throw new NotFoundException();
        }
        $canAddTask = true;
        if (empty($courrier['Courrier']['soustype_id'])) {
            $canAddTask = false;
        }
        $this->set('canAddTask', $canAddTask);

        $querydata = array(
            'contain' => array(
                $this->Courrier->Tache->Desktop->alias
            ),
            'conditions' => array(
                "Tache.courrier_id" => $fluxId
            ),
            'order' => array(
                'Tache.created'
            )
        );
        $taches_tmp = $this->Courrier->Tache->find('all', $querydata);

        $taches = array();
//on verifie que l utilisateur fait partie des personnes pouvant valider la tache
        $userDesktops = $this->SessionTools->getDesktopList();
        foreach ($taches_tmp as $tache) {
//calcul du retard
            $retard = false;
            if ($tache['Tache']['statut'] != 2) {
                $tmpTime = preg_split('# #', $tache['Tache']['created']);
                $tmpTime1 = preg_split('#-#', $tmpTime[0]);
                if ($tache['Tache']['delai_unite'] == 0) {
                    $endTime = mktime(0, 0, 0, $tmpTime1[1], $tmpTime1[2] + $tache['Tache']['delai_nb'], $tmpTime1[0]);
                } else if ($tache['Tache']['delai_unite'] == 1) {
                    $endTime = mktime(0, 0, 0, $tmpTime1[1], $tmpTime1[2] + (7 * $tache['Tache']['delai_nb']), $tmpTime1[0]);
                } else if ($tache['Tache']['delai_unite'] == 2) {
                    $endTime = mktime(0, 0, 0, $tmpTime1[1] + $tache['Tache']['delai_nb'], $tmpTime1[2], $tmpTime1[0]);
                }
                if ($endTime < mktime()) {
                    $retard = true;
                }
            }
            $tache['retard'] = $retard;
            $tache['canGrab'] = false;
            $tache['canRelease'] = false;
            $tache['canValid'] = false;

            if ($tache['Tache']['statut'] == 0) {
                if (count($tache['Desktop']) == 1) {
                    if (in_array($tache['Desktop'][0]['id'], $userDesktops)) {
                        $tache['canValid'] = true;
                    }
                } else if (count($tache['Desktop'] > 1)) {
                    foreach ($tache['Desktop'] as $dktp) {
                        if (in_array($dktp['id'], $userDesktops)) {
                            $tache['canGrab'] = true;
                        }
                    }
                }
            } else if ($tache['Tache']['statut'] == 1) {
                if (in_array($tache['Tache']['act_desktop_id'], $userDesktops)) {
                    $tache['canValid'] = true;
                    $tache['canRelease'] = true;
                }
            }

            if ($retard) {
                array_unshift($taches, $tache);
            } else {
                array_push($taches, $tache);
            }
        }
        $this->set('taches', $taches);
        $this->set('userDesktops', $userDesktops);

        $rights = array(
            'add' => ($this->userAclCheck(array('model' => 'User', 'foreign_key' => $this->Session->read('Auth.User.id')), 'controllers/Taches/add') ? true : false),
            'edit' => ($this->userAclCheck(array('model' => 'User', 'foreign_key' => $this->Session->read('Auth.User.id')), 'controllers/Taches/edit') ? true : false),
            'delete' => ($this->userAclCheck(array('model' => 'User', 'foreign_key' => $this->Session->read('Auth.User.id')), 'controllers/Taches/delete') ? true : false)
        );
        $this->set('rights', $rights);
        $this->set('id', $fluxId);
    }

    /**
     * Accès à l'onglet "Dossiers/Affaires" (ajax)
     *
     * @logical-group Flux
     * @logical-flux Edition d'un flux
     * @user-profile User
     *
     * @access public
     * @param integer $courrierId identifiant du flux
     * @param integer $affaireId identifiant de l'affaire
     * @throws NotFoundException
     * @return void
     */
    public function setAffaire($courrierId = null, $affaireId = null) {
//enregistrement des données
//association d un courrier a une affaire
        if ($courrierId != null && $affaireId != null) {
            $courrier = $this->Courrier->find('first', array('conditions' => array('Courrier.id' => $courrierId)));
            $msg = 'Onglet ' . __d('courrier', 'Affaires') . ' : ';
            $this->Jsonmsg->init($msg . __('default', 'save.error'));
            $this->Courrier->begin();

            if ($courrier['Courrier']['affaire_id'] == $affaireId) { //le courrier et l affaire sont liés, on va les dissocier
                $courrier['Courrier']['affaire_id'] = null;
            } else { //sinon on les associe
                $courrier['Courrier']['affaire_id'] = $affaireId;
            }

            if ($this->Courrier->save($courrier)) {
                $this->Courrier->commit();
                $this->Jsonmsg->valid($msg . __('default', 'save.ok'));
            } else {
                $this->Courrier->rollback();
            }
            $this->Jsonmsg->send();
        } else {
//formulaire de creation d un affaire ( et d un dossier)
            if (!empty($this->request->data)) {
                if (!empty($this->request->data['Affaire'])) {
                    if (!empty($this->request->data['Dossier']['name'])) {
                        $this->Courrier->Affaire->Dossier->begin();
                        $saveDossier = $this->Courrier->Affaire->Dossier->save($this->request->data['Dossier']);
                        if ($saveDossier) {
                            $this->Courrier->Affaire->Dossier->commit();
                            $this->request->data['Affaire']['dossier_id'] = $this->Courrier->Affaire->Dossier->id;
                        } else {
                            $this->Courrier->Affaire->Dossier->rollback();
                            $this->request->data['Affaire']['dossier_id'] = '';
                        }
                    }
                    $this->Jsonmsg->init();
                    if ($this->Courrier->Affaire->save($this->request->data['Affaire'])) {
                        $this->Courrier->id = $courrierId;
                        if ($this->Courrier->saveField('affaire_id', $this->Courrier->Affaire->id)) {
                            $this->Jsonmsg->valid();
                        }
                    }
                    $this->Jsonmsg->send();
                }
            }

//affichage du formulaire
            if ($courrierId != null) {
                $querydata = array(
                    'contain' => array(
                        $this->Courrier->Affaire->alias => array(
                            $this->Courrier->Affaire->Dossier->alias
                        )
                    ),
                    'conditions' => array(
                        'Courrier.id' => $courrierId
                    )
                );
                $courrier = $this->Courrier->find('first', $querydata);

                if (!empty($courrier)) {
                    $this->Courrier->Affaire->recursive = 1;
                    $this->Courrier->Affaire->Dossier->recursive = 1;

                    $this->loadModel('Compteur');
// select nom from compteurs where id= '1'; => compteur_affaire
//                     select id from compteurs where nom ='compteur_affaire';
                    $CompteurAffaire = $this->Compteur->find(
                            'first', array(
                        'fields' => array('Compteur.id', 'Compteur.nom'),
                        'conditions' => array(
                            'Compteur.nom' => 'compteur_affaire'
                        ),
                        'recursive' => -1
                            )
                    );
                    $idAffaire = $CompteurAffaire['Compteur']['id'];

                    $CompteurDossier = $this->Compteur->find(
                            'first', array(
                        'fields' => array('Compteur.id', 'Compteur.nom'),
                        'conditions' => array(
                            'Compteur.nom' => 'compteur_dossier'
                        ),
                        'recursive' => -1
                            )
                    );
                    $idDossier = $CompteurDossier['Compteur']['id'];

                    $this->set('newAffaireName', $this->Compteur->genereCompteur($idAffaire));
// select nom from compteurs where id= '2'; => compteur_dossier
                    $this->set('newDossierName', $this->Compteur->genereCompteur($idDossier));

                    $this->set('dossiers', $this->Courrier->Affaire->Dossier->getDossiersAffairesTree());
//                    $this->set('listDossiers', $this->Courrier->Affaire->Dossier->find('list'));

                    $listDossiers = $this->Courrier->Affaire->Dossier->find('list');
                    $ajoutDossier = array('new' => __d('dossier', 'Dossier.add'));
                    $listDossiers = ($ajoutDossier + $listDossiers );
                    $this->set('listDossiers', $listDossiers);

                    $this->set('selectedAffaire', $courrier['Affaire']['id']);
                    $this->set('selectedFolder', $courrier['Affaire']['dossier_id']);
                    $this->request->data = $courrier;
                } else {
                    throw new NotFoundException();
                }
            }
            $this->autoLayout = false;
        }
    }

    /**
     * Renvoi la liste des sous-types liés au sous-type du flux en fin de circuit
     *
     * @logical-group Flux
     * @user-profile User
     *
     * @access public
     * @param integer $id identifiant du flux
     * @return void
     */
    public function reponse($id = null) {
        if ($id != null) {
            $soustype_id = $this->Courrier->field('soustype_id', array('Courrier.id' => $id));
            $soustypes_lies = $this->Courrier->Soustype->find('list', array('conditions' => array('Soustype.parent_id' => $soustype_id)));
            $this->set('soustypes_lies', $soustypes_lies);
        }
    }

    /**
     * Validation d'une étape d'un circuit
     *
     * @logical-group Flux
     * @logical-group CakeFlow
     * @user-profile User
     *
     * @access public
     * @param integer $fluxId identifiant du flux
     * @param integer $parent identifiant du fluw parent
     * @param integer $stype_id identifiant du sous-type
     * @param integer $insertAuto
     * @return void
     */
    public function valid($fluxId, $parent = 0, $stype_id = null, $insertAuto = 0) {
        $this->autoRender = false;
        $desktop_id = $this->Session->read('Auth.User.Courrier.Desktop.id');

        $secondaryDesktops = $this->Session->read('Auth.User.SecondaryDesktops');
        $groupId = Hash::extract($secondaryDesktops, '{n}.Group.id');
        $desktopId = Hash::extract($secondaryDesktops, '{n}.id');
        $groupName = $this->Session->read('Auth.User.Desktop.Group');
        // Si le bureau secondaire est de type Valideur Editeur, Valideur ou Documentaliste
        if ( in_array( $groupId, array( 4, 5, 6 )  ) ) {
            $desktop_id = $desktopId;
        }
        $flux = $this->Courrier->find(
            'first',
            array(
                'conditions' => array(
                    'Courrier.id' => $fluxId
                ),
                'contain' => false, 
                'recursive' => -1
            )
        );
        $ret = $this->Courrier->cakeflowExecuteNext($desktop_id, $fluxId, $parent, $stype_id, $insertAuto);
        if ($ret === true) {
            $this->loadModel('Journalevent');
            $datasSession = $this->Session->read('Auth.User');
            $msg = "L'utilisateur ". $this->Session->read('Auth.User.username'). " a validé le flux ".$flux['Courrier']['reference']." le ".date('d/m/Y à H:i:s');
            $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $flux);
           
            
            $this->Session->setFlash(__d('courrier', 'Courrier.treated.ok'), 'growl', array('type' => 'default'));
        } else {
            $this->Session->setFlash(__d('courrier', 'Courrier.treated.error') . ' : ' . json_decode($ret), 'growl', array('type' => 'erreur'));
        }
    }

    /**
     * Validation d'une étape collaborative qui est le dernière etape d'un circuit 
     *
     * @logical-group Flux
     * @logical-group CakeFlow
     * @user-profile User
     *
     * @access public
     * @param integer $fluxId identifiant du flux
     * @param integer $parent identifiant du fluw parent
     * @param integer $stype_id identifiant du sous-type
     * @param integer $insertAuto
     * @return void
     */
    public function validEtapeLastCol($fluxId, $parent = 0, $stype_id = null, $insertAuto = 0) {
        $this->autoRender = false;
        $courrier = $this->Courrier->find(
                'first', array(
            'fields' => array(
                'Courrier.id',
                'Courrier.soustype_id',
                'Soustype.id',
                'Soustype.circuit_id',
                'Document.id'
            ),
            'conditions' => array(
                'Courrier.id' => $fluxId
            ),
            'joins' => array(
                $this->Courrier->join('Soustype', array('type' => 'LEFT OUTER')),
                $this->Courrier->join('Document', array('type' => 'LEFT OUTER'))
            ),
            'contain' => false
                )
        );
        $last_etape_query = 'select max(E.ordre) from wkf_etapes E where E.circuit_id = ' . $courrier['Soustype']['circuit_id'] . ';';
        $last_etape_id = $this->Courrier->Traitement->Circuit->Etape->query($last_etape_query);
        $last_etape = $this->Courrier->Traitement->Circuit->Etape->find('first', array('conditions' => array('Etape.ordre' => $last_etape_id[0][0]['max'], 'Etape.circuit_id' => $courrier['Soustype']['circuit_id']), 'contain' => false));
        $traitement_id = $this->Courrier->Traitement->field('Traitement.id', array('Traitement.circuit_id' => $last_etape['Etape']['circuit_id'], 'Traitement.target_id' => $courrier['Courrier']['id']));
        $visas = $this->Courrier->Traitement->Visa->find('all', array(
            'fields' => array(
                'Visa.action',
                'Visa.trigger_id',
                'Visa.id'
            ),
            'conditions' => array(
                'Visa.traitement_id' => $traitement_id,
                'Visa.etape_id' => $last_etape['Etape']['id']
            )
        ));
        $list_desktopId = Hash::extract($visas, "{n}.Visa.trigger_id");
        $this->sendwkf($list_desktopId, $fluxId);
    }

    /**
     * Insertion d'un flux dans un circuit
     *
     * @logical-group Flux
     * @logical-group CakeFlow
     * @user-profile User
     *
     * @access public
     * @param integer $fluxId identifiant du flux
     * @throws BadFunctionCallException
     * @return void
     */
    public function insert($fluxId) {
//		if ($fluxId == null) {
//			throw new BadFunctionCallException();
//		}
        $envactual = $this->Session->read('Auth.User.Env.actual.name');
        $envmain = $this->Session->read('Auth.User.Env.main');

        if (!Configure::read('Conf.SAERP')) {
            $isEtape = $this->Courrier->isEtape($fluxId);
        } else {
            $isEtape = true;
        }
        $this->autoRender = false;

        if ($isEtape == true) {
            $ret = $this->Courrier->cakeflowInsert($fluxId, $this->Session->read('Auth.User.Courrier.Desktop.id'));
            
            $flux = $this->Courrier->find(
                'first',
                array(
                    'conditions' => array(
                        'Courrier.id' => $fluxId
                    ),
                    'contain' => false, 
                    'recursive' => -1
                )
            );
            if ($ret === true) {
//                $this->log( "L'utilisateur ". $this->Session->read('Auth.User.username'). " a inséré le flux ".$flux['Courrier']['reference']." dans un circuit, le ".date('d/m/Y à H:i:s'), LOG_WARNING );
                
                $this->loadModel('Journalevent');
                $datasSession = $this->Session->read('Auth.User');
                $msg = "L'utilisateur ". $this->Session->read('Auth.User.username'). " a inséré le flux ".$flux['Courrier']['reference']." dans un circuit, le ".date('d/m/Y à H:i:s');
                $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $flux);
            
                $this->Session->setFlash(__d('courrier', 'Courrier.insert.ok'), 'growl', array('type' => 'default'));
            } else {
                $this->Session->setFlash(__d('courrier', 'Courrier.insert.error') . ' : ' . json_decode($ret), 'growl', array('type' => 'erreur'));
            }
        } else {
            $this->Session->setFlash(__d('courrier', 'Courrier.insert.emptyStep'), 'growl');
        }

        $this->redirect(array('controller' => 'environnement', 'action' => 'userenv'));
    }

    /**
     * Refus d'un flux inséré dans un circuit
     *
     * @logical-group Flux
     * @logical-group CakeFlow
     * @user-profile User
     *
     * @access public
     * @param integer $id identifiant du flux
     * @throws BadFunctionCallException
     * @return void
     */

    public function refus($id = null, $message = null) {
        if ($id != null) {
            $flux = $this->Courrier->find('first', array('conditions' => array('Courrier.id' => $id)));
            $this->set('courrier', $flux);
            $msg = array(
                'success' => false,
                'message' => ''
            );
            if (!empty($this->request->data)) {

                $this->Courrier->begin();

//Enregistrement du motif de refus dans le courrier
                if (empty($message)) {
                    if (empty($this->request->data['Notification']['message'])) {
                        $this->request->data['Notification']['message'] = "Motif de refus à demander à l'agent ayant refusé";
                    } else {
                        $this->request->data['Notification']['message'] = $this->request->data['Notification']['message'];
                    }
                    $this->Courrier->updateAll(
                            array(
                        'Courrier.motifrefus' => "'" . Sanitize::clean($this->request->data['Notification']['message'], array('encode', false)) . "'",
                        'Courrier.ref_ancien' => $id,
                        'Courrier.parapheur_etat' => null,
                        'Courrier.parapheur_id' => null
                            ), array('Courrier.id' => $id)
                    );
                } else {
                    $this->Courrier->updateAll(
                            array(
                        'Courrier.motifrefus' => "'" . Sanitize::clean($message, array('encode', false)) . "'",
                        'Courrier.ref_ancien' => $id,
                        'Courrier.parapheur_etat' => null,
                        'Courrier.parapheur_id' => null
                            ), array('Courrier.id' => $id)
                    );
                }

//action de refus pour le traitement
                $this->Courrier->Traitement->execute('KO', $this->Session->read('Auth.User.Courrier.Desktop.id'), $flux['Courrier']['id']);
//                $this->Courrier->Traitement->delete( $flux['Courrier']['id'] );
                $traitements = $this->Courrier->Traitement->find(
                        'all', array(
                    'conditions' => array(
                        'Traitement.target_id' => $flux['Courrier']['id']
                    ),
                    'contain' => false
                        )
                );
                foreach ($traitements as $t => $traitement) {
                    $this->Courrier->Traitement->delete($traitement['Traitement']['id']);
                }
                //on change l etat du flux dans toutes les bannettes
                $this->Courrier->Bancontenu->cancel($flux['Courrier']['id']);
                $this->Courrier->Bancontenu->refus($this->Session->read('Auth.User.Courrier.Desktop.id'), $flux['Courrier']['id']);

//on ajoute le flux dupliqué dans la bannette du rédacteur
                if ($this->Courrier->Bancontenu->add($flux['Courrier']['desktop_creator_id'], BAN_REFUS, $flux['Courrier']['id'])) {
//notification au rédacteur
                    $notifyDesktops = array($flux['Courrier']['desktop_creator_id'] => array($flux['Courrier']['id']));
                    if ($this->Courrier->Notifieddesktop->Notification->add(__d('notification', 'ban_cancel.name'), __d('notification', 'ban_cancel.description'), BAN_REFUS, $this->Session->read('Auth.User.Courrier.Desktop.id'), $notifyDesktops)) {


                        // On récupère toutes les infos de bancontenus sauf les copies
                        $conditions = array(
                            'Bancontenu.courrier_id' => $flux['Courrier']['id'],
                            'Bancontenu.bannette_id <>' => BAN_COPY
                        );
                        // On récupère les infos de bancontenus uniquement pour les initiateurs
                        if( Configure::read('Refus.InitiateurOnly') ) {
                            $conditions = array(
                                'Bancontenu.courrier_id' => $flux['Courrier']['id'],
                                'Bancontenu.bannette_id' => BAN_DOCS
                            );
                        }
                        $bancontenus = $this->Courrier->Bancontenu->find(
                            'all',
                            array(
                                'conditions' => $conditions,
                                'contain' => false
                            )
                        );
                        $destinataires = Hash::extract($bancontenus, '{n}.Bancontenu.desktop_id');
                        foreach ($destinataires as $destinatairem_id) {
                            if ($destinatairem_id != -1 && !empty($destinatairem_id)) {
                                $user_id = $this->Courrier->User->userIdByDesktop($destinatairem_id);
                                $typeNotif = $this->Courrier->User->find(
                                        'first', array(
                                        'fields' => array('User.typeabonnement'),
                                        'conditions' => array('User.id' => $user_id),
                                        'contain' => false
                                    )
                                );
                                $notificationId = $this->Courrier->Notifieddesktop->Notification->id;
                                if ($typeNotif['User']['typeabonnement'] == 'quotidien') {
                                    $this->Courrier->User->saveNotif($flux['Courrier']['id'], $user_id, $notificationId, 'refus');
                                } else {
                                    $this->Courrier->User->notifier($flux['Courrier']['id'], $user_id, $notificationId, 'refus');
                                }
                            }
                        }
                        
                        if (empty($message)) {
//                            $this->log( "L'utilisateur ". $this->Session->read('Auth.User.username'). " a refusé le flux ".$flux['Courrier']['reference']." le ".date('d/m/Y à H:i:s'), LOG_WARNING );
                            $this->loadModel('Journalevent');
                            $datasSession = $this->Session->read('Auth.User');
                            $msg = "L'utilisateur ". $this->Session->read('Auth.User.username'). " a refusé le flux ".$flux['Courrier']['reference']." le ".date('d/m/Y à H:i:s'). " avec le motif suivant : <br />" . $this->request->data['Notification']['message'];
                            $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $flux);
                            
                            $msg['message'] = 'Le flux ' . $flux['Courrier']['name'] . ' a été refusé avec le motif suivant : <br />' . $this->request->data['Notification']['message'];
                        } else {
//                            $this->log( "L'utilisateur ". $this->Session->read('Auth.User.username'). " a refusé le flux ".$flux['Courrier']['reference']." le ".date('d/m/Y à H:i:s'), LOG_WARNING );
                            $this->loadModel('Journalevent');
                            $datasSession = $this->Session->read('Auth.User');
                            $msg = "L'utilisateur ". $this->Session->read('Auth.User.username'). " a refusé le flux ".$flux['Courrier']['reference']." le ".date('d/m/Y à H:i:s'). " avec le motif suivant : <br />" . $message;
                            $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $flux);
                            
                            $msg['message'] = 'Le flux ' . $flux['Courrier']['name'] . ' a été refusé avec le motif suivant : <br />' . $message;
                        }
                        $msg['success'] = true;
                    } else {
                        $msg['message'] .= '<br />Notification: error';
                    }
                } else {
                    $msg['message'] .= '<br />Bannette add: error';
                }
            } else {
                $msg['message'] .= '<br />Courrier duplicate: error';
            }
//debug($msg);
            if ($msg['success']) {
                $this->Courrier->commit();
                $this->Session->setFlash('Le flux a été refusé', 'growl');
            } else {
                $this->Courrier->rollback();
                if (Configure::read('debug') > 0) {
                    $msg['message'] .= '<br />Le flux n\'a pas été refusé.';
                } else {
                    $msg['message'] = 'Le flux n\'a pas été refusé.';
                }
                $this->Session->setFlash($msg['message'], 'growl');
            }
        }
    }

    /**
     * Envoi d'un flux en copie
     *
     * @logical-group Flux
     * @logical-group Edition de flux
     * @user-profile User
     *
     * @access public
     * @param integer $fluxId identifiant du flux
     * @return void
     */
    public function sendcpy() {
        if (!empty($this->request->data)) {
//cas d envoi pour copie
            $this->Jsonmsg->init();
            if ($this->Courrier->copy($this->Session->read('Auth.User.Courrier.Desktop.id'), $this->request->data['Send']['flux_id'], $this->request->data['Send']['copy_id'])) {
                $success = true;
//                if (!empty($this->request->data['Comment']['content'])) {
                if (!empty($this->request->data['Comment']['objet'])) {
                    $success = $this->Courrier->Comment->save($this->request->data);
                }
                if (!empty($success)) {
                    $this->Jsonmsg->valid();
                }
            }
            $this->Jsonmsg->send();
        }
    }

    /**
     * Envoi d'un flux à une étape hors circuit
     *
     * @logical-group Flux
     *
     * @logical-used-by CakeFlow > Envoi d'un flux (avec ou sans rebond) à une nouvelle étape
     * @user-profile User
     *
     * @access public
     * @param integer $fluxId identifiant du flux
     * @return void
     */
    public function sendwkf($list_desktopId = null, $fluxId = null) {

        if (!empty($this->request->data)) {
            $this->autoRender = false;
//rebond
            $newDesktopId = $this->request->data['Send']['desktop_id'];
            $fluxId = $this->request->data['Send']['flux_id'];
//            $newDesktop = $this->Courrier->Desktop->find('first', array('conditions' => array('Desktop.id' => $newDesktopId)));
            $newDesktop = $this->Courrier->Desktop->Desktopmanager->find(
                    'first', array(
                'conditions' => array(
                    'Desktopmanager.id' => $newDesktopId
                ),
                'contain' => array(
                    'Desktop'
                )
                    )
            );
            $desktopId = $this->Session->read('Auth.User.Courrier.Desktop.id');

            $desktopsReadersIds = $this->Courrier->Desktop->Desktopmanager->getDesktops($newDesktopId);

// initialisation des visas a ajouter au traitement
            $options = array(
                'insertion' => array(
                    '0' => array(
                        'Etape' => array(
                            'etape_nom' => $newDesktop[CAKEFLOW_TRIGGER_MODEL][CAKEFLOW_TRIGGER_FIELDS],
                            'etape_type' => 1
                        ),
                        'Visa' => array(
                            '0' => array(
                                'trigger_id' => $newDesktopId,
                                'type_validation' => 'V'
                            )
                        )
                    )
                )
            );
            $action = $this->request->data['Send']['getback'] ? 'IL' : 'IP';

            $success = false;

            if ($this->Courrier->cakeflowExecuteSend($action, $desktopId, $fluxId, $options)) {
                $success = true;
//                if (!empty($this->request->data['Comment']['content'])) {
                if (!empty($this->request->data['Comment']['objet'])) {
                    $datas = $this->request->data;
                    $datas['Comment']['owner_id'] = $this->Session->read('Auth.User.Courrier.Desktop.id');
                    $datas['Comment']['private'] = true;
                    $datas['Comment']['target_id'] = $fluxId;
                    $datas['Reader'] = array('Reader' => $desktopsReadersIds);

                    $success = $this->Courrier->Comment->save($datas) && $success;
                }
            }

            if (!empty($success)) {
                $this->Session->setFlash(__d('default', 'save.ok'), 'growl');
            } else {
                $this->Session->setFlash(__d('default', 'save.error'), 'growl');
            }
//fin circuit est une etape collaborative, ajouter une etape fictive concurrant
        } 
    }

    /**
     *
     */
    public function send($fluxId = null, $cpyOnly = false) {
        $this->set('sendwkf', $this->userAclCheck(array('model' => 'User', 'foreign_key' => $this->Session->read('Auth.User.id')), 'controllers/Courriers/sendwkf'));
        $this->set('sendcpy', $this->userAclCheck(array('model' => 'User', 'foreign_key' => $this->Session->read('Auth.User.id')), 'controllers/Courriers/sendcpy'));

        if (!empty($this->request->data)) {
//debug($this->request->data);
////die();
            if (isset($this->request->data['Send']['copy']) && $this->request->data['Send']['copy']) {
                $valid = array();
                $this->Jsonmsg->init();


                $flux = array();
                $desktopsFromManagerIds = array();
                $desktopsCopyFromManagerIds = array();

// On récupère les ids sélectionnés pour envoi pour copie
                $desktopCopyIds = Hash::get($this->request->data, 'Send.copy_id');
                $desktopCopyIds = ( empty($desktopCopyIds) ? array() : (array) $desktopCopyIds );
// On regarde le bureau sélectionné et on retourne les profils associés
                foreach ($desktopCopyIds as $desktopmanagercopyId) {
                    $desktopsCopyFromManagerIds[$desktopmanagercopyId] = $this->Courrier->Desktop->Desktopmanager->getDesktops($desktopmanagercopyId);
                }

                $desktopsIds = array();
                foreach ($desktopCopyIds as $i => $desktopmanager) {
                    $this->Desktopmanager = ClassRegistry::init('Desktopmanager');
                    $desktopsIds[] = $this->Desktopmanager->getDesktops($desktopmanager);
                }


                // Enregistrement des commentaires pour les flux (copie ou aiguillage)
                $readersCopyIds = Hash::extract($desktopsCopyFromManagerIds, '{n}.{n}');
                $readers = $readersCopyIds;
//                if (!empty($this->request->data['Comment']['content'])) {
                if (!empty($this->request->data['Comment']['objet'])) {
                    $datas = $this->request->data;
                    $this->request->data['Comment']['owner_id'] = $this->Session->read('Auth.User.Courrier.Desktop.id');
                    $this->request->data['Comment']['private'] = false;
                    $this->request->data['Comment']['target_id'] = $this->request->data['Send']['flux_id'];
                    $this->request->data['Reader'] = array('Reader' => $readers);
                    $this->request->data['Send']['flux_id'] = $fluxId;
                    $this->Courrier->Comment->saveAll($this->request->data);
                }





                foreach ($desktopsIds as $i => $desktopId) {
                    $success = true;
// Envoi des notifications pour chacun des bureaux en copie
                    $destId = array();
                    $notifInfos = $this->Courrier->Notifieddesktop->Notification->setNotification('ban_copy');
//                    $desktopId = $this->Session->read('Auth.User.desktop_id');
                    $desktopAuthId = $this->Session->read('Auth.User.Courrier.Desktop.id');
                    $fluxId = $this->request->data['Send']['flux_id'];


                    for ($d = 0; $d < count($desktopId); $d++) {
                        $notifyDesktops[$desktopId[$d]] = array($fluxId);
                        $notified = $this->Courrier->Notifieddesktop->Notification->add($notifInfos['name'], $notifInfos['description'], $notifInfos['typeNotif'], $desktopAuthId, $notifyDesktops);
// On ajoute le flux dans la bannette copie
                        $valid[$this->request->data['Send']['flux_id']] = array(
                            'add' => $this->Courrier->Bancontenu->add($desktopId[$d], BAN_COPY, $this->request->data['Send']['flux_id'])
                        );
                    }
                }

// Ajout pour les notifs durant le traitement
                foreach ($desktopCopyIds as $destinataire_id) {
                    $this->Desktopmanager = ClassRegistry::init('Desktopmanager');
                    $desktopsToSendIds = $this->Desktopmanager->getDesktops($destinataire_id);
                    foreach ($desktopsToSendIds as $deskId) {
                        if ($deskId != -1) {
                            $user_id = $this->Courrier->User->userIdByDesktop($deskId);
                            if (!empty($user_id)) {
                                $typeNotif = $this->Courrier->User->find(
                                        'first', array(
                                    'fields' => array('User.typeabonnement'),
                                    'conditions' => array('User.id' => $user_id),
                                    'contain' => false
                                        )
                                );
                                $notificationId = $this->Courrier->Notifieddesktop->Notification->id;
                                if ($typeNotif['User']['typeabonnement'] == 'quotidien') {
                                    $this->Courrier->User->saveNotif($this->request->data['Send']['flux_id'], $user_id, $notificationId, 'copy');
                                } else {
                                    $this->Courrier->User->notifier($this->request->data['Send']['flux_id'], $user_id, $notificationId, 'copy');
                                }
                            }
                        }
                    }
                }

                if ($valid == true) {
                    $this->Jsonmsg->valid();
                }

                $this->Jsonmsg->send();
            }
// envoi à la signature manuelle
// ajout d'une étape "fictive"
            else if (isset($this->request->data['Send']['signature_manuelle']) && $this->request->data['Send']['signature_manuelle']) {
//                $this->request->data['Send']['getback'] = fa;
                $this->request->data['Send']['desktop_id'] = $this->Session->read('Auth.User.Courrier.Desktop.id');
                $this->sendwkfsignaturemanuelle($this->request->data);
            } else {
                $this->sendwkf();
            }
        } else {

//            $allDesktops = $this->Courrier->Desktop->getDesktopsByService( 'all' );
// Récupération de la liste de tous les bureaux
            $allDesktops = $this->Courrier->User->Desktop->Desktopmanager->getAllDesktopsByProfils();
            $desktopsToSend = $this->Courrier->User->Desktop->Desktopmanager->getAllDesktopsByProfils(VALEDIT_GID, VAL_GID, ARCH_GID);

            $courrier = $this->Courrier->find('first', array(
                'fields' => array_merge(
                        $this->Courrier->Soustype->fields()
                ),
                'conditions' => array(
                    'Courrier.id' => $fluxId
                ),
                'joins' => array(
                    $this->Courrier->join('Soustype')
                ),
                'contain' => false
            ));
// on enlève les bureaux déjà présents dans le circuit pour les envois dans le circuit
            if (Configure::read('Conf.SAERP')) {
                $desktopsAlreadyInCircuit = $this->Courrier->getCircuitFromCourrier($fluxId);
                if (!empty($desktopsAlreadyInCircuit)) {
                    foreach ($desktopsToSend as $idDesktop => $name) {
                        if (in_array($idDesktop, $desktopsAlreadyInCircuit)) {
                            unset($desktopsToSend[$idDesktop]);
                        }
                    }
                    foreach ($allDesktops as $idAllDesktop => $nameAll) {
                        if (in_array($idAllDesktop, $desktopsAlreadyInCircuit)) {
                            unset($allDesktops[$idAllDesktop]);
                        }
                    }
                }
            } else {
//                $desktopsAlreadyInCircuit = $this->Courrier->Traitement->Circuit->desktopInCircuit($courrier['Soustype']['circuit_id']);
//                if (!empty($desktopsAlreadyInCircuit)) {
//                    foreach ($desktopsToSend as $idDesktop => $name) {
//                        if (in_array($idDesktop, $desktopsAlreadyInCircuit)) {
//                            unset($desktopsToSend[$idDesktop]);
//                        }
//                    }
//                }
            }
            $this->set('desktopsToSend', $desktopsToSend);
            $this->set('allDesktops', $allDesktops);
            $this->set('cpyOnly', $cpyOnly);
            $this->set('fluxId', $fluxId);
        }
    }

    /**
     * Envoi d'un flux à un aiguilleur
     *
     * @logical-group Flux
     * @user-profile User
     * @user-profile Aiguilleur
     *
     * @access public
     * @return void
     */
    public function dispsend() {
        $this->autoRender = false;
        if (!empty($this->request->data)) {
            $desktopId = $this->request->data['DispForm']['initDesktopService'];
            $flux = array();
            foreach ($this->request->data['DispForm'] as $key => $val) {
                if ($key != 'initDesktopService') {
                    if ($val == true) {
                        $tmp = explode('_', $key);
                        if ($tmp[0] == 'checkItem') {
                            $flux[] = $tmp[1];
                        }
                    }
                }
            }

            $groupId = $this->Courrier->Bancontenu->Desktop->field('Desktop.group_id', array('Desktop.id' => $desktopId));
            $dispDesktops = array_keys($this->getSessionDispDesktops());
            $senderDispId = $dispDesktops[0];
            $notifyDesktops = array($desktopId => $flux);
            if ($groupId == DISP_GID) {
                $valid = array();
                for ($i = 0; $i < count($flux); $i++) {
                    $valid[$flux[$i]] = array(
                        'end' => $this->Courrier->Bancontenu->end($senderDispId, BAN_AIGUILLAGE, $flux[$i]),
                        'add' => $this->Courrier->Bancontenu->add($desktopId, BAN_AIGUILLAGE, $flux[$i])
                    );
                }
            } else if ($groupId == INIT_GID) {
                $valid = array();
                for ($i = 0; $i < count($flux); $i++) {
                    $courrier = $this->Courrier->find('first', array('conditions' => array('Courrier.id' => $flux[$i])));
                    $courrier['Courrier']['desktop_creator_id'] = $desktopId;
                    $this->Courrier->create();
                    $this->Courrier->save($courrier);
                    $valid[$flux[$i]] = array(
                        'end' => $this->Courrier->Bancontenu->end($senderDispId, BAN_AIGUILLAGE, $flux[$i]),
                        'add' => $this->Courrier->Bancontenu->add($desktopId, BAN_DOCS, $flux[$i])
                    );
                }
                $notifInfos = $this->Courrier->Notifieddesktop->Notification->setNotification('ban_xnew');
                $this->Courrier->Notifieddesktop->Notification->add($notifInfos['name'], $notifInfos['description'], $notifInfos['typeNotif'], $this->Session->read('Auth.User.Courrier.Desktop.id'), $notifyDesktops);
            }
        }
    }

    /**
     * Suppression d'un flux
     *
     * @logical-group Flux
     * @user-profile User
     *
     * @param integer $id identifiant du flux
     * @throws NotFoundException
     */
    public function delete($id = null) {

        $this->autoRender = false;
        $this->Courrier->id = $id;
        if (!$this->Courrier->exists()) {
            throw new NotFoundException();
        }

        $deleteAll = array();
        $bancontenus = array_keys($this->Courrier->Bancontenu->find('list', array('conditions' => array('Bancontenu.courrier_id' => $id))));
        $this->Courrier->begin();

        // on stocke qui a supprimé quel flux
        $flux = $this->Courrier->find('first', array('conditions' => array('Courrier.id' => $id), 'contain' => false, 'recursive' => -1) );
        $this->loadModel('Journalevent');
        $datasSession = $this->Session->read('Auth.User');
        $msg = "L'utilisateur ". $this->Session->read('Auth.User.username'). " a supprimé le flux ".$flux['Courrier']['reference']." le ".date('d/m/Y à H:i:s');
        $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $flux);
        
        for ($i = 0; $i < count($bancontenus); $i++) {
            $deleteAll[] = $this->Courrier->Bancontenu->delete($bancontenus[$i]);
        }
        $deleteAll[] = $this->Courrier->delete($id);

        if (!in_array(false, $deleteAll, true)) {        
            $this->Courrier->commit();
            $this->Session->setFlash(__d('courrier', 'Courrier deleted', true), 'growl');
        } else {
            $this->Courrier->rollback();
            $this->Session->setFlash(__d('courrier', 'Courrier was not deleted', true), 'growl');
        }
        
        $this->redirect($_SERVER['HTTP_REFERER']);
    }


    /**
     * Vérification de la possibilité d'insertion d'un flux dans un circuit à la fin du wizard de création
     *
     * @logical-group Flux
     * @logical-group Création de flux
     * @user-profile User
     *
     * @access public
     * @param integer $id identifiant du flux
     * @return void
     */
    public function getInsertEnd($id) {
        $this->Courrier->id = $id;
        $courrier = $this->Courrier->find(
                'first', array(
            'fields' => array(
                'Courrier.id',
                'Courrier.soustype_id',
                'Soustype.id',
                'Soustype.circuit_id',
                'Document.id'
            ),
            'conditions' => array(
                'Courrier.id' => $id
            ),
            'joins' => array(
                $this->Courrier->join('Soustype', array('type' => 'LEFT OUTER')),
                $this->Courrier->join('Document', array('type' => 'LEFT OUTER'))
            ),
            'contain' => false
                )
        );
// Le circuit possède-t-il comme prochaine étape une délégation vers le parapheur ?
        $hasEtapeParapheur = $this->Courrier->Traitement->Circuit->hasEtapeDelegation($courrier['Soustype']['circuit_id']);
        $this->set(compact('hasEtapeParapheur'));
        $soustypeDefined = false;
        $canInsert = false;
        if (!empty($courrier['Courrier']["soustype_id"])) {
            $soustypeDefined = true;

            if (!empty($courrier['Soustype']["circuit_id"])) {
                $canInsert = true;
            }
            if ($hasEtapeParapheur) {
                if (!empty($courrier['Document']['id'])) {
                    $canInsert = true;
                } else {
                    $canInsert = false;
                }
            }
        }
        $this->set('courrier', $courrier);
        $this->set('soustypeDefined', $soustypeDefined);
        $this->set('canInsert', $canInsert);
    }

    /**
     * Récupération de la liste des accusés de réception
     *
     * @logical-group Flux
     * @logical-group Context
     * @user-profile User
     *
     * @access public
     * @param integer $fluxId identifiant du flux

     * @throws NotFoundException
     * @return void
     */
    public function getArs($fluxId) {
        $qdFlux = array(
            'conditions' => array(
                'Courrier.id' => $fluxId
            ),
            'contain' => array(
                'Soustype' => array(
                    'Armodel' => array(
                        'fields' => $this->Courrier->Soustype->Armodel->getLightFields(),
                        'order' => array('Armodel.name')
                    )
                )
            )
        );
        $flux = $this->Courrier->find('first', $qdFlux);

        if (empty($flux)) {
            throw new NotFoundException();
        }

        $qdAr = array(
            'fields' => $this->Courrier->Ar->getLightFields(),
            'recursive' => -1,
            'conditions' => array(
                'Ar.courrier_id' => $fluxId
            ),
            'order' => 'Ar.created DESC'
        );
        $ar = $this->Courrier->Ar->find('first', $qdAr);

        $this->set('ar', $ar);
        $this->set('armodels', !empty($flux['Soustype']['Armodel']) ? $flux['Soustype']['Armodel'] : array());
        $this->set('fluxId', $fluxId);

        $this->set('fromForbiddenLocation', $this->_isFromFobiddenLocation($flux));

        $this->set('right_sendmail', true);
    }

    /**
     * Génération d'un accusé de réception
     *
     * @logical-group Flux
     * @logical-group Context
     * @user-profile User
     *
     * @access public
     * @param integer $fluxId identifiant du flux

     * @throws NotFoundException
     * @return void
     */
    public function setArs($fluxId) {
        $qdFlux = array(
            'fields' => array('Courrier.id'),
            'recursive' => -1,
            'conditions' => array(
                'Courrier.id' => $fluxId
            )
        );
        $flux = $this->Courrier->find('first', $qdFlux);
        if (empty($flux)) {
            throw new NotFoundException();
        }

        $qdArmodel = array(
            'recursive' => -1,
            'conditions' => array(
                'Armodel.id' => $this->request->data['Armodel']['choice']
            )
        );
        $armodel = $this->Courrier->Soustype->Armodel->find('first', $qdArmodel);
        if (empty($armodel)) {
            throw new NotFoundException();
        }

        if (!empty($this->request->data)) {
            $this->Jsonmsg->init(__d('ar', 'Ar.generated.error'));
            $this->Courrier->Ar->begin();
            $this->Courrier->Ar->deleteAll(array('Ar.courrier_id' => $fluxId));
            $ar = array(
                'Ar' => array(
//                    'name' => '[AR] ' . $armodel['Armodel']['name'] . " " . date('YmdHis') . '.pdf',
                    'name' => '[AR] ' . $armodel['Armodel']['name'] . " " . date('YmdHis') . '.' . $armodel['Armodel']['ext'],
                    'format' => $armodel['Armodel']['format'],
                    'email_title' => $armodel['Armodel']['email_title'],
                    'email_content' => $armodel['Armodel']['email_content'],
                    'sms_content' => $armodel['Armodel']['sms_content'],
                    'courrier_id' => $fluxId
                )
            );

            if ($armodel['Armodel']['format'] == "ott") {
                $gedoooResult = $this->_generate($fluxId, array('name' => '[AR] ' . $armodel['Armodel']['name'], 'content' => $armodel['Armodel']['content']), null, $this->Session->read('Auth.User.id'));

                // Conversion en PDF
                $ar['Ar']['content'] = $gedoooResult['content'];
                $ar['Ar']['size'] = $gedoooResult['size'];
                $ar['Ar']['mime'] = $gedoooResult['mime'];
                $ar['Ar']['ext'] = $gedoooResult['ext'];
            } else if ($armodel['Armodel']['format'] == "video" || $armodel['Armodel']['format'] == "audio") {
//TODO: prendre en charge la gestion de la ged
                $ar['Ar']['content'] = $armodel['Armodel']['content'];
                $ar['Ar']['size'] = $armodel['Armodel']['size'];
                $ar['Ar']['mime'] = $armodel['Armodel']['mime'];
                $ar['Ar']['ext'] = $armodel['Armodel']['ext'];
            }

            $this->Courrier->Ar->create();
            $saved = $this->Courrier->Ar->save($ar);

            if ($saved) {
                $documentAr = array(
                    'Document' => array(
                        'name' => $ar['Ar']['name'],
                        'ext' => $ar['Ar']['ext'],
                        'size' => $ar['Ar']['size'],
                        'main_doc' => false,
                        'desktop_creator_id' => $this->Session->read('Auth.User.id'),
                        'courrier_id' => $fluxId,
                        'content' => $ar['Ar']['content'],
                        'mime' => $ar['Ar']['mime']
                    )
                );
                $this->Courrier->Document->create($documentAr);
                $saved = $this->Courrier->Document->save() && $saved;


                if ($saved) {
// Ajout du fichier généré dans le répertoire du webdav pour le webdav
                    $sessionFluxIdDir = WEBDAV_DIR . DS . $fluxId;
                    $Folder = new Folder($sessionFluxIdDir, true, 0777);
                    $generatedFile = file_put_contents($sessionFluxIdDir . DS . $documentAr['Document']['name'], $documentAr['Document']['content']);
                }
            }


            if (!empty($saved)) {
                $this->loadModel('Journalevent');
                $datasSession = $this->Session->read('Auth.User');
                $msg = "L'utilisateur ". $this->Session->read('Auth.User.username'). " a modifié le flux ".$flux['Courrier']['reference']." (génération de l'AR ".$ar['Ar']['name'].") le ".date('d/m/Y à H:i:s');
                $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $flux);
                
                
                $this->Courrier->Ar->commit();
                $this->Jsonmsg->valid(__d('ar', 'Ar.generated.ok'));
            } else {
                $this->Courrier->Ar->rollback();
            }
            $this->Jsonmsg->send();
        }
    }

    /**
     * Génération d'un document réponse à partir du modèle de document initial et des éléments (webdav) de réponse (composants de réponse)
     *
     * @logical-group Flux
     * @logical-group Context
     * @user-profile User
     *
     * @access public
     * @return void
     */
    public function genResponse() {
        if ($this->request->data) {
            $this->Jsonmsg->init();
            $fluxId = $this->request->data['ResponseDoc']['courrier_id'];
            if (isset($this->request->data['ResponseDoc']['rmodel_id'])) {
                $rmodelId = $this->request->data['ResponseDoc']['rmodel_id'];
            }
            if (isset($this->request->data['ResponseDoc']['gabarit_id'])) {
                $gabaritId = $this->request->data['ResponseDoc']['gabarit_id'];
            }

            if (!empty($gabaritId)) {
                $this->Gabaritdocument = ClassRegistry::init('Gabaritdocument');
                $this->Gabaritdocument->id = $gabaritId;
                $rmodel = array(
                    'name' => $this->Gabaritdocument->field('name', array('id' => $gabaritId)),
                    'content' => $this->Gabaritdocument->getFileContent($gabaritId)
                );
            } else if (!empty($rmodelId)) {
                $this->Courrier->Soustype->Rmodel->id = $rmodelId;
                $rmodel = array(
                    'name' => $this->Courrier->Soustype->Rmodel->field('name', array('id' => $rmodelId)),
                    'content' => $this->Courrier->Soustype->Rmodel->getFileContent($rmodelId)
                );
            }

            $relements = array();
            if (!empty($this->request->data['ResponseDoc']['Relement'])) {
                foreach ($this->request->data['ResponseDoc']['Relement'] as $key => $val) {
                    if ($val == 1) {
                        $name = $this->Courrier->Relement->field('Relement.name', array('Relement.id' => $key));
                        if (!empty($name)) {
                            $tab = array(
                                'id' => $key,
                                'name' => $name,
                                'content' => file_get_contents(WEBDAV_DIR . DS . $fluxId . DS . $name)
                            );
                            $relements[] = $tab;
                        }
                    }
                }
            }
            
            $name = $rmodel['name'];
            $name = preg_replace("/[: ]/", "_", $name);
            if (Configure::read('Conf.SAERP')) {
                $valueName = date('Ymd_Hi') . '_' . trim($name) . ".odt";
            } else {
                $valueName = date('Ymd_Hi') . '_' . $name;
            }
            $document = array(
                'Document' => array(
                    'name' => $valueName,
                    'courrier_id' => $fluxId
                )
            );
            $gedoooResult = $this->_generate($fluxId, $rmodel, $relements, $this->Session->read('Auth.User.id'));
            if (!empty($gedoooResult)) {
                $document['Document']['content'] = $gedoooResult['content'];
                $document['Document']['size'] = $gedoooResult['size'];
                $document['Document']['mime'] = $gedoooResult['mime'];
                $document['Document']['ext'] = $gedoooResult['ext'];
// Passage en doc principal pour les modèles de réponse générés
// car ils finiront par être adressés au parapheur
                $document['Document']['main_doc'] = true;
// Seul les créateurs de doc peuvent les supprimer
                $document['Document']['desktop_creator_id'] = $this->Session->read('Auth.User.id');

                $docPrincipalFlux = $this->Courrier->getMainDoc($fluxId);
                if (!empty($docPrincipalFlux)) {
                    $this->Courrier->Document->updateAll(
                            array('Document.main_doc' => false), array('Document.id' => $docPrincipalFlux['Document']['id'])
                    );
                }
                $this->Courrier->Document->create($document);
                $docSaved = $this->Courrier->Document->save();
                if (!empty($docSaved)) {
                    $flux = $this->Courrier->find(
                        'first',
                        array(
                            'conditions' => array(
                                'Courrier.id' => $fluxId
                            ),
                            'contain' => false,
                            'recursive' => -1
                        )
                    );
                    $this->loadModel('Journalevent');
                    $datasSession = $this->Session->read('Auth.User');
                    $msg = "L'utilisateur ". $this->Session->read('Auth.User.username'). " a modifié le flux ".$flux['Courrier']['reference']." (génération de la réponse ".$document['Document']['name'].") le ".date('d/m/Y à H:i:s');
                    $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $flux);
                
                    $this->Jsonmsg->valid();
                }

// Ajout du fichier généré dans le répertoire du webdav pour le webdav
                $sessionFluxIdDir = WEBDAV_DIR . DS . $fluxId;
                $Folder = new Folder($sessionFluxIdDir, true, 0777);
                $generatedFile = file_put_contents($sessionFluxIdDir . DS . $document['Document']['name'], $document['Document']['content']);
            }
            $this->Jsonmsg->send();
        }
    }

    /**
     * Génération de document odt via GED'OOo
     *
     * @access private
     * @param integer $courrier_id identifiant du flux
     * @param integer $soustype_id identifiant du sous-type
     * @return boolean
     */
    private function _generate($courrier_id, $model, $elements = null, $user_id) {
        $return = array();

//generation du fichier avec GedOOo
        App::import('Vendor', 'GDO_Utility', array('file' => 'GEDOOo' . DS . 'phpgedooo' . DS . 'GDO_Utility.class'));
        App::import('Vendor', 'GDO_FieldType', array('file' => 'GEDOOo' . DS . 'phpgedooo' . DS . 'GDO_FieldType.class'));
        App::import('Vendor', 'GDO_ContentType', array('file' => 'GEDOOo' . DS . 'phpgedooo' . DS . 'GDO_ContentType.class'));
        App::import('Vendor', 'GDO_IterationType', array('file' => 'GEDOOo' . DS . 'phpgedooo' . DS . 'GDO_IterationType.class'));
        App::import('Vendor', 'GDO_PartType', array('file' => 'GEDOOo' . DS . 'phpgedooo' . DS . 'GDO_PartType.class'));
        App::import('Vendor', 'GDO_FusionType', array('file' => 'GEDOOo' . DS . 'phpgedooo' . DS . 'GDO_FusionType.class'));
        App::import('Vendor', 'GDO_MatrixType', array('file' => 'GEDOOo' . DS . 'phpgedooo' . DS . 'GDO_MatrixType.class'));
        App::import('Vendor', 'GDO_MatrixRowType', array('file' => 'GEDOOo' . DS . 'phpgedooo' . DS . 'GDO_MatrixRowType.class'));
        App::import('Vendor', 'GDO_AxisTitleType', array('file' => 'GEDOOo' . DS . 'phpgedooo' . DS . 'GDO_AxisTitleType.class'));

        $u = new GDO_Utility();
//*****************************************
// Organisation des données
//*****************************************
        $oMainPart = new GDO_PartType();

        $querydata = array(
            'fields' => array_merge(
                    $this->Courrier->fields(), $this->Courrier->Contact->fields(), $this->Courrier->Contact->Ban->fields(), $this->Courrier->Contact->Bancommune->fields(), $this->Courrier->Organisme->fields(),
                    $this->Courrier->Soustype->fields(), $this->Courrier->Service->fields(), $this->Courrier->Soustype->Type->fields(), $this->Courrier->Soustype->Circuit->fields(), $this->Courrier->Affairesuivie->fields(), $this->Courrier->Affairesuivie->User->fields(), array(
                'Courrier.name',
                'Courrier.objet',
                'Courrier.date',
                'Courrier.datereception',
                'Courrier.reference',
                'Contact.name',
                'Type.name',
                'Soustype.name',
                'Soustype.delai_nb',
                'Soustype.delai_unite',
                'Circuit.nom'
                    )
            ),
            'contain' => false,
            'joins' => array(
                $this->Courrier->join($this->Courrier->Contact->alias, array('type' => 'LEFT OUTER')),
                $this->Courrier->Contact->join($this->Courrier->Contact->Ban->alias, array('type' => 'LEFT OUTER')),
                $this->Courrier->Contact->join($this->Courrier->Contact->Ban->Bancommune->alias, array('type' => 'LEFT OUTER')),
                $this->Courrier->join($this->Courrier->Organisme->alias, array('type' => 'LEFT OUTER')),
                $this->Courrier->join($this->Courrier->Soustype->alias, array('type' => 'LEFT OUTER')),
                $this->Courrier->join($this->Courrier->Service->alias, array('type' => 'LEFT OUTER')),
                $this->Courrier->Soustype->join($this->Courrier->Soustype->Type->alias, array('type' => 'LEFT OUTER')),
                $this->Courrier->Soustype->join($this->Courrier->Soustype->Circuit->alias, array('type' => 'LEFT OUTER')),
                $this->Courrier->join($this->Courrier->Affairesuivie->alias, array('type' => 'LEFT OUTER')),
                $this->Courrier->Affairesuivie->join($this->Courrier->Affairesuivie->User->alias, array('type' => 'LEFT OUTER'))
            ),
            'conditions' => array(
                'Courrier.id' => $courrier_id
            )
        );
        if (Configure::read('Conf.SAERP')) {
            $querydataSAERP = array(
                'joins' => array(
                    $this->Courrier->join($this->Courrier->Marche->alias, array('type' => 'LEFT OUTER')),
                    $this->Courrier->join($this->Courrier->Ordreservice->alias, array('type' => 'LEFT OUTER')),
                    $this->Courrier->join($this->Courrier->Pliconsultatif->alias, array('type' => 'LEFT OUTER')),
                    $this->Courrier->Soustype->Type->join($this->Courrier->Soustype->Type->Operation->alias, array('type' => 'LEFT OUTER')),
                    $this->Courrier->join($this->Courrier->Consultation->alias, array('type' => 'LEFT OUTER')),
                    $this->Courrier->Marche->join($this->Courrier->Marche->Contractant->alias, array('type' => 'LEFT OUTER')),
                    $this->Courrier->Marche->join($this->Courrier->Marche->Uniterif->alias, array('type' => 'LEFT OUTER'))
                ),
                'fields' => array_merge(
                        $this->Courrier->Marche->fields(), $this->Courrier->Ordreservice->fields(), $this->Courrier->Pliconsultatif->fields(), $this->Courrier->Soustype->Type->Operation->fields(), $this->Courrier->Consultation->fields(), $this->Courrier->Marche->Contractant->fields(), $this->Courrier->Marche->Uniterif->fields()
                )
            );
            $querydata['joins'] = array_merge($querydata['joins'], $querydataSAERP['joins']);
            $querydata['fields'] = array_merge($querydata['fields'], $querydataSAERP['fields']);
        }
        $courrier = $this->Courrier->find('first', $querydata);

        if (Configure::read('Conf.SAERP')) {
            if (!empty($courrier['Operation'])) {
                $associations = $this->Courrier->Soustype->Type->Operation->Intituleagentbyoperation->find(
                        'all', array(
                    'conditions' => array(
                        'Intituleagentbyoperation.operation_id' => $courrier['Operation']['id']
                    ),
                    'contain' => array(
                        'Desktopmanager' => array(
                            'Desktop'
                        ),
                        'Intituleagent'
                    )
                        )
                );

                foreach ($associations as $a => $assoc) {
                    $poste = strtolower($assoc['Intituleagent']['name']);
                    $fonction = $assoc['Intituleagent']['description'];
                    if (count($assoc['Desktopmanager']['Desktop']) != 0) {
                        for ($i = 0; $i < count($assoc['Desktopmanager']['Desktop']); $i++) {

                            $this->User = ClassRegistry::init('User');
                            $userDesktop = $this->User->find(
                                    'first', array(
                                'fields' => array(
                                    'User.nom',
                                    'User.prenom',
                                    'User.mail',
                                    'User.numtel',
                                    'User.username'
                                ),
                                'conditions' => array(
                                    'User.desktop_id' => $assoc['Desktopmanager']['Desktop'][$i]['id']
                                ),
                                'recursive' => -1
                                    )
                            );

                            if (!empty($userDesktop)) {
                                $usernameDesktop = $userDesktop['User']['prenom'] . ' ' . $userDesktop['User']['nom'];
                                $usernameTel = $userDesktop['User']['numtel'];
                                $usernameMail = $userDesktop['User']['mail'];
                                $words = explode(" ", $usernameDesktop);
                                $inits = '';
//loop through array extracting initial letters
                                foreach ($words as $word) {
                                    $inits.=strtoupper(substr($word, 0, 1));
                                }
                                $usernameInits = $inits;
//                                $initials = $inits;
                            } else {
                                $secondaryUserDesktop = $this->Courrier->Desktop->DesktopsUser->find(
                                        'first', array(
                                    'fields' => array(
                                        'DesktopsUser.user_id'
                                    ),
                                    'conditions' => array(
                                        'DesktopsUser.desktop_id' => $assoc['Desktopmanager']['Desktop'][$i]['id']
                                    ),
                                    'contain' => false
                                        )
                                );
                                if (!empty($secondaryUserDesktop)) {
                                    $secondaryUserDesktopUser = $this->User->find(
                                            'first', array(
                                        'fields' => array(
                                            'User.nom',
                                            'User.prenom',
                                            'User.mail',
                                            'User.numtel',
                                            'User.username'
                                        ),
                                        'conditions' => array(
                                            'User.id' => $secondaryUserDesktop['DesktopsUser']['user_id']
                                        ),
                                        'recursive' => -1
                                            )
                                    );

                                    if (!empty($secondaryUserDesktopUser)) {
                                        $usernameDesktop = $secondaryUserDesktopUser['User']['prenom'] . ' ' . $secondaryUserDesktopUser['User']['nom'];
                                        $usernameTel = $secondaryUserDesktopUser['User']['numtel'];
                                        $usernameMail = $secondaryUserDesktopUser['User']['mail'];
                                        $words = explode(" ", $usernameDesktop);
                                        $inits = '';
//loop through array extracting initial letters
                                        foreach ($words as $word) {
                                            $inits.=strtoupper(substr($word, 0, 1));
                                        }
                                        $usernameInits = $inits;
                                    }
                                }
                            }
                            $names = $usernameDesktop;
                            $tels = $usernameTel;
                            $mails = $usernameMail;
                            $initials = $usernameInits;
                        }
                        $oMainPart->addElement(new GDO_FieldType("operation_{$poste}", $names, 'text'));
                        $oMainPart->addElement(new GDO_FieldType("operation_{$poste}tel", $tels, 'text'));
                        $oMainPart->addElement(new GDO_FieldType("operation_{$poste}mail", $mails, 'text'));
                        $oMainPart->addElement(new GDO_FieldType("operation_{$poste}fonction", $fonction, 'text'));
                        $oMainPart->addElement(new GDO_FieldType("operation_{$poste}initials", $initials, 'text'));
                    } else {
                        $oMainPart->addElement(new GDO_FieldType("operation_{$poste}", $assoc['Desktopmanager']['Desktop'][0]['name'], 'text'));
                        $oMainPart->addElement(new GDO_FieldType("operation_{$poste}tel", $assoc['Desktopmanager']['Desktop'][0]['name'], 'text'));
                        $oMainPart->addElement(new GDO_FieldType("operation_{$poste}mail", $assoc['Desktopmanager']['Desktop'][0]['name'], 'text'));
                        $oMainPart->addElement(new GDO_FieldType("operation_{$poste}fonction", $fonction, 'text'));
                        $oMainPart->addElement(new GDO_FieldType("operation_{$poste}initials", $initials, 'text'));
                    }
                }

//                debug($associations);
//                die();
            }
        }
//debug($courrier);
//die();
// Récuéprationd e sifnos de l'affaire suviie par
        $affairesuivieDesktop = $this->Courrier->Desktop->find('first', array(
            'conditions' => array(
                'Desktop.id' => $courrier['Courrier']['affairesuiviepar_id']
            ),
            'recursive' => -1
        ));


//debug($affairesuivieDesktop);

        $this->User = ClassRegistry::init('User');
        $userAffaire = $this->User->find('first', array(
            'fields' => array(
                'User.nom',
                'User.prenom',
                'User.mail',
                'User.numtel',
                'User.username'
            ),
            'conditions' => array(
                'User.desktop_id' => $courrier['Courrier']['affairesuiviepar_id']
            ),
            'recursive' => -1
        ));

        if (!empty($userAffaire)) {
            $courrier['Affairesuivie']['name'] = $userAffaire['User']['prenom'] . ' ' . $userAffaire['User']['nom'];
            $courrier['Affairesuivie']['tel'] = $userAffaire['User']['numtel'];
            $courrier['Affairesuivie']['mail'] = $userAffaire['User']['mail'];
            $extractName = explode(" ", $courrier['Affairesuivie']['name']);
            $initials = '';
            foreach ($extractName as $extract) {
                $initials.=strtoupper(substr($extract, 0, 1));
            }
            $affairesuivieInits = $initials;
            $courrier['Affairesuivie']['initiales'] = $affairesuivieInits;
        } else {
            $secondaryDesktop = $this->Courrier->Desktop->DesktopsUser->find('first', array(
                'fields' => array(
                    'DesktopsUser.user_id'
                ),
                'conditions' => array(
                    'DesktopsUser.desktop_id' => $courrier['Courrier']['affairesuiviepar_id']
                ),
                'contain' => false
            ));
            if (!empty($secondaryDesktop)) {
                $secondaryDesktopUser = $this->User->find('first', array(
                    'fields' => array(
                        'User.nom',
                        'User.prenom',
                        'User.mail',
                        'User.numtel',
                        'User.username'
                    ),
                    'conditions' => array(
                        'User.id' => $secondaryDesktop['DesktopsUser']['user_id']
                    ),
                    'recursive' => -1
                ));

                if (!empty($secondaryDesktopUser)) {
                    $courrier['Affairesuivie']['name'] = $secondaryDesktopUser['User']['prenom'] . ' ' . $secondaryDesktopUser['User']['nom'];
                    $courrier['Affairesuivie']['tel'] = $secondaryDesktopUser['User']['numtel'];
                    $courrier['Affairesuivie']['mail'] = $secondaryDesktopUser['User']['mail'];
                    $extractName = explode(" ", $courrier['Affairesuivie']['name']);
                    $initials = '';
                    foreach ($extractName as $extract) {
                        $initials.=strtoupper(substr($extract, 0, 1));
                    }
                    $affairesuivieInits = $initials;
                    $courrier['Affairesuivie']['initiales'] = $affairesuivieInits;
                }
            }
        }

        $metadonnees = $this->Courrier->CourrierMetadonnee->find('all', array(
            'fields' => array_merge(
                    $this->Courrier->CourrierMetadonnee->fields(), $this->Courrier->CourrierMetadonnee->Metadonnee->fields()
            ),
            'conditions' => array(
                'CourrierMetadonnee.courrier_id' => $courrier_id
            ),
            'joins' => array(
                $this->Courrier->CourrierMetadonnee->join('Metadonnee', array('type' => 'LEFT OUTER'))
            ),
            'recursive' => -1,
            'order' => array('Metadonnee.name ASC')
        ));
        if (!empty($metadonnees)) {
            $metas = array();
            $courrier['Courrier']['listemetadonnees'] = implode(', ', Hash::extract($metadonnees, '{n}.Metadonnee.name'));
            foreach ($metadonnees as $key => $metadonnee) {
                if ($metadonnee['Metadonnee']['typemetadonnee_id'] == 3) {
                    if ($metadonnee['CourrierMetadonnee']['valeur'] == 1) {
                        $metadonnee['CourrierMetadonnee']['valeur'] = 'Réalisé';
                    } else {
                        $metadonnee['CourrierMetadonnee']['valeur'] = 'Non réalisé';
                    }
                } else if ($metadonnee['Metadonnee']['typemetadonnee_id'] == Configure::read('Selectvaluemetadonnee.id')) {
                    $selectvaluemetadonnee = $this->Courrier->Metadonnee->Selectvaluemetadonnee->find('first', array(
                        'fields' => array(
                            'Selectvaluemetadonnee.name'
                        ),
                        'conditions' => array(
                            'Selectvaluemetadonnee.id' => $metadonnee['CourrierMetadonnee']['valeur']
                        ),
                        'contain' => false
                    ));
                    if (!empty($selectvaluemetadonnee)) {
                        $metadonnee['CourrierMetadonnee']['valeur'] = $selectvaluemetadonnee['Selectvaluemetadonnee']['name'];
                    }
                }
                if (!empty($metadonnee['Metadonnee']['champfusion'])) {
                    $name = $metadonnee['Metadonnee']['champfusion'];
                    $metas['valeurmet'][$key] = $metadonnee['CourrierMetadonnee']['valeur'];
                    $oMainPart->addElement(new GDO_FieldType("metadonnee_{$name}", $metas['valeurmet'][$key], 'text'));
                } else {
                    $metas['valeurmet'][$key] = $metadonnee['Metadonnee']['name'] . ': ' . $metadonnee['CourrierMetadonnee']['valeur'];
                    $oMainPart->addElement(new GDO_FieldType("metadonnee_{$key}_name", $metas['valeurmet'][$key], 'text'));
                }
//debug($selectvaluemetadonnee);
//debug($name);
            }
            $courrier['Courrier']['listemetadonnees'] = implode(', ', Hash::extract($metas, 'valeurmet'));
        }

        $user = $this->Courrier->User->find('first', array(
            'conditions' => array(
                'User.id' => $user_id
            ),
            'contain' => array(
                'Desktop' => array(
                    'Service'
                )
            )
        ));

        $courrier = Hash::merge($courrier, $user);

// Gestion des différents services liés à l'utilisateur
        $type_id = $courrier['Type']['id'];
        $soustype_id = $courrier['Soustype']['id'];
// en fonction du sous-type, on regarde les droits attribués à ce sous-type
        $daco = $this->Daco->find('first', array(
            'conditions' => array(
                'Daco.foreign_key' => $soustype_id
            ),
            'contain' => false
        ));
        if (!empty($daco)) {
            $daco_id = $daco['Daco']['id'];
        }

// On regarde les services associés au(x) bureau(x) de l'utilisateur
        $servicesIds = Hash::extract($courrier, 'Desktop.Service.{n}.id');

// pour chaque service, on regarde les droits qui lui sont attribués
        $daros = $this->Daro->find('all', array(
            'conditions' => array(
                'Daro.foreign_key' => $servicesIds
            ),
            'contain' => false
        ));

        if (!empty($daros)) {
            $darosids = Hash::extract($daros, '{n}.Daro.id');
        }

        if (!empty($darosids) && !empty($daco_id)) {
            $this->DarosDaco = ClassRegistry::init('DarosDaco');
// pour chaque droit du service (darosids), on vérifie si les droits d'accès au sous -type (daco_id) sont autorisés pour ce(s) service(s)
            $darodaco = $this->DarosDaco->find('first', array(
                'conditions' => array(
                    'DarosDaco.daco_id' => $daco_id,
                    'DarosDaco.daro_id' => $darosids
                ),
                'contain' => false
            ));
            if (!empty($darodaco)) {
                $darodaco_service_id = $darodaco['Daro']['foreign_key'];
            }
        }

        if (!empty($darodaco_service_id)) {
// on récupère donc l'ID du service concerné par le sous-type défini et on retourne son nom
            $this->Service = ClassRegistry::init('Service');
            $service = $this->Service->find('first', array(
                'conditions' => array(
                    'Service.id' => $darodaco_service_id
                ),
                'contain' => false
            ));
            $serviceName = $service['Service']['name'];
        } else {
            $serviceName = '';
        }

// Infos sur la collectivité
        $collectivite = ClassRegistry::init('Collectivite')->find('first', array(
            'fields' => array(
                'Collectivite.name',
                'Collectivite.logo',
                'Collectivite.siren',
                'Collectivite.adresse',
                'Collectivite.codeinsee',
                'Collectivite.codepostal',
                'Collectivite.ville',
                'Collectivite.complementadresse',
                'Collectivite.telephone'
            ),
            'conditions' => array(
                'Collectivite.conn' => $this->Session->read('Auth.User.connName')
            ),
            'contain' => false
        ));

// Gestion du cas de l'adresse reprise sur le document
        if (empty($courrier['Contact']['id'])) {
            if (!empty($courrier['Organisme']['banadresse'])) {
                $courrier['Contact']['adresse'] = $courrier['Organisme']['numvoie'] . ' ' . $courrier['Organisme']['banadresse'];
            } else {
                $courrier['Contact']['adresse'] = $courrier['Organisme']['numvoie'] . ' ' . $courrier['Organisme']['nomvoie'];
            }
            $courrier['Contact']['cp'] = $courrier['Organisme']['cp'];
            $courrier['Contact']['ville'] = $courrier['Organisme']['ville'];
        } else {
            $courrier['Contact']['adresse'] = $courrier['Contact']['adresse'];
            $courrier['Contact']['cp'] = $courrier['Contact']['cp'];
            $courrier['Contact']['ville'] = $courrier['Contact']['ville'];
        }

        $civiliteOptions = array(
            1 => 'Monsieur',
            2 => 'Madame',
            3 => 'Monsieur et Madame'
        );
        $civilite = Hash::get($civiliteOptions, $courrier['Contact']['civilite']);
//debug($civilite);
//die();
// Information sur le courrier envoyée à Gedooo
        $oMainPart->addElement(new GDO_FieldType('courrier_name', $courrier['Courrier']['name'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('courrier_objet', $courrier['Courrier']['objet'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('courrier_reference', $courrier['Courrier']['reference'], 'text'));
// Affaire suivie par
        $oMainPart->addElement(new GDO_FieldType('affairesuivie_name', $courrier['Affairesuivie']['name'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('affairesuivie_tel', isset($courrier['Affairesuivie']['tel']) ? $courrier['Affairesuivie']['tel'] : '', 'text'));
        $oMainPart->addElement(new GDO_FieldType('affairesuivie_mail', isset($courrier['Affairesuivie']['mail']) ? $courrier['Affairesuivie']['mail'] : '', 'text'));
        $oMainPart->addElement(new GDO_FieldType('affairesuivie_ini', isset($courrier['Affairesuivie']['initiales']) ? $courrier['Affairesuivie']['initiales'] : '', 'text'));

        $date_tmp = explode("-", $courrier['Courrier']['date']);
        $date = $date_tmp[2] . "/" . $date_tmp[1] . "/" . $date_tmp[0];
        $oMainPart->addElement(new GDO_FieldType('courrier_date', $date, 'date'));

        $date_reception_tmp = explode("-", $courrier['Courrier']['datereception']);
        $date_reception = $date_reception_tmp[2] . "/" . $date_reception_tmp[1] . "/" . $date_reception_tmp[0];
        $oMainPart->addElement(new GDO_FieldType('courrier_datereception', $date_reception, 'date'));

        $oMainPart->addElement(new GDO_FieldType('courrier_emetteur', $courrier['Contact']['name'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('courrier_type', $courrier['Type']['name'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('courrier_soustype', $courrier['Soustype']['name'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('courrier_circuit', $courrier['Circuit']['nom'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('service_name', isset($serviceName) ? $serviceName : $courrier['Service']['name'], 'text'));
        if (!empty($metadonnees)) {
            $oMainPart->addElement(new GDO_FieldType('courrier_metadonnee', $courrier['Courrier']['listemetadonnees'], 'text'));
        }

        if ($courrier['Contact']['nom'] == '0Sans contact') {
            $contactName = '';
        } else {
            $contactName = $courrier['Contact']['name'];
        }

// Information sur la personne ayant contacté la collectivité
        $oMainPart->addElement(new GDO_FieldType('contact_name', $contactName, 'text'));
//        $oMainPart->addElement(new GDO_FieldType('contactinfo_civilite', $courrier['Contact']['civilite'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('contactinfo_civilite', $civilite, 'text'));
        $oMainPart->addElement(new GDO_FieldType('contactinfo_nom', !empty($contactName) ? $courrier['Contact']['nom'] : '', 'text'));
        $oMainPart->addElement(new GDO_FieldType('contactinfo_prenom', !empty($contactName) ? $courrier['Contact']['prenom'] : '', 'text'));
        $oMainPart->addElement(new GDO_FieldType('contactinfo_numvoie', $courrier['Contact']['numvoie'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('contactinfo_nomvoie', $courrier['Contact']['nomvoie'], 'text'));
//        $oMainPart->addElement(new GDO_FieldType('contactinfo_banadresse', $courrier['Contact']['banadresse'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('contactinfo_adresse', $courrier['Contact']['adresse'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('contactinfo_compl', $courrier['Contact']['compl'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('contactinfo_cp', $courrier['Contact']['cp'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('contactinfo_email', $courrier['Contact']['email'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('contactinfo_ville', !empty($courrier['Bancommune']['name']) ? $courrier['Bancommune']['name'] : $courrier['Contact']['ville'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('contactinfo_departement', $courrier['Ban']['name'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('contactinfo_pays', $courrier['Contact']['pays'], 'text'));

        $oMainPart->addElement(new GDO_FieldType('contactinfo_tel', $courrier['Contact']['tel'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('contactinfo_role', $courrier['Contact']['role'], 'text'));

        if ($courrier['Organisme']['name'] == 'Sans organisme') {
            $organismeName = '';
        } else {
            $organismeName = $courrier['Organisme']['name'];
        }
        
        $oMainPart->addElement(new GDO_FieldType('contactinfo_organisation', $organismeName, 'text'));
        $oMainPart->addElement(new GDO_FieldType('organisme_name', $organismeName, 'text'));
        $oMainPart->addElement(new GDO_FieldType('organisme_adressecomplete', $courrier['Organisme']['adressecomplete'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('organisme_numvoie', $courrier['Organisme']['numvoie'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('organisme_nomvoie', $courrier['Organisme']['nomvoie'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('organisme_compl', $courrier['Organisme']['compl'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('organisme_cp', $courrier['Organisme']['cp'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('organisme_ville', $courrier['Organisme']['ville'], 'text'));
//        $oMainPart->addElement(new GDO_FieldType('organisme_ville', !empty( $courrier['Bancommune']['name'] ) ? $courrier['Bancommune']['name'] : $courrier['Organisme']['ville'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('organisme_email', $courrier['Organisme']['email'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('organisme_tel', $courrier['Organisme']['tel'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('organisme_portable', $courrier['Organisme']['portable'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('organisme_fax', $courrier['Organisme']['fax'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('organisme_pays', $courrier['Organisme']['pays'], 'text'));

// Information sur l'utilsiateur connecté
        $oMainPart->addElement(new GDO_FieldType('user_username', $user['User']['username'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('user_nom', $user['User']['nom'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('user_prenom', $user['User']['prenom'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('user_mail', $user['User']['mail'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('user_numtel', $user['User']['numtel'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('desktop_name', $user['Desktop']['name'], 'text'));

// Information sur la collectivité de l'utilsiateur
        $oMainPart->addElement(new GDO_FieldType('collectivite_name', $collectivite['Collectivite']['name'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('collectivite_logo', $collectivite['Collectivite']['logo'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('collectivite_siren', $collectivite['Collectivite']['siren'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('collectivite_adresse', $collectivite['Collectivite']['adresse'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('collectivite_codeinsee', $collectivite['Collectivite']['codeinsee'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('collectivite_codepostal', $collectivite['Collectivite']['codepostal'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('collectivite_ville', $collectivite['Collectivite']['ville'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('collectivite_complementadresse', $collectivite['Collectivite']['complementadresse'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('collectivite_telephone', $collectivite['Collectivite']['telephone'], 'text'));

// Information sur le type/sous type du courrier
        $delaiunite = '';
        if ($courrier['Soustype']['delai_unite'] == '0') {
            $delaiunite = 'jour(s)';
        } else if ($courrier['Soustype']['delai_unite'] == '1') {
            $delaiunite = 'semaine(s)';
        }
        if ($courrier['Soustype']['delai_unite'] == '2') {
            $delaiunite = 'mois';
        }

        $direction = 'entrant';
        if ($courrier['Soustype']['entrant'] == '0') {
            $direction = 'sortant';
        }
        $oMainPart->addElement(new GDO_FieldType('type_name', $courrier['Type']['name'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('soustype_name', $courrier['Soustype']['name'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('soustype_delai_nb', $courrier['Soustype']['delai_nb'], 'text'));
        $oMainPart->addElement(new GDO_FieldType('soustype_delai_unite', $delaiunite, 'text'));
        $oMainPart->addElement(new GDO_FieldType('soustype_direction', $direction, 'text'));

        if (Configure::read('Conf.SAERP')) {
            if (!empty($courrier['Operation']['name'])) {
                $oMainPart->addElement(new GDO_FieldType('operation_name', $courrier['Operation']['name'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('operation_numero', $courrier['Operation']['name'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('operation_nomoperation', $courrier['Operation']['nomoperation'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('operation_ville', $courrier['Operation']['ville'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('operation_numvoie', $courrier['Operation']['numvoie'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('operation_nomvoie', $courrier['Operation']['nomvoie'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('operation_compl', $courrier['Operation']['compl'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('operation_codepostal', $courrier['Operation']['codepostal'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('operation_commune', $courrier['Operation']['commune'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('operation_numconvention', $courrier['Operation']['numconvention'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('operation_nature', $courrier['Operation']['nature'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('operation_lieu', $courrier['Operation']['lieu'], 'text'));
            }
            if (!empty($courrier['Marche']['name'])) {
                $oMainPart->addElement(new GDO_FieldType('marche_name', $courrier['Marche']['name'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('marche_numero', $courrier['Marche']['numero'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('marche_objet', $courrier['Marche']['objet'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('marche_chrono', $courrier['Marche']['chrono'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('marche_titulaire', $courrier['Marche']['titulaire'], 'text'));

                $datemarche_tmp = explode("-", $courrier['Marche']['datelimite']);
                if (!empty($courrier['Marche']['datelimite'])) {
                    $datemarche = $datemarche_tmp[2] . "/" . $datemarche_tmp[1] . "/" . $datemarche_tmp[0];
                } else {
                    $datemarche = '';
                }
                $oMainPart->addElement(new GDO_FieldType('marche_datelimite', $datemarche, 'date'));
                $oMainPart->addElement(new GDO_FieldType('marche_heurelimite', $courrier['Marche']['heurelimite'], 'text'));
            }
            if (!empty($courrier['Pliconsultatif']['name'])) {
                $oMainPart->addElement(new GDO_FieldType('pli_name', $courrier['Pliconsultatif']['name'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('pli_numero', $courrier['Pliconsultatif']['numero'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('pli_objet', $courrier['Pliconsultatif']['objet'], 'text'));

                $datepli_tmp = explode("-", $courrier['Pliconsultatif']['date']);
                $datepli = $datepli_tmp[2] . "/" . $datepli_tmp[1] . "/" . $datepli_tmp[0];
                $oMainPart->addElement(new GDO_FieldType('pli_date', $datepli, 'date'));
                $oMainPart->addElement(new GDO_FieldType('pli_heure', $courrier['Pliconsultatif']['heure'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('pli_lot', $courrier['Pliconsultatif']['lot'], 'text'));
            }
            if (!empty($courrier['Ordreservice']['name'])) {
                $oMainPart->addElement(new GDO_FieldType('os_name', $courrier['Ordreservice']['name'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('os_numero', $courrier['Ordreservice']['numero'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('os_objet', $courrier['Ordreservice']['objet'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('os_montant', $courrier['Ordreservice']['montant'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('os_organisme', $courrier['Organisme']['name'], 'text'));
            }
            if (!empty($courrier['Contractant']['name'])) {
                $oMainPart->addElement(new GDO_FieldType('contractant_name', $courrier['Contractant']['name'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('contractant_description', $courrier['Contractant']['description'], 'text'));
            }
            if (!empty($courrier['Uniterif']['name'])) {
                $oMainPart->addElement(new GDO_FieldType('uniterif_name', $courrier['Uniterif']['name'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('uniterif_description', $courrier['Uniterif']['description'], 'text'));
            }
            if (!empty($courrier['Consultation']['name'])) {
                $oMainPart->addElement(new GDO_FieldType('consultation_name', $courrier['Consultation']['name'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('consultation_numero', $courrier['Consultation']['numero'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('consultation_objet', $courrier['Consultation']['objet'], 'text'));
                $oMainPart->addElement(new GDO_FieldType('consultation_chrono', $courrier['Consultation']['chrono'], 'text'));
//                $oMainPart->addElement(new GDO_FieldType('consultation_titulaire', $courrier['Consultation']['titulaire'], 'text'));

                $dateconsultation_tmp = explode("-", $courrier['Consultation']['datelimite']);
                $dateconsultation = $dateconsultation_tmp[2] . "/" . $dateconsultation_tmp[1] . "/" . $dateconsultation_tmp[0];
                $oMainPart->addElement(new GDO_FieldType('consultation_datelimite', $dateconsultation, 'date'));
                $oMainPart->addElement(new GDO_FieldType('consultation_heurelimite', $courrier['Consultation']['heurelimite'], 'text'));
            }
        }


//inclusion des fichiers webdav
        if (!empty($elements)) {
            $idToUse = '';
            foreach ($this->request->data['ResponseDoc']['Relement'] as $idrelement => $value) {
                if ($value == "1") {
                    $idToUse = $idrelement;
                }
            }
            $documents = new GDO_IterationType("documents");
            foreach ($elements as $element) {
                if ($element['id'] == $idToUse) {
                    $oDevPart = new GDO_PartType();
                    $oDevPart->addElement(new GDO_ContentType("document", "", "application/vnd.oasis.opendocument.text", "binary", $element['content']));
                    $documents->addPart($oDevPart);
                }
            }
            $oMainPart->addElement($documents);
        }

//On charge le fichier
//TODO: prevoir la gestion de la ged
        $oTemplate = new GDO_ContentType("", Inflector::slug($model['name']) . $courrier_id . "_" . date('YmdHis') . ".odt", "application/vnd.oasis.opendocument.text", "binary", $model['content']);



// Debug: plugin Gedooo2
// Gedooo
        /* CakePlugin::load('Gedooo2');
          App::uses( 'Gedooo2Debugger', 'Gedooo2.Utility' );
          Configure::write(
          'Gedooo2',
          array(
          'debugHashPathsToCsv' => true,
          'debugAllPathsToCsv' => true,
          'debugAllPathsValuesToCsv' => true,
          )
          );
          debug( Gedooo2Debugger::hashPathsToCsv( $oMainPart ) );
          debug( Gedooo2Debugger::allPathsToCsv( $oMainPart, Configure::read( 'Gedooo2.debugAllPathsValuesToCsv' ) === true ) );
          die(); */

//Fusion
        $oFusion = new GDO_FusionType($oTemplate, "application/vnd.oasis.opendocument.text", $oMainPart);
        $oFusion->process();

        $success = ( $oFusion->getCode() == 'OK' );
        if ($success) {
            $content = $oFusion->getContent();

            $return['content'] = $content->binary;
            $return['size'] = strlen($return['content']);
            $return['ext'] = 'odt';
            $return['mime'] = 'application/vnd.oasis.opendocument.text';
//            }
        }


        return $return;
    }

    /**
     * Récupération du panneau contextuel
     *
     * @logical-group Flux
     * @logical-group Context
     * @user-profile User
     *
     * @access public
     * @param integer $fluxId identifiant du flux

     * @throws NotFoundException
     * @return void
     */
    public function getContext($fluxId) {
        $qdFlux = array(
            'conditions' => array(
                'Courrier.id' => $fluxId
            ),
            'contain' => array(
                'Document' => array(
                    'conditions' => array('Document.main_doc' => false)
                )
            ),
            'fields' => array('Courrier.id')
        );
        $flux = $this->Courrier->find('first', $qdFlux);

        if (empty($flux)) {
            throw new NotFoundException();
        }

//		TODO: utiliser $this->Acl->check
        $rights = array('getDocuments' => ($this->userAclCheck(array('model' => 'User', 'foreign_key' => $this->Session->read('Auth.User.id')), 'controllers/Courriers/getDocuments') ? true : false));
        $this->set('mainDoc', $this->Courrier->getMainDoc($fluxId));
        $this->set('rights', $rights);
        $this->set('fluxId', $fluxId);
        $this->set('documents', $flux['Document']);


//		BAN_AIGUILLAGE
        $qd = array(
            'recursive' => -1,
            'conditions' => array(
                'Bancontenu.bannette_id' => BAN_AIGUILLAGE,
                'Bancontenu.courrier_id' => $fluxId,
                'Bancontenu.desktop_id' => $this->SessionTools->getDesktopList(),
                'Bancontenu.etat' => 1
            )
        );
        $result = $this->Courrier->Bancontenu->find('first', $qd);
        if (!empty($result) && count($result) == 1) {
            $this->Courrier->Bancontenu->setRead($result['Bancontenu']['courrier_id'], $result['Bancontenu']['desktop_id']);
        }

        $fromMesServices = false;
        $fluxMesServices = $this->Session->read('Auth.User.Courrier.mesServices');

        if (!empty($fluxMesServices)) {
            if (in_array($fluxId, $fluxMesServices) && !in_array($this->Session->read('Auth.User.Courrier.Desktop.id'), $this->SessionTools->getDesktopList())) {
                $fromMesServices = true;
            }
        }
        $this->set('fromMesServices', $fromMesServices);
    }

    /**
     * Récupération des composants de réponse
     *
     * @logical-group Flux
     * @logical-group Context
     * @user-profile User
     *
     * @access public
     * @param integer $fluxId identifiant du flux

     * @throws NotFoundException
     * @return void
     */
    public function getRelements($fluxId) {
//		if (!is_integer($fluxId) || $fluxId <= 0) {
//			throw new BadMethodCallException();
//		}
        $qdFlux = array(
            'recursive' => -1,
            'conditions' => array(
                'Courrier.id' => $fluxId
            ),
            'fields' => array(
                'Courrier.id',
                'Courrier.soustype_id'
            )
        );
        $flux = $this->Courrier->find('first', $qdFlux);
        if (empty($flux)) {
            throw new NotFoundException();
        }
        if (Configure::read('Conf.SAERP')) {
            $this->Gabaritdocument = ClassRegistry::init('Gabaritdocument');
            $qdRmodels = array(
                'recursive' => -1,
                'fields' => $this->Gabaritdocument->getLightFields(),
                'order' => array('Gabaritdocument.name ASC')
            );
            $rmodels = $this->Gabaritdocument->find('all', $qdRmodels);
            $this->set('rmodels', $rmodels);
        } else {
//debug($gabarits);
            $qdRmodels = array(
                'recursive' => -1,
                'fields' => $this->Courrier->Soustype->Rmodel->getLightFields(),
                'conditions' => array(
                    'Rmodel.soustype_id' => $flux['Courrier']['soustype_id']
                )
            );
            $rmodels = $this->Courrier->Soustype->Rmodel->find('all', $qdRmodels);
            $this->set('rmodels', $rmodels);
        }
// 2. Recherche des fichiers déjà liés*
        $qdRelements = array(
            'recursive' => -1,
            'conditions' => array(
                'Relement.courrier_id' => $flux['Courrier']['id']
            ),
            'fields' => array(
                'Relement.id',
                'Relement.name',
                'Relement.mime',
                '( \'' . WEBDAV_DIR . DS . '\' || "Relement"."courrier_id" || \'' . DS . '\' || "Relement"."name" ) AS "Relement__path"'
            )
        );
        $relements = $this->Courrier->Relement->find('all', $qdRelements);

// Ajouter un modèle ODT "type" par défaut
        $fichiers = array();
        $modeleDir = WEBDAV_DIR . DS . 'modeles';
        $Folder = new Folder($modeleDir, false, 0777);
        foreach ($Folder->find('.+\.odt$') as $i => $fileName) {
            $fichiers[$i] = array(
                'id' => '',
                'name' => $fileName,
                'path' => $modeleDir . DS . $fileName,
                'mime' => 'application/vnd.oasis.opendocument.text'
            );
            $relementsName = Hash::extract($relements, '{n}.Relement.name');
            if (in_array($fichiers[$i]['name'], $relementsName)) {
                unset($fichiers[$i]['name']);
            }
        }


        $fichiersSoustypes = array();
        $modeleDirSoustype = WEBDAV_DIR . DS . 'modeles' . DS . $flux['Courrier']['soustype_id'];
        $Folder = new Folder($modeleDirSoustype, false, 0777);
        foreach ($Folder->find('.+\.odt$') as $i => $fileName) {
            $fichiersSoustypes[$i] = array(
                'id' => '',
                'name' => $fileName,
                'path' => $modeleDirSoustype . DS . $fileName,
                'mime' => 'application/vnd.oasis.opendocument.text'
            );
            $relementsName = Hash::extract($relements, '{n}.Relement.name');
            if (in_array($fichiersSoustypes[$i]['name'], $relementsName)) {
                unset($fichiersSoustypes[$i]['name']);
            }
        }
        $fichiers = array_merge($fichiers, $fichiersSoustypes);

        $fichiersName = Hash::extract($fichiers, '{n}.name');
        $this->set('fichiersName', $fichiersName);
        $sessionId = $this->Session->id();
        $this->set('sessionId', $sessionId);

        $aro = array('model' => 'Desktop', 'foreign_key' => $this->Session->read('Auth.User.Desktop.id'));
        $this->set('right_upload', $this->Acl->check($aro, 'controllers/Relements/add') && !$this->_isFromFobiddenLocation($flux));

        $inCircuit = $this->Courrier->isInCircuit($fluxId);
        $this->set('right_delete', $this->Acl->check($aro, 'controllers/Relements/delete') && !$this->_isFromFobiddenLocation($flux) && !$inCircuit);
        $this->set('right_sendmail', $this->Acl->check($aro, 'controllers/Courriers/sendmail') && !$this->_isFromFobiddenLocation($flux));
        $this->set('right_sendged', $this->Acl->check($aro, 'controllers/Courriers/sendDocumentToGed') && !$this->_isFromFobiddenLocation($flux));
        $this->set('relements', $relements);
        $this->set('fichiers', $fichiers);
        $this->set('fluxId', $fluxId);
        $soustypeId = $flux['Courrier']['soustype_id'];
        $this->set('soustypeId', $soustypeId);
    }

    /**
     * Vérification de la présence du flux dans une bannette ne donnant pas lieu à la modification du flux (Mes services, En copie, Historique)
     *
     * @param type $flux
     * @return boolean
     */
    private function _isFromFobiddenLocation($flux) {
        $fromHistorique = false;
        if (strpos($_SERVER['HTTP_REFERER'], 'historiqueGlobal') !== false) {
            $fromHistorique = true;
        }
        return $fromHistorique;
    }

    /**
     * Récupération du document principal et des pièces jointes d'un flux
     *
     * @logical-group Flux
     * @logical-group Context
     * @user-profile User
     *
     * @access public
     * @param integer $fluxId identifiant du flux

     * @throws NotFoundException
     * @return void
     */
    public function getDocuments($fluxId) {
        $qdFlux = array(
            'recursive' => -1,
            'conditions' => array(
                'Courrier.id' => $fluxId
            ),
            'fields' => array(
                'Courrier.id'
            )
        );
        $flux = $this->Courrier->find('first', $qdFlux);

        if (empty($flux)) {
            throw new NotFoundException();
        }

        $documents = $this->Courrier->getDocs($flux['Courrier']['id']);
        $desktopCreatorId = array();

        foreach ($documents as $i => $document) {
            $desktopCreatorId[] = $document['Document']['desktop_creator_id'];

            $documents[$i]['Document']['isgenerated'] = false;
            $documentName = $document['Document']['name'];
            if (is_dir(WEBDAV_DIR . DS . $fluxId)) {
                $dirFileGenerated = scandir(WEBDAV_DIR . DS . $fluxId);
                if (in_array($documentName, $dirFileGenerated)) {
                    $documents[$i]['Document']['isgenerated'] = true;
                }
            }
        }
        $this->set('documents', $documents);

//document principal
        $this->set('mainDoc', $this->Courrier->getMainDoc($flux['Courrier']['id']));

// liste des mails envoyés par document
        $this->set('mailsSent', $this->Courrier->getMailsSent($flux['Courrier']['id']));


        $documentssignes = $this->Courrier->getDocsSignes($flux['Courrier']['id']);
        if( !empty($documentssignes) ) {
            $documentssignes['Document']['isgenerated'] = false;
        }
        $this->set('documentssignes', $documentssignes);
        $this->set('fluxId', $fluxId);
        $aro = array('model' => 'Desktop', 'foreign_key' => $this->Session->read('Auth.User.Desktop.id'));
        $this->set('right_upload', $this->Acl->check($aro, 'controllers/Documents/upload') && !$this->_isFromFobiddenLocation($flux));
        $inCircuit = $this->Courrier->isInCircuit($fluxId);
        $this->set('right_delete', $this->Acl->check($aro, 'controllers/Documents/delete') && !$this->_isFromFobiddenLocation($flux) && !$inCircuit);
        $this->set('right_sendmail', $this->Acl->check($aro, 'controllers/Courriers/sendmail') /* && !$this->_isFromFobiddenLocation($flux) */);
        $this->set('right_sendged', $this->Acl->check($aro, 'controllers/Courriers/sendDocumentToGed') && !$this->_isFromFobiddenLocation($flux));
        $this->set('right_setAsDefault', $this->Acl->check($aro, 'controllers/Documents/setMainDoc') && !$this->_isFromFobiddenLocation($flux));
        $this->set('fromDispEnv', $this->Session->read('Auth.User.Env.actual.group_id') == DISP_GID);
        $fromMesServices = false;
        $this->set('fromMesServices', $fromMesServices);
    }

    /**
     * Récupération des informations du flux parent dans le cas d'une réponse à un flux
     *
     * @logical-group Flux
     * @logical-group Context
     * @user-profile User
     *
     * @access public
     * @param integer $fluxId identifiant du flux

     * @throws NotFoundException
     * @return void
     */
    public function getParent($fluxId) {
        $conditions = array();
       
        $querydata = array(
            'conditions' => array(
                'Courrier.id' => $fluxId
            ),
            'contain' => array(
                'Organisme',
                'Contact',
                'Soustype' => array(
                    'Type'
                ),
                'Metadonnee',
                'Affaire' => array(
                    'Dossier'
                ),
                'Bancontenu' => array(
                    'conditions' => array(
                        'Bancontenu.bannette_id is null',
                        'Bancontenu.etat' => '-1'
                    ),
                    'order' => 'Bancontenu.modified DESC',
                    'limit' => 1
                )
            )
        );
        $flux = $this->Courrier->find('first', $querydata);
        
        if( empty($flux['Bancontenu']) ) {
            $querydata = array(
                'conditions' => array(
                    'Courrier.id' => $fluxId
                ),
                'contain' => array(
                    'Organisme',
                    'Contact',
                    'Soustype' => array(
                        'Type'
                    ),
                    'Metadonnee',
                    'Affaire' => array(
                        'Dossier'
                    ),
                    'Bancontenu' => array(
                        'conditions' => array(
                            'Bancontenu.etat' => '-1'
                        ),
                        'order' => 'Bancontenu.modified DESC',
                        'limit' => 1
                    )
                )
            );
            $flux = $this->Courrier->find('first', $querydata);
        }
        
        
//debug($flux);
        if (!empty($flux['Bancontenu'][0]['desktop_id'])) {
            $desktopId = $flux['Bancontenu'][0]['desktop_id'];
            $userId = $this->Courrier->Desktop->getUsers( $desktopId );
            $user = $this->Courrier->Desktop->User->find(
                'first',
                array(
                    'conditions' => array(
                        'User.id' => $userId
                    ),
                    'contain' => false,
                    'recursive' => -1
                )
            );
            if (!empty($user)) {
                $desktopName = $user['User']['prenom'] . ' ' . $user['User']['nom'];
            }
        } else {
            $desktopName = '';
        }

        if (!empty($flux['Bancontenu'][0]['desktop_id'])) {
            $desktopmanagerId = $this->Courrier->Desktop->getDesktopManager($flux['Bancontenu'][0]['desktop_id']);
            $desktopManagerName = $this->Courrier->Desktop->Desktopmanager->find(
                    'first', array(
                'conditions' => array(
                    'Desktopmanager.id' => $desktopmanagerId
                ),
                'recursive' => -1,
                'fields' => array('Desktopmanager.name')
                    )
            );
        } else {
            $desktopManagerName = '';
        }
        $this->set(compact('desktopManagerName'));
        
        if( isset($desktopManagerName) && !empty($desktopManagerName) ) {
            $desktopName = $desktopName. ' ( '.$desktopManagerName['Desktopmanager']['name'].' )';
        }
        else {
            $desktopName = $desktopName;
        }
        $this->set(compact('desktopName'));
        if (empty($flux)) {
            throw new NotFoundException();
        }

        $metadonnees = Hash::extract($flux, 'Metadonnee.{n}');
        $this->set(compact('metadonnees'));

// Ajout pour récupérer les documents liés au flux d'origine
        $this->set('documents', $this->Courrier->getDocs($flux['Courrier']['id']));
        $this->set('mainDoc', $this->Courrier->getMainDoc($flux['Courrier']['id']));
        $aro = array('model' => 'Desktop', 'foreign_key' => $this->Session->read('Auth.User.Desktop.id'));
        $this->set('right_setAsDefault', $this->Acl->check($aro, 'controllers/Documents/setMainDoc') && !$this->_isFromFobiddenLocation($flux));

        $this->set('flux', $flux);
    }

    /**
     *
     * @throws NotFoundException
     *
     * exmeple de crontab :
     * 		0 13 * * * /var/www/webgfc/lib/Cake/Console/cake --app /var/www/webgfc/app CreateFromFiles process
     *
     */
    public function acquisition() { //TODO: revoir le principe d acquisition (mettre le code du shell dans le modele)
        if (!$this->Session->read('Auth.User.id')) {
            throw new NotFoundException();
        }

        $this->loadModel('Collectivite');
        $this->Collectivite->useDbConfig = 'default';
        $scan_desktop_id = $this->Collectivite->field('scan_desktop_id', array('conn' => $this->Session->read('Auth.User.connName')));
        $desktops = $this->SessionTools->getDesktopList();

        if (!in_array($scan_desktop_id, $desktops)) {
            throw new NotFoundException();
        }
    }

    /**
     * Avant Ré-aiguillage d'un flux à un aiguilleur ou un initiateur, vérifier 
     * si ce flux est déjà inserer dans un circuit
     *

     */
    public function isInTraite() {
        $this->autoRender = false;
        $fluxIds = $this->request->data('InCircuit');
        $inCircuit = array();
        $fromMesServices = array();
        if (count($fluxIds) > 0) {
            foreach ($fluxIds as $i => $fluxId) {
                $inCircuit[] = $this->Courrier->isInCircuit($fluxId);
            }
            return in_array(true, $inCircuit);
        } else {
            return false;
        }
    }

    /**
     * Réaliser un list de fluxId en traitement
     *

     */
    public function fluxIdInTraite() {
        $this->autoRender = false;
        $listFluxId = array_values($this->Courrier->Traitement->find('list', array('fields' => array('Traitement.target_id'), 'contain' => false)));
        echo json_encode($listFluxId);
    }

    /**
     * Fonction permettant de retourner l'historique global  d'un flux
     * @user-profile User
     * 
     *
     * @access public
     * @return void
     */
    public function historiqueGlobal($fluxId = null) {

        $desktops = $this->getSessionAllDesktops();
        $historiqueGlobal = array();
        $namedModel = Hash::get($this->request->params, 'named.model');
//ajouter ariane
        $domain = strrchr($_SERVER['HTTP_REFERER'], '/');
        $courrier = $this->Courrier->find('first', array('conditions' => array('Courrier.id' => $fluxId), 'contain' => false));
        if ($domain == '/historique') {
            $arianeParent = __d('courrier', 'Bannette.archives');
        } else if ($domain == '/recherches') {
            $arianeParent = __d('menu', 'Recherche', true);
        } else {

            $arianeParent = __d('courrier', 'Bannette.archives');
        }
        $ariane = array(
            '<a href="/environnement/index/0">' . __d('menu', 'Courrier') . '</a>',
            '<a href="/environnement/historique">' . $arianeParent . '</a>',
            $courrier['Courrier']['name']
        );
        $parent = array();
        if (!empty($courrier['Courrier']['parent_id'])) {
            $qdParent = array(
                'fields' => array(
                    'Courrier.id',
                    'Courrier.name'
                ),
                'conditions' => array(
                    'Courrier.id' => $courrier['Courrier']['parent_id']
                ),
                'recursive' => -1
            );
            $parent = $this->Courrier->find('first', $qdParent);

            $ariane = array(
                '<a href="/environnement/index/0">' . __d('menu', 'Courrier') . '</a>',
                '<a href="/environnement/historique">' . $arianeParent . '</a>',
                '<a href="/courriers/historiqueGlobal/' . $parent['Courrier']['id'] . '">' . $parent['Courrier']['name'] . '</a>',
                $courrier['Courrier']['name']
            );
        }
        $this->set('ariane', $ariane);

// Données liées au courrier
        $querydata = array(
            'fields' => array_merge(
                    $this->Courrier->fields(),
                    $this->Courrier->Organisme->fields(), $this->Courrier->Contact->fields(),
                    $this->Courrier->Soustype->fields(), $this->Courrier->Service->fields(), $this->Courrier->Soustype->Type->fields(), $this->Courrier->Soustype->Circuit->fields(), array(
                'Courrier.name',
                'Courrier.objet',
                'Courrier.date',
                'Courrier.datereception',
                'Organisme.name',
                'Contact.name',
                'Type.name',
                'Soustype.name',
                'Circuit.nom',
                'Service.name',
                'Affairesuivie.name',
                'Origineflux.name'
                    )
            ),
            'contain' => false,
            'joins' => array(
                $this->Courrier->join($this->Courrier->Organisme->alias, array('type' => 'LEFT OUTER')),
                $this->Courrier->join($this->Courrier->Contact->alias, array('type' => 'LEFT OUTER')),
                $this->Courrier->join($this->Courrier->Soustype->alias, array('type' => 'LEFT OUTER')),
                $this->Courrier->join($this->Courrier->Service->alias, array('type' => 'LEFT OUTER')),
                $this->Courrier->Soustype->join($this->Courrier->Soustype->Type->alias, array('type' => 'LEFT OUTER')),
                $this->Courrier->Soustype->join($this->Courrier->Soustype->Circuit->alias, array('type' => 'LEFT OUTER')),
                $this->Courrier->join($this->Courrier->Affairesuivie->alias, array('type' => 'LEFT OUTER')),
                $this->Courrier->join($this->Courrier->Origineflux->alias, array('type' => 'LEFT OUTER'))
            ),
            'conditions' => array(
                'Courrier.id' => $fluxId
            )
        );

        if (Configure::read('Conf.SAERP')) {
            $typesdocument = array(
                'OS' => 'Ordre de service',
                'LN' => 'Lettre de notification',
                'LC' => 'Lettre de commandes',
                'PLI' => 'Pli'
            );
            $this->set(compact('typesdocument'));
            $querydata['joins'] = array_merge(
                    $querydata['joins'], array(
                $this->Courrier->join($this->Courrier->Marche->alias, array('type' => 'LEFT OUTER'))
                    )
            );
            $querydata['fields'] = array_merge(
                    $querydata['fields'], $this->Courrier->Marche->fields()
            );
        }
        $courrier = $this->Courrier->find('first', $querydata);

//debug($courrier);
// Données nécessaire pour récupérer les différents documents liés au flux
        $qdCourrier = array(
            'conditions' => array(
                'Document.courrier_id' => $fluxId
            ),
            'fields' => array(
                'Document.name'
            ),
            'contain' => false
        );
        $documents = $this->Courrier->Document->find('all', $qdCourrier);

        $rights = array(
            'getDocuments' => true,
            'getRelements' => true,
            'getArs' => true,
            'getCircuit' => true
        );

// Si le sous-type est sortant, on affiche les composants de réponse sinon les ARs
        $sortant = false;
        if (isset($courrier['Soustype']['entrant']) && $courrier['Soustype']['entrant'] == 0) {
            $sortant = true;
        }
        $this->set('sortant', $sortant);

        $qdParent = array(
            'fields' => array(
                'Courrier.id',
                'Courrier.name'
            ),
            'conditions' => array(
                'Courrier.id' => $courrier['Courrier']['parent_id']
            )
        );
        $parent = $this->Courrier->find('first', $qdParent);

//         $metas_values = $this->DataAuthorized->getAuthMetadonnees(array( 'fluxId' => $fluxId));
        $this->set('metas', $this->DataAuthorized->getAuthMetadonnees(array('fluxId' => $fluxId)));


//       debug($this->params);  
// En cas de refus 
        $fluxRefus = array();
        if (!empty($courrier['Courrier']['ref_ancien'])) {
            $qdFluxRefus = array(
                'fields' => array(
                    'Courrier.id',
                    'Courrier.name'
                ),
                'conditions' => array(
                    'Courrier.id' => $courrier['Courrier']['ref_ancien']
                )
            );
            $fluxRefus = $this->Courrier->find('first', $qdFluxRefus);
        }
        $this->set('fluxRefus', $fluxRefus);



// Récupération de toutes les infos échangés sur le flux entre les diférentes bannettes
        $bannettes = $this->Courrier->Bancontenu->find(
                'all', array(
            'conditions' => array(
                'Bancontenu.courrier_id' => $fluxId
            ),
            'contain' => array(
                'Desktop' => array(
                    'SecondaryUser',
                    'User',
                    'Group',
                    'Desktopmanager',
                ),
                'Bannette'
            ),
            'order' => array('Bancontenu.modified ASC')
                )
        );

//select date from wkf_visas where traitement_id in (select id from wkf_traitements where target_id=courrier_id) ;
        $traitement = $this->Courrier->Traitement->find(
                'first', array(
            'fields' => array(
                'Traitement.id'
            ),
            'conditions' => array(
                'Traitement.target_id' => $fluxId
            ),
            'contain' => false,
            'recursive' => -1
                )
        );
        $traitement_id = Hash::get($traitement, 'Traitement.id');

        $visas = $this->Courrier->Traitement->Visa->find(
                'all', array(
            'fields' => array_merge(
                    $this->Courrier->Traitement->Visa->fields(), $this->Courrier->Traitement->Visa->Desktopmanager->fields()
            ),
            'conditions' => array(
                'Visa.traitement_id' => $traitement_id,
                'Visa.action' => array('OK', 'IL')
            ),
            'contain' => array(
                'Desktopmanager' => array(
                    'Desktop'
                )
            ),
            'recursive' => -1,
            'order' => 'Visa.numero_traitement ASC'
                )
        );
        $this->set('visas', $visas);

        $validated = array();
        foreach ($visas as $v => $visa) {
            $validated[$visa['Visa']['trigger_id']] = $visa['Visa']['date'];
        }

        foreach ($validated as $id => $date) {
            $validationDesktopmanagerId[$id] = $this->Courrier->Desktop->Desktopmanager->getDesktops($id);
        }

        foreach ($bannettes as $b => $bannette) {
            if (!empty($validated[$bannette['Bancontenu']['desktop_id']])) {
                $bannettes[$b]['Bancontenu']['validated'] = $validated[$bannette['Bancontenu']['desktop_id']];
            } else if (!empty($validationDesktopmanagerId)) {
                foreach ($bannette['Desktop']['Desktopmanager'] as $dKey => $desktopmanager) {
                    if (isset($validated[$desktopmanager['id']])) {
                        $bannettes[$b]['Bancontenu']['validated'] = $validated[$desktopmanager['id']];
                    }
                }
            }
// Si le flux n'est pas lu, on n'affiche pas la date de modification, ni celle de validation
            if ($bannette['Bancontenu']['read'] == false) {
                $bannettes[$b]['Bancontenu']['validated'] = '';
                $bannettes[$b]['Bancontenu']['modified'] = '';
            }
        }

// Récupération des commentaires liés au flux
        $comments = $this->_getComments($fluxId);

//        $this->set('mainDoc', $this->Courrier->getMainDoc($fluxId));
        $this->set('mainDoc', $this->Courrier->getLightMainDoc($fluxId));
        $this->set('documents', $documents);
        $this->set('rights', $rights);
        $this->set('parent', $parent);
        $this->set('courrier', $courrier);
        $this->set('comments', $comments);
        $this->set('bannettes', $bannettes);
        $fromMesServices = false;
        $this->set('fromMesServices', $fromMesServices);

        $secondaryDesktops = $this->Session->read('Auth.User.SecondaryDesktops');
        $desktopName = Hash::extract($secondaryDesktops, '{n}.Group.name');
        $isAdmin = false;
        $groupName = $this->Session->read('Auth.User.Desktop.Group');
        if (in_array('Admin', $desktopName) || !empty($groupName) && $groupName['name'] == 'Admin') {
            $isAdmin = true;
        }

        $deletable = false;
        $hasRightToDelete = $this->userAclCheck(array('model' => 'User', 'foreign_key' => $this->Session->read('Auth.User.id')), 'controllers/Courriers/delete');
        if ($hasRightToDelete && $isAdmin) {
            $deletable = true;
        }
        $this->set('deletable', $deletable);

        $versable = false;
        $hasRightToSendToGed = $this->userAclCheck(array('model' => 'User', 'foreign_key' => $this->Session->read('Auth.User.id')), 'controllers/Courriers/sendToGed');
        if ($hasRightToSendToGed && $isAdmin) {
            $versable = true;
        }
        $this->set('versable', $versable);
    }

    /** Envoie pour un ged en protocole CMIS
     * 
     * @param type $courrier_id
     */
    public function sendToGed($courrier_id) {
        App::uses('Folder', 'Utility');
        App::uses('File', 'Utility');
        $this->autoRender = false;

        $this->Connecteur = ClassRegistry::init('Connecteur');
        $connecteurGed = $this->Connecteur->find(
                'first', array(
            'conditions' => array(
                'Connecteur.name ILIKE' => '%GED%'
            ),
            'contain' => false
                )
        );
        $folderTmp = new Folder(TMP . 'files' . DS . 'export' . DS . $courrier_id, true, 0777);

        try {
            $cmis = new CmisComponent;
            $cmis->CmisComponent_Service();

            $folderSend = new Folder($folderTmp->pwd() . DS . 'send', true, 0777);

            $cmisFolder = $this->{'_sendToGedVersion' . $connecteurGed['Connecteur']['ged_xml_version']}($cmis, $folderTmp, $folderSend, $courrier_id);

            $files = $folderSend->find('.*');
            foreach ($files as $file) {
                $file = new File($folderSend->pwd() . DS . $file);
                $contents = $file->read();
                $cmis->client->createDocument($cmisFolder->id, preg_replace("/[: ]/", "_", $file->name), array(), $file->read(), $file->mime());

                $file->close();
            }
            $folderTmp->delete();

            if ($this->params['params']['action'] == 'getFlowControls') {
                $desktopidactuel = $this->Session->read('Auth.User.Courrier.Desktop.id');
                $this->redirect(array('controler' => 'courriers', 'action' => 'getFlowControls', $courrier_id, $desktopidactuel));
            }
            $this->redirect(array('controller' => 'courriers', 'action' => 'historiqueGlobal', $courrier_id));
        } catch (Exception $e) {
            switch ($e->getCode()) {
                case '500':
                    $message = 'Erreur interne';
                    break;
                case '404':
                    $message = 'Ressource non trouvée';
                    break;
                case '409':
                    $message = 'Conflit, le courrier existe déjà dans la GED';
                    break;
                default:
                    $message = strip_tags($e->getMessage());
                    break;
            }

            $this->log('Export CMIS: Erreur ' . $e->getCode() . " ! \n" . $e->getMessage(), 'error');
            $this->Session->setFlash('CMIS: Erreur ' . $e->getCode() . ' ! ' . $message, 'growl', array('type' => 'erreur'));
        }

    }

    /** Envoi d'un document pour un ged en protocole CMIS
     * 
     * @param type $doc_id
     */
    public function sendDocumentToGed($doc_id) {
        App::uses('Folder', 'Utility');
        App::uses('File', 'Utility');

        $this->autoRender = false;
        $doc = $this->Courrier->Document->find(
                'first', array(
            'fields' => array(
                'Document.id',
                'Courrier.id'
            ),
            'conditions' => array(
                'Document.id' => $doc_id
            ),
            array(
                'Courrier'
            )
                )
        );

        $this->Connecteur = ClassRegistry::init('Connecteur');
        $connecteurGed = $this->Connecteur->find(
                'first', array(
            'conditions' => array(
                'Connecteur.name ILIKE' => '%GED%'
            ),
            'contain' => false
                )
        );
        $folderTmp = new Folder(TMP . 'files' . DS . 'export' . DS . $doc_id, true, 0777);

        try {
            $cmis = new CmisComponent;
            $cmis->CmisComponent_Service();

            $folderSend = new Folder($folderTmp->pwd() . DS . 'send', true, 0777);

            $cmisFolder = $this->_sendDocToGedVersion($cmis, $folderTmp, $folderSend, $doc_id);

            $files = $folderSend->find('.*');
            foreach ($files as $file) {
                $file = new File($folderSend->pwd() . DS . $file);
                $contents = $file->read();
                $cmis->client->createDocument($cmisFolder->id, $file->name, array(), $file->read(), $file->mime());

                $file->close();
            }


            $folderTmp->delete();
//debug($this->params['params']);die();

            $this->redirect(array('controller' => 'courriers', 'action' => 'view', $doc['Courrier']['id'], $this->Session->read('Auth.User.Desktop.id')));
        } catch (Exception $e) {
            switch ($e->getCode()) {
                case '500':
                    $message = 'Erreur interne';
                    break;
                case '404':
                    $message = 'Ressource non trouvée';
                    break;
                case '409':
                    $message = 'Conflit, le courrier existe déjà dans la GED';
                    break;
                default:
                    $message = strip_tags($e->getMessage());
                    break;
            }

            $this->log('Export CMIS: Erreur ' . $e->getCode() . " ! \n" . $e->getMessage(), 'error');
            $this->Session->setFlash('CMIS: Erreur ' . $e->getCode() . ' ! ' . $message, 'growl', array('type' => 'erreur'));
        }
    }

    /**
     * Création des fichiers pour l'export GED en version 2 et 3
     * @param type $cmis
     * @param type $folderTmp
     * @param type $folderSend
     * @param type $courrier_id
     * @param type $message_tdt
     * @return type
     * @throws Exception
     */
    function _sendToGedVersion2(&$cmis, &$folderTmp, &$folderSend, $courrier_id, $message_tdt = false) {

        try {
            $this->Conversion = new ConversionComponent();
// Création du répertoire de séance
            $result = $cmis->client->getFolderTree($cmis->folder->id, 1);

            $courrier = $this->Courrier->find(
                    'first', array(
                'conditions' => array('Courrier.id' => $courrier_id),
                'contain' => array(
                    'Document',
                    'Metadonnee' => array(
                        'Selectvaluemetadonnee'
                    ),
                    'Contact',
                    'Origineflux',
                    'Soustype' => array(
                        'Type'
                    )
                )
                    )
            );

// Récupération de toutes les infos échangés sur le flux entre les diférentes bannettes
            $bannettes = $this->Courrier->Bancontenu->find(
                    'all', array(
                'conditions' => array(
                    'Bancontenu.courrier_id' => $courrier_id
                ),
                'contain' => array(
                    'Desktop' => array(
                        'SecondaryUser',
                        'User',
                        'Group',
                        'Desktopmanager',
                    ),
                    'Bannette'
                ),
                'order' => array('Bancontenu.modified ASC')
                    )
            );

            $etat = $bannettes[0]['Bancontenu']['etat'];
// On récupère les valeurs des métadonnées
            foreach ($courrier['Metadonnee'] as $m => $flux) {
                $idSelect = Configure::read('Selectvaluemetadonnee.id');
                if ($flux['typemetadonnee_id'] == $idSelect) {
                    foreach ($flux['Selectvaluemetadonnee'] as $s => $selectedValue) {
                        if ($flux['CourrierMetadonnee']['valeur'] == $selectedValue['id']) {
                            $courrier['Metadonnee'][$m]['CourrierMetadonnee']['valeur'] = $selectedValue['name'];
                        }
                    }
                }
            }

            $date_courrier = $courrier['Courrier']['date'];
            $date_reception = $courrier['Courrier']['datereception'];
            $nom_courrier = $courrier['Courrier']['name'];
            $libelle_courrier = $courrier['Courrier']['reference'] . " " . date('Ymd_His'); //CakeTime::i18nFormat($courrier['Courrier']['date'], '%A %d %B %G à %k:%M');
//            $libelle_courrier = $courrier['Courrier']['reference'];

            $this->_deletetoGed($cmis, $libelle_courrier);

// Création des dossiers
            $my_courrier_folder = $cmis->client->createFolder($cmis->folder->id, $libelle_courrier);

            $courrier_id = $courrier['Courrier']['id'];

            $dom = new DOMDocument('1.0', 'utf-8');
            $dom->formatOutput = true;

            $idDepot = $courrier['Courrier']['numero_depot'] + 1;

// origine du dépôt
            $dom_depot = $this->_createElement($dom, 'depot', null, array(
                'versionDepot' => 2,
                'idDepot' => $idDepot,
                'dateDepot' => date("Y-m-d H:i:s"),
                'xmlns:webgfcdossier' => 'http://www.adullact.org/webgfc/infodossier/1.0',
                'xmlns:xm' => 'http://www.w3.org/2005/05/xmlmine'));

// Informations du courrier
            $dom_courrier = $this->_createElement($dom, 'courrier', null, array('idCourrier' => $courrier_id));
            $dom_courrier->appendChild($this->_createElement($dom, 'nomCourrier', $nom_courrier));
            $dom_courrier->appendChild($this->_createElement($dom, 'referenceCourrier', $courrier['Courrier']['reference']));
            $dom_courrier->appendChild($this->_createElement($dom, 'origineCourrier', $courrier['Origineflux']['name']));
            $dom_courrier->appendChild($this->_createElement($dom, 'objetCourrier', $courrier['Courrier']['objet']));
            $dom_courrier->appendChild($this->_createElement($dom, 'directionCourrier', $courrier['Courrier']['direction']));
            $dom_courrier->appendChild($this->_createElement($dom, 'prioriteCourrier', $courrier['Courrier']['priorite']));
            $dom_courrier->appendChild($this->_createElement($dom, 'etatCourrier', $etat));
            $dom_courrier->appendChild($this->_createElement($dom, 'typeCourrier', @$courrier['Soustype']['Type']['name']));
            $dom_courrier->appendChild($this->_createElement($dom, 'soustypeCourrier', @$courrier['Soustype']['name']));
            $dom_courrier->appendChild($this->_createElement($dom, 'dateCourrier', $date_courrier));
            $dom_courrier->appendChild($this->_createElement($dom, 'dateReception', $date_reception));

// Document (principal) attaché au courrier
            $aDocuments = array();
            $aDocuments = $this->Courrier->getDocumentsForDelegation($courrier_id);
            $courrier_filename = preg_replace("/[: ]/", "_", /* date('Ymd_His') . '_' . */ $aDocuments['docPrincipale']['Document']['name']);
            $document = $this->_createElement($dom, 'document', null, array('idDocument' => $aDocuments['docPrincipale']['Document']['id']));
            $document->appendChild($this->_createElement($dom, 'nom', $courrier_filename));
            $document->appendChild($this->_createElement($dom, 'relName', 'Document' . DS . $courrier_filename));
            $document->appendChild($this->_createElement($dom, 'type', 'Document'));
            $document->appendChild($this->_createElement($dom, 'mimetype', $aDocuments['docPrincipale']['Document']['mime']));
            $document->appendChild($this->_createElement($dom, 'encoding', 'utf-8'));
            $dom_courrier->appendChild($document);


// Fichiers supplémentaires
            $annexesDocuments = $this->_createElement($dom, 'annexes', null, array('nom' => 'Annexes', 'type' => 'document'));
            foreach ($aDocuments['annexes'] as $i => $annexe) {
                $annexe_filename = preg_replace("/[: ]/", "_", $annexe['filename']);
                $annexesDoc = $this->_createElement($dom, 'annexes', null, array('idDocument' => $i));
                $annexesDoc->appendChild($this->_createElement($dom, 'idAnnexe', $i));
                $annexesDoc->appendChild($this->_createElement($dom, 'nom', $annexe_filename));
                $annexesDoc->appendChild($this->_createElement($dom, 'relName', 'Annexe' . DS . $annexe_filename));
                $annexesDoc->appendChild($this->_createElement($dom, 'type', 'Annexe'));
                $annexesDoc->appendChild($this->_createElement($dom, 'signature', 'false'));
                $annexesDoc->appendChild($this->_createElement($dom, 'mimetype', $annexe['mimetype']));
                $annexesDoc->appendChild($this->_createElement($dom, 'encoding', 'utf-8'));
                $annexesDocuments->appendChild($annexesDoc);

                $isAR = strpos($annexe_filename, '[AR]');
                if ($isAR !== false && $annexe['mimetype'] != 'application/pdf') {
                    $annexe['content'] = $this->Conversion->convertirFlux($annexe['content'], 'odt', 'pdf');
                    $annexe['mimetype'] = 'application/pdf';
                    $annexe_filename = str_replace('odt', 'pdf', $annexe_filename);
                }
                $pathinfo = pathinfo($annexe_filename);

                if (!isset($pathinfo['extension'])) {
                    if ($annexe['mimetype'] == 'application/pdf') {
                        $annexe_filename = trim($annexe_filename) . '.pdf';
                    } else {
                        $annexe_filename = trim($annexe_filename) . '.' . $annexe['ext'];
                    }
                }
                $pjs = new File($folderSend->pwd() . DS . $annexe_filename);
                $pjs->write($annexe['content']);
                $pjs->close();
            }
            $dom_courrier->appendChild($annexesDocuments);

// Méta-données
            $metas = $this->_createElement($dom, 'metadonnees', null, array('nom' => 'Metadonnéées', 'type' => 'text'));
            foreach ($courrier['Metadonnee'] as $m => $meta) {
                $metaData = $this->_createElement($dom, 'metadonnees', null, array('idMeta' => $meta['id']));
                $metaData->appendChild($this->_createElement($dom, 'nom', $meta['name']));
                $metaData->appendChild($this->_createElement($dom, 'relName', 'Métadonnée' . DS . $meta['name']));
                $metaData->appendChild($this->_createElement($dom, 'type', 'Metadonnee'));
                $metaData->appendChild($this->_createElement($dom, 'value', $meta['CourrierMetadonnee']['valeur']));
                $metas->appendChild($metaData);
            }
            $dom_courrier->appendChild($metas);

// Mails adressés depuis le flux
            $mailssents = $this->Courrier->getMailsSent($courrier_id);
            $mails = $this->_createElement($dom, 'mails', null, array('nom' => 'Mails', 'type' => 'text'));
            foreach ($mailssents as $mail) {
                $mailData = $this->_createElement($dom, 'mails', null, array('idMail' => $mail['Sendmail']['id']));
                $mailData->appendChild($this->_createElement($dom, 'sender', $mail['Desktop']['name']));
                $mailData->appendChild($this->_createElement($dom, 'sendto', $mail['Sendmail']['email']));
                $mailData->appendChild($this->_createElement($dom, 'sujet', $mail['Sendmail']['sujet']));
                $mailData->appendChild($this->_createElement($dom, 'message', $mail['Sendmail']['message']));
                $mailData->appendChild($this->_createElement($dom, 'docconcerne', preg_replace("/[: ]/", "_", $mail['Document']['name'])));
                $mailData->appendChild($this->_createElement($dom, 'dateenvoi', strftime('%d/%m/%Y %T', strtotime($mail['Sendmail']['created']))));
                $mails->appendChild($mailData);
            }
            $dom_courrier->appendChild($mails);

// Commentaires associés au flux
            $comments = $this->_getComments($courrier_id);
            $commentsDom = $this->_createElement($dom, 'commentaires', null, array('nom' => 'Commentaires', 'type' => 'text'));
            if (!empty($comments)) {
                foreach ($comments['public'] as $key => $comment) {
                    $commentData = $this->_createElement($dom, 'commentaires', null, array('idComment' => $comment['Comment']['id']));
                    $commentData->appendChild($this->_createElement($dom, 'contenu', $comment['Comment']['content']));
                    $commentData->appendChild($this->_createElement($dom, 'owner', $comment['Owner']['name']));
                    $commentData->appendChild($this->_createElement($dom, 'dateenvoi', strftime('%d/%m/%Y %T', strtotime($comment['Comment']['created']))));
                    $commentsDom->appendChild($commentData);
                }
            }
            $dom_courrier->appendChild($commentsDom);

// Contact du flux
            $contactDom = array();
            $contact = $this->Courrier->Contact->find(
                    'first', array(
                'conditions' => array(
                    'Contact.id' => $courrier['Courrier']['contact_id']
                ),
                'contain' => false,
                'recursive' => -1
                    )
            );
            if (!empty($contact)) {
                $contactDom = $this->_createElement($dom, 'contact', null, array('idContact' => $contact['Contact']['id']));
                $contactDom->appendChild($this->_createElement($dom, 'name', $contact['Contact']['name']));
                $contactDom->appendChild($this->_createElement($dom, 'civilite', $contact['Contact']['civilite']));
                $contactDom->appendChild($this->_createElement($dom, 'nom', $contact['Contact']['nom']));
                $contactDom->appendChild($this->_createElement($dom, 'prenom', $contact['Contact']['prenom']));
                $contactDom->appendChild($this->_createElement($dom, 'email', $contact['Contact']['email']));
                $contactDom->appendChild($this->_createElement($dom, 'adresse', $contact['Contact']['adresse']));
                $contactDom->appendChild($this->_createElement($dom, 'tel', $contact['Contact']['tel']));
                $contactDom->appendChild($this->_createElement($dom, 'portable', $contact['Contact']['portable']));
                $contactDom->appendChild($this->_createElement($dom, 'role', $contact['Contact']['role']));
                $contactDom->appendChild($this->_createElement($dom, 'ville', $contact['Contact']['ville']));
                $contactDom->appendChild($this->_createElement($dom, 'numvoie', $contact['Contact']['numvoie']));
                $contactDom->appendChild($this->_createElement($dom, 'nomvoie', $contact['Contact']['nomvoie']));
                $contactDom->appendChild($this->_createElement($dom, 'compl', $contact['Contact']['compl']));
                $contactDom->appendChild($this->_createElement($dom, 'cp', $contact['Contact']['cp']));
                $contactDom->appendChild($this->_createElement($dom, 'pays', $contact['Contact']['pays']));
                $contactDom->appendChild($this->_createElement($dom, 'lignedirecte', $contact['Contact']['lignedirecte']));
                $contactDom->appendChild($this->_createElement($dom, 'observations', $contact['Contact']['observations']));
                $dom_courrier->appendChild($contactDom);


// Organisme du flux (lié au contact)
                $organismeDom = array();
                $organisme = $this->Courrier->Contact->Organisme->find(
                        'first', array(
                    'conditions' => array(
                        'Organisme.id' => $contact['Contact']['organisme_id']
                    ),
                    'contain' => false,
                    'recursive' => -1
                        )
                );
                if (!empty($organisme)) {
                    $organismeDom = $this->_createElement($dom, 'organisme', null, array('idOrganisme' => $organisme['Organisme']['id']));
                    $organismeDom->appendChild($this->_createElement($dom, 'name', $organisme['Organisme']['name']));
                    $organismeDom->appendChild($this->_createElement($dom, 'numvoie', $organisme['Organisme']['numvoie']));
                    $organismeDom->appendChild($this->_createElement($dom, 'nomvoie', $organisme['Organisme']['nomvoie']));
                    $organismeDom->appendChild($this->_createElement($dom, 'adressecomplete', $organisme['Organisme']['adressecomplete']));
                    $organismeDom->appendChild($this->_createElement($dom, 'compl', $organisme['Organisme']['compl']));
                    $organismeDom->appendChild($this->_createElement($dom, 'cp', $organisme['Organisme']['cp']));
                    $organismeDom->appendChild($this->_createElement($dom, 'ville', $organisme['Organisme']['ville']));
                    $organismeDom->appendChild($this->_createElement($dom, 'pays', $organisme['Organisme']['pays']));
                    $organismeDom->appendChild($this->_createElement($dom, 'email', $organisme['Organisme']['email']));
                    $organismeDom->appendChild($this->_createElement($dom, 'tel', $organisme['Organisme']['tel']));
                    $organismeDom->appendChild($this->_createElement($dom, 'portable', $organisme['Organisme']['portable']));
                    $organismeDom->appendChild($this->_createElement($dom, 'fax', $organisme['Organisme']['fax']));
                    $organismeDom->appendChild($this->_createElement($dom, 'antenne', $organisme['Organisme']['antenne']));
                    $dom_courrier->appendChild($organismeDom);
                }
            }

// Cycle de vie du flux
            $vie = $this->_createElement($dom, 'cyclevie', null, array('nom' => 'Cycle de vie', 'type' => 'text'));
            foreach ($bannettes as $b => $bannette) {
                $traitement = $this->Courrier->Traitement->find('first', array(
                    'fields' => array(
                        'Traitement.id',
                        'Traitement.circuit_id',
                        'Traitement.numero_traitement'
                    ),
                    'conditions' => array(
                        'Traitement.target_id' => $courrier_id
                    ),
                    'contain' => false,
                    'recursive' => -1
                ));
                $traitement_id = Hash::get($traitement, 'Traitement.id');
                $visas = $this->Courrier->Traitement->Visa->find(
                        'all', array(
                    'fields' => array_merge(
                            $this->Courrier->Traitement->Visa->fields(), $this->Courrier->Traitement->Visa->Desktopmanager->fields()
                    ),
                    'conditions' => array(
                        'Visa.traitement_id' => $traitement_id,
                        'Visa.action' => array('OK', 'IL')
                    ),
                    'contain' => array(
                        'Desktopmanager' => array(
                            'Desktop'
                        )
                    ),
                    'recursive' => -1,
                    'order' => 'Visa.numero_traitement ASC'
                        )
                );

                $validated = array();
                foreach ($visas as $v => $visa) {
                    $validated[$visa['Visa']['trigger_id']] = $visa['Visa']['date'];
                }

                foreach ($validated as $id => $date) {
                    $validationDesktopmanagerId[$id] = $this->Courrier->Desktop->Desktopmanager->getDesktops($id);
                }
//debug($validated);
                if (!empty($validated[$bannette['Bancontenu']['desktop_id']])) {
                    $bannette['Bancontenu']['validated'] = $validated[$bannette['Bancontenu']['desktop_id']];
                } else if (!empty($validationDesktopmanagerId)) {
                    foreach ($bannette['Desktop']['Desktopmanager'] as $dKey => $desktopmanager) {
                        if (isset($validated[$desktopmanager['id']])) {
                            $bannettes['Bancontenu']['validated'] = $validated[$desktopmanager['id']];
                        }
                    }
                }

// Si le flux n'est pas lu, on n'affiche pas la date de modification, ni celle de validation
                if ($bannette['Bancontenu']['read'] == false) {
                    $bannettes['Bancontenu']['validated'] = '';
                }
                $bannetteName = $bannette['Bannette']['name'];
// Utilisateur ayant réalisé l'action
                $user = @$bannette['Desktop']['User'][0]['nom'] . ' ' . @$bannette['Desktop']['User'][0]['prenom'];
                if ($user == ' ') {
                    $user = @$bannette['Desktop']['SecondaryUser'][0]['nom'] . ' ' . @$bannette['Desktop']['SecondaryUser'][0]['prenom'];
                }

                $vieDom = $this->_createElement($dom, 'cyclevie', null, array('idBannette' => $bannette['Bancontenu']['id']));
                $vieDom->appendChild($this->_createElement($dom, 'bureautraitant', $bannette['Desktop']['name']));
                $vieDom->appendChild($this->_createElement($dom, 'agenttraitant', $user));
                $vieDom->appendChild($this->_createElement($dom, 'datearrivee', strftime('%d/%m/%Y %T', strtotime($bannette['Bancontenu']['created']))));
                $vieDom->appendChild($this->_createElement($dom, 'datedernieremodif', strftime('%d/%m/%Y %T', strtotime($bannette['Bancontenu']['modified']))));
                $vieDom->appendChild($this->_createElement($dom, 'datevalidation', !empty($bannette['Bancontenu']['validated']) ? strftime('%d/%m/%Y %T', strtotime($bannette['Bancontenu']['validated'])) : ''));
                $vieDom->appendChild($this->_createElement($dom, 'pourcopie', ($bannetteName == 'copy' ) ? 'Oui' : 'Non' ));
                $vie->appendChild($vieDom);
            }
            $dom_courrier->appendChild($vie);

//Insertion du noeud xml courrier
            $dom_depot->appendChild($dom_courrier);

            $dom->appendChild($dom_depot);

            $file = new File($folderSend->pwd() . DS . 'XML_DESC_' . date('Ymd_His') . '.xml');
            $file->append($dom->saveXML());
            $file->close();

            $docprincipal = new File($folderSend->pwd() . DS . $courrier_filename);
            $docprincipal->write($aDocuments['docPrincipale']['Document']['content']);
            $docprincipal->close();

            $this->Courrier->id = $courrier_id;
            $this->Courrier->saveField('numero_depot', $idDepot);

            $this->Session->setFlash('Le dossier \"' . $libelle_courrier . '\" a été ajouté (Depot n°' . $idDepot . ')', 'growl', array('type' => 'success'));
        } catch (Exception $e) {
            $this->log($e);
            $this->log('Export CMIS: Erreur ' . $e->getCode() . "! \n File:" . $e->getFile() . ' Line:' . $e->getLine(), 'error');
            throw $e;
        }

        if( !empty($my_courrier_folder)) {
            $this->loadModel('Journalevent');
            $datasSession = $this->Session->read('Auth.User');
            $msg = "L'utilisateur ". $this->Session->read('Auth.User.username'). " a versé en GED le flux ".$courrier['Courrier']['reference']." (".$libelle_courrier."), le ".date('d/m/Y à H:i:s');
            $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $courrier);
        }
        $this->log( $my_courrier_folder );
        return !empty($my_courrier_folder) ? $my_courrier_folder : false;
    }

    /**
     * Création des fichiers pour l'export GED en version 3
     * @param type $cmis
     * @param type $folderTmp
     * @param type $folderSend
     * @param type $courrier_id
     * @return type
     */
    function _sendToGedVersion3(&$cmis, &$folderTmp, &$folderSend, $courrier_id) {

        return $this->_sendToGedVersion2($cmis, $folderTmp, $folderSend, $courrier_id, true);
    }

    /**
     * Création des fichiers pour l'export GED en version 3
     * @param type $cmis
     * @param type $folderTmp
     * @param type $folderSend
     * @param type $courrier_id
     * @return type
     */
    function _deletetoGed(&$cmis, $libelle_courrier) {

        $this->Connecteur = ClassRegistry::init('Connecteur');
        $connecteurGed = $this->Connecteur->find('first', array(
            'conditions' => array(
                'Connecteur.name ILIKE' => '%GED%'
            ),
            'contain' => false
        ));
        // Règle de gestion on écrase les documents existants
        try {
            //On recherche le dossier
            $objet_cmis = $cmis->client->getObjectByPath($connecteurGed['Connecteur']['ged_repo'] . '/' . $libelle_courrier);

            if (is_object($objet_cmis)) {
                //On recherche tous les enfants du dossier
                $children = $cmis->client->getChildren($objet_cmis->id);
                //On boucle sur les enfants
                foreach ($children->objectList as $child) {
                    //On supprimer l'enfant selectionné
                    $cmis->client->deleteObject($child->id);
                }
                //On peut maitenant supprimer le dossier
                $cmis->client->deleteObject($objet_cmis->id);
            }
        } catch (CmisObjectNotFoundException $e) {
            // L'objet n'existe pas encore : ne rien faire
        }
    }

    function _createElement($domObj, $tag_name, $value = NULL, $attributes = NULL) {
        try {
            $element = ($value != NULL ) ? $domObj->createElement($tag_name, AppTools::xml_entity_encode($value)) : $domObj->createElement($tag_name);

            if ($attributes != NULL) {
                foreach ($attributes as $attr => $val) {
                    $element->setAttribute($attr, $val);
                }
            }
        } catch (Exception $e) {
            $this->log('Export CMIS: Erreur _createElement (' . $tag_name . ') ' . $e->getCode() . "! \n" . $e->getMessage() . ' line:' . $e->getLine(), 'error');
            throw $e;
        }
        return $element;
    }

    /**
     * Envoi d'un document par mail
     */
    public function sendmail($documentId = null, $fluxId = null, $ar) {

        if ($ar == 'false') {
            $document = $this->Courrier->Document->find(
                    'first', array(
                'recursive' => -1,
                'conditions' => array(
                    'Document.id' => $documentId,
                    'Document.courrier_id' => $fluxId
                )
                    )
            );
        } else if ($ar == 'true') {
            $document = $this->Courrier->Ar->find(
                    'first', array(
                'recursive' => -1,
                'conditions' => array(
                    'Ar.id' => $documentId
                )
                    )
            );
        }
        if (!empty($document) && !empty($this->request->data)) {

            // DESTINATIRE = A
            // Liste déroulante utilisée uniquement
            $emails = $this->request->data['Sendmail']['email'];
            if (is_array($emails) || !empty($emails)) {
                $this->request->data['Sendmail']['email'] = implode('; ', $emails);
            }
            // Champ texte libre uniquement
            if (!empty($this->request->data['Sendmail']['email2']) && empty($emails)) {
                $this->request->data['Sendmail']['email'] = $this->request->data['Sendmail']['email2'];
            }
            // Liste déroulante utilisée + Champ texte libre
            if (!empty($this->request->data['Sendmail']['email2']) && !empty($emails)) {
                $this->request->data['Sendmail']['email'] = implode('; ', array($this->request->data['Sendmail']['email2'], $this->request->data['Sendmail']['email']));
            }

            // POUR COPIE = CC
            // Liste déroulante utilisée uniquement
            $ccmails = $this->request->data['Sendmail']['ccmail'];
            if (is_array($ccmails) || !empty($ccmails)) {
                $this->request->data['Sendmail']['ccmail'] = implode('; ', $ccmails);
            }
            // Champ texte libre uniquement
            if (!empty($this->request->data['Sendmail']['ccmail2']) && empty($ccmails)) {
                $this->request->data['Sendmail']['ccmail'] = $this->request->data['Sendmail']['ccmail2'];
            }
            // Liste déroulante utilisée + Champ texte libre
            if (!empty($this->request->data['Sendmail']['ccmail2']) && !empty($ccmails)) {
                $this->request->data['Sendmail']['ccmail'] = implode('; ', array($this->request->data['Sendmail']['ccmail2'], $this->request->data['Sendmail']['ccmail']));
            }

            $attachements = array();
            if (!empty($this->request->data['Document']['Document'])) {
                $attachements = $this->Courrier->Document->find(
                        'all', array(
                    'conditions' => array(
                        'Document.id' => $this->request->data['Document']['Document']
                    ),
                    'contain' => false
                        )
                );
            }

            $success = $this->Courrier->docParMail(
                    $this->request->data['Sendmail']['email'], $document, $this->request->data['Sendmail']['sujet'], $this->request->data['Sendmail']['message'], $this->request->data['Sendmail']['ccmail'], $attachements
            );

            if (!isset($document['Document']) && !empty($document['Ar'])) {
                $documentAr['Document']['content'] = $document['Ar']['content'];
                $documentAr['Document']['id'] = $documentId;
                $documentAr['Document']['courrier_id'] = $fluxId;
                $documentAr['Document']['name'] = $document['Ar']['name'];
                $documentAr['Document']['size'] = $document['Ar']['size'];
                $documentAr['Document']['mime'] = $document['Ar']['mime'];
                $documentAr['Document']['ext'] = $document['Ar']['ext'];
                // Passage en doc principal pour les modèles de réponse générés
                // car ils finiront par être adressés au parapheur
                $documentAr['Document']['main_doc'] = false;
                // Seul les créateurs de doc peuvent les supprimer
                $documentAr['Document']['desktop_creator_id'] = $this->Session->read('Auth.User.id');
                $this->Courrier->Document->create($documentAr);
                $success = $this->Courrier->Document->save() && $success;
            }

            if ($success) {
                $this->Courrier->Sendmail->create($this->request->data);
                $success = $this->Courrier->Sendmail->save() && $success;
            }

            $this->Jsonmsg->init();
            if ($success) {
                $this->Jsonmsg->valid("Le mail a bien été envoyé");
            }
            $this->Jsonmsg->send();
        }
        $desktopId = $this->Session->read('Auth.User.Courrier.Desktop.id');
        $this->set(compact('fluxId', 'desktopId', 'documentId'));

        $templatemails = $this->Courrier->Sendmail->Templatemail->find('all');
        $this->set(compact('templatemails'));

        $userMails = $this->Courrier->User->getUserMails();
        $contactMails = array();

        $allMails = array_merge($userMails, $contactMails);

// On récupère les mails des services actifs
        $serviceMails = $this->Courrier->Service->getServiceMails();
        $contactMails = $this->Courrier->Contact->getContactMails();
        $allMails = array_merge($allMails, $contactMails, $serviceMails);
        $this->set(compact('allMails'));

        // Liste des autres fichiers associés au flux
        $documentsLies = $this->Courrier->Document->find(
                'list', array(
            'conditions' => array(
                'Document.courrier_id' => $fluxId,
                'Document.id <>' => $documentId
            ),
            'contain' => false
                )
        );
        $this->set('documentsLies', $documentsLies);
    }

    /**
     * Envoi d'un flux à une étape hors circuit
     *
     * @logical-group Flux
     *
     * @logical-used-by CakeFlow > Envoi d'un flux (avec ou sans rebond) à une nouvelle étape
     * @user-profile User
     *
     * @access public
     * @param integer $fluxId identifiant du flux
     * @return void
     */
    public function sendwkfsignaturemanuelle($data) {
        if (!empty($data)) {
            $this->autoRender = false;
            //rebond
            $newDesktopId = $data['Send']['desktop_id'];
            $fluxId = $data['Send']['flux_id'];

            $newDesktop = $this->Courrier->Desktop->find('first', array('conditions' => array('Desktop.id' => $newDesktopId)));
            $desktopId = $this->Session->read('Auth.User.Courrier.Desktop.id');

            // initialisation des visas a ajouter au traitement
            $options = array(
                'insertion' => array(
                    '0' => array(
                        'Etape' => array(
                            'etape_nom' => 'En cours de signature',
                            'etape_type' => 1
                        ),
                        'Visa' => array(
                            '0' => array(
                                'trigger_id' => $newDesktopId,
                                'type_validation' => 'V'
                            )
                        )
                    )
                )
            );
            $action = $data['Send']['getback'] ? 'IL' : 'IP';

            $success = false;
            if ($this->Courrier->cakeflowExecuteSend($action, $desktopId, $fluxId, $options)) {
                $success = true;
            }

            if (!empty($success)) {
                $this->Session->setFlash(__d('default', 'save.ok'), 'growl');
            } else {
                $this->Session->setFlash(__d('default', 'save.error'), 'growl');
            }
        }
    }

    /**
     * Création des fichiers pour l'export GED en version 2 et 3
     * @param type $cmis
     * @param type $folderTmp
     * @param type $folderSend
     * @param type $courrier_id
     * @param type $message_tdt
     * @return type
     * @throws Exception
     */
    function _sendDocToGedVersion(&$cmis, &$folderTmp, &$folderSend, $doc_id, $message_tdt = false) {
//debug($cmis->folder);
//die();
        try {
            $this->Conversion = new ConversionComponent();
// Création du répertoire de séance
            $result = $cmis->client->getFolderTree($cmis->folder->id, 1);

            $qdDoc = array(
                'recursive' => -1,
                'fields' => array(
                    'Document.id',
                    'Document.courrier_id',
                    'Document.name',
                    'Document.ext',
                    'Document.content',
                    'Document.gedpath',
                    'Document.size',
                    'Document.mime',
                    'Document.main_doc',
                    'Document.desktop_creator_id'
                ),
                'conditions' => array(
                    'Document.id' => $doc_id
                ),
                'contain' => false
            );


            $doc = $this->Courrier->Document->find('first', $qdDoc);

            $courrier = $this->Courrier->find('first', array(
                'conditions' => array('Courrier.id' => $doc['Document']['courrier_id']),
                'contain' => array(
                    'Document',
                    'Soustype' => array(
                        'Type'
                    ),
                    'Contact' => array(
                        'Organisme'
                    ),
                    'Origineflux',
                    'Metadonnee' => array(
                        'Selectvaluemetadonnee'
                    )
                )
            ));

            $date_courrier = $courrier['Courrier']['date'];
            $date_reception = $courrier['Courrier']['datereception'];
            $nom_courrier = $courrier['Courrier']['name'];
            $libelle_courrier = $courrier['Courrier']['reference'] . " " . date('Ymd_His'); //CakeTime::i18nFormat($courrier['Courrier']['date'], '%A %d %B %G à %k:%M');

            $this->_deletetoGed($cmis, $libelle_courrier);

            // Création des dossiers
            $my_courrier_folder = $cmis->client->createFolder($cmis->folder->id, $libelle_courrier);
            $courrier_id = $courrier['Courrier']['id'];

            // Récupération de toutes les infos échangés sur le flux entre les diférentes bannettes
            $bannettes = $this->Courrier->Bancontenu->find(
                    'all', array(
                'conditions' => array(
                    'Bancontenu.courrier_id' => $courrier_id
                ),
                'contain' => array(
                    'Desktop' => array(
                        'SecondaryUser',
                        'User',
                        'Group',
                        'Desktopmanager',
                    ),
                    'Bannette'
                ),
                'order' => array('Bancontenu.modified ASC')
                    )
            );

            $etat = $bannettes[0]['Bancontenu']['etat'];

            $dom = new DOMDocument('1.0', 'utf-8');
            $dom->formatOutput = true;

            $idDepot = $courrier['Courrier']['numero_depot'] + 1;

// origine du dépôt
            $dom_depot = $this->_createElement($dom, 'depot', null, array(
                'versionDepot' => 2,
                'idDepot' => $idDepot,
                'dateDepot' => date("Y-m-d H:i:s"),
                'xmlns:webgfcdossier' => 'http://www.adullact.org/webgfc/infodossier/1.0',
                'xmlns:xm' => 'http://www.w3.org/2005/05/xmlmine'));

// Informations du courrier
            $dom_courrier = $this->_createElement($dom, 'courrier', null, array('idCourrier' => $courrier_id));
            $dom_courrier->appendChild($this->_createElement($dom, 'nomCourrier', $nom_courrier));
            $dom_courrier->appendChild($this->_createElement($dom, 'referenceCourrier', $courrier['Courrier']['reference']));
            $dom_courrier->appendChild($this->_createElement($dom, 'origineCourrier', $courrier['Origineflux']['name']));
            $dom_courrier->appendChild($this->_createElement($dom, 'objetCourrier', $courrier['Courrier']['objet']));
            $dom_courrier->appendChild($this->_createElement($dom, 'directionCourrier', $courrier['Courrier']['direction']));
            $dom_courrier->appendChild($this->_createElement($dom, 'prioriteCourrier', $courrier['Courrier']['priorite']));
            $dom_courrier->appendChild($this->_createElement($dom, 'etatCourrier', $etat));
            $dom_courrier->appendChild($this->_createElement($dom, 'typeCourrier', $courrier['Soustype']['Type']['name']));
            $dom_courrier->appendChild($this->_createElement($dom, 'soustypeCourrier', $courrier['Soustype']['name']));
            $dom_courrier->appendChild($this->_createElement($dom, 'dateCourrier', $date_courrier));
            $dom_courrier->appendChild($this->_createElement($dom, 'dateReception', $date_reception));

// Document (principal) attaché au courrier
            $aDocuments = array();
            $aDocuments = $this->Courrier->getDocumentsForDelegation($courrier_id);
            $courrier_filename = preg_replace("/[: ]/", "_", /* date('Ymd_His') . '_' . */ $aDocuments['docPrincipale']['Document']['name']);
            $document = $this->_createElement($dom, 'document', null, array('idDocument' => $aDocuments['docPrincipale']['Document']['id']));
            $document->appendChild($this->_createElement($dom, 'nom', $courrier_filename));
            $document->appendChild($this->_createElement($dom, 'relName', 'Document' . DS . $courrier_filename));
            $document->appendChild($this->_createElement($dom, 'type', 'Document'));
            $document->appendChild($this->_createElement($dom, 'mimetype', $aDocuments['docPrincipale']['Document']['mime']));
            $document->appendChild($this->_createElement($dom, 'encoding', 'utf-8'));
            $dom_courrier->appendChild($document);


//Insertion du noeud xml courrier
            $dom_depot->appendChild($dom_courrier);

//            $zip->close();
            $dom->appendChild($dom_depot);

            $file = new File($folderSend->pwd() . DS . 'XML_DESC_' . date('Ymd_His') . '.xml');
            $file->append($dom->saveXML());
            $file->close();

// On ne sauve que l fichier envoyé
            $isAR = strpos($doc['Document']['name'], '[AR]');
            if ($isAR !== false && $doc['Document']['mime'] != 'application/pdf') {
                $doc['Document']['content'] = $this->Conversion->convertirFlux($doc['Document']['content'], 'odt', 'pdf');
                $doc['Document']['mime'] = 'application/pdf';
                $doc['Document']['name'] = str_replace('odt', 'pdf', $doc['Document']['name']);
            }
            $doc['Document']['name'] = date('Ymd_His') . '_' . trim($doc['Document']['name']);
            $file = new File($folderSend->pwd() . DS . $doc['Document']['name']);
            $file->write($doc['Document']['content'], 'w');
            $file->close();

            $this->Courrier->id = $courrier_id;
            $this->Courrier->saveField('numero_depot', $idDepot);

            $this->Session->setFlash('Le dossier \"' . $libelle_courrier . '\" a été ajouté (Depot n°' . $idDepot . ')', 'growl', array('type' => 'success'));
        } catch (Exception $e) {
            $this->log('Export CMIS: Erreur ' . $e->getCode() . "! \n File:" . $e->getFile() . ' Line:' . $e->getLine(), 'error');
            throw $e;
        }

        return !empty($my_courrier_folder) ? $my_courrier_folder : false;
    }

    /**
     * Validation d'unicité du nom d'une collectivité (création / édition)
     *
     * @param type $field
     */
    public function ajaxformvalid($field = null, $collectiviteId = 0) {
        //On vérifie que le nom de bureau n'est pas un nom de groupe en lecture seule (Initiateur, Valideur, ...)
        
        $datereception_tmp = explode("/", $this->request->data['Courrier']['datereception']);
        $dateinsertion_tmp = explode("/", $this->request->data['Courrier']['date']);
        $datereception = !empty($datereception_tmp[1]) ? $datereception_tmp[2] . '/' . $datereception_tmp[1] . '/' . $datereception_tmp[0] : '';
        $dateinsertion = !empty($dateinsertion_tmp[1]) ? $dateinsertion_tmp[2] . '/' . $dateinsertion_tmp[1] . '/' . $dateinsertion_tmp[0] : '';
        if ($field == 'datereception') {
            if ($datereception > $dateinsertion) {
                $this->autoRender = false;
                $content = json_encode(array('Courrier' => array('datereception' => 'La date d\'entrée dans la collectivité ne peut etre postérieure à la date de création')));
                header('Pragma: no-cache');
                header('Cache-Control: no-store, no-cache, max-age=0, must-revalidate');
                header('Content-Type: text/x-json');
                header("X-JSON: {$content}");
                Configure::write('debug', 0);
                echo $content;
                return;
            }
        } else if ($field == 'date') {
            if ($dateinsertion < $datereception) {
                $this->autoRender = false;
                $content = json_encode(array('Courrier' => array('date' => 'La date de création ne peut être inférieure à la date d\'entrée dans la collectivité')));
                header('Pragma: no-cache');
                header('Cache-Control: no-store, no-cache, max-age=0, must-revalidate');
                header('Content-Type: text/x-json');
                header("X-JSON: {$content}");
                Configure::write('debug', 0);
                echo $content;
                return;
            }
        }

        $models = array();
        if ($field != null) {
            if ($field == 'datereception') {
                $models['Courrier'] = array('datereception');
            } else {
                $models['Courrier'] = array('date');
            }
        }

        $rd = array();
        foreach ($this->request->data as $k => $v) {

            if ($field == 'datereception' && $k == 'Courrier') {
                $rd[$k] = $v;
            }
        }

        $this->Ajaxformvalid->valid($models, $rd, $collectiviteId);
    }

    public function dispmultiplesend($fluxIds = array(), $cpyOnly = false) {

        $this->set('sendwkf', $this->userAclCheck(array('model' => 'User', 'foreign_key' => $this->Session->read('Auth.User.id')), 'controllers/Courriers/sendwkf'));
        $this->set('sendcpy', $this->userAclCheck(array('model' => 'User', 'foreign_key' => $this->Session->read('Auth.User.id')), 'controllers/Courriers/sendcpy'));


        if (!empty($this->request->data['Send'])) {

            $flux = array();
            $desktopsFromManagerIds = array();
            $desktopsCopyFromManagerIds = array();
// On récupère les ids sélectionnés pour aiguillage
            $desktopmanagerIds = Hash::get($this->request->data, 'Send.initDesktopService');
// On regarde le bureau sélectionné et on retourne les profils associés
            foreach ($desktopmanagerIds as $desktopmanagerId) {
                $desktopsFromManagerIds[$desktopmanagerId] = $this->Courrier->Desktop->Desktopmanager->getDesktops($desktopmanagerId);
            }

// On récupère les ids sélectionnés pour envoi pour copie
            $desktopCopyIds = Hash::get($this->request->data, 'Send.copy_id');
            $desktopCopyIds = ( empty($desktopCopyIds) ? array() : (array) $desktopCopyIds );
// On regarde le bureau sélectionné et on retourne les profils associés
            foreach ($desktopCopyIds as $desktopmanagercopyId) {
                $desktopsCopyFromManagerIds[$desktopmanagercopyId] = $this->Courrier->Desktop->Desktopmanager->getDesktops($desktopmanagercopyId);
            }

// pour chacun des flux sélectionnés
            foreach ($this->request->data['DispForm']['itemToLink'] as $key => $fluxId) {
                $flux[] = $fluxId;

// on regarde si le flux existe dans d'autres bannettes d'aiguilleur
                $banettesActuelles = $this->Courrier->Bancontenu->find(
                        'all', array(
                    'conditions' => array(
                        'Bancontenu.courrier_id' => $fluxId,
                        'Bancontenu.etat' => 1,
                        'Bancontenu.bannette_id' => 5
                    ),
                    'contain' => false
                        )
                );
                $oldBannettesDesktopsIds = Hash::extract($banettesActuelles, '{n}.Bancontenu.desktop_id');

// Enregistrement des commentaires pour les flux (copie ou aiguillage)
                $readersIds = Hash::extract($desktopsFromManagerIds, '{n}.{n}');
                $readersCopyIds = Hash::extract($desktopsCopyFromManagerIds, '{n}.{n}');
                $readers = array_merge(@$readersIds, @$readersCopyIds);

                if (!empty($this->request->data['Comment']['content'])) {
                    $this->request->data['Comment']['owner_id'] = $this->Session->read('Auth.User.Courrier.Desktop.id');
                    $this->request->data['Comment']['private'] = false;
                    $this->request->data['Comment']['target_id'] = $fluxId;
                    $this->request->data['Reader'] = array('Reader' => $readers);
                    $this->request->data['Send']['flux_id'] = $fluxId;
                    $this->Courrier->Comment->saveAll($this->request->data);
                }
            }
            $desktopAuthId = $this->Session->read('Auth.User.desktop_id');

// Pour chacun de ces profils, on regarde le groupe auquel il est lié
            foreach ($desktopsFromManagerIds as $key => $desktopsIds) {

                foreach ($desktopsIds as $desktopId) {

                    $groupsIds[] = $this->Courrier->Bancontenu->Desktop->field('Desktop.group_id', array('Desktop.id' => $desktopId));

                    $dispDesktops = array_keys($this->getSessionDispDesktops());
                    $senderDispId = $dispDesktops[0];

// Pour chacun de ces groupes, on vérifie s'il est INIT ou AIGUILLEUR
                    foreach ($groupsIds as $i => $groupId) {
                        $valid = array();
                        for ($i = 0; $i < count($flux); $i++) {
                            if ($groupId == INIT_GID) {
                                $courrier = $this->Courrier->find('first', array('conditions' => array('Courrier.id' => $flux[$i])));
                                $courrier['Courrier']['desktop_creator_id'] = $desktopAuthId;
                                $this->Courrier->create();
                                $this->Courrier->save($courrier);
                                $bannetteAdd = BAN_DOCS;
                            } else {
                                $bannetteAdd = BAN_AIGUILLAGE;
                            }
                        }
                        // AIGUILLAGE NORMAL
                        // On notifie chacun des profils sélectionnés
                        for ($i = 0; $i < count($flux); $i++) {
                            // Envoi des notifications pour chacun des bureaux en copie
                            $destId = array();
                            $valid[$flux[$i]] = array(
                                'end' => $this->Courrier->Bancontenu->end($senderDispId, BAN_AIGUILLAGE, $flux[$i]),
                                'add' => $this->Courrier->Bancontenu->add($desktopId, $bannetteAdd, $flux[$i])
                            );

                            // Dans le cas où le même flux est chez plusieurs utilisateurs, 
                            // on l'enlève des bannettes car il a été traité par l'un d'entre eux
                            if (!empty($oldBannettesDesktopsIds)) {
                                foreach ($oldBannettesDesktopsIds as $j => $otherDesktopId) {
                                    $valid[$flux[$i]] = array(
                                        'end' => $this->Courrier->Bancontenu->end($otherDesktopId, BAN_AIGUILLAGE, $flux[$i])
                                    );
                                }
                            }
                        }
//                    }
                    }
// Pour chaque flux, on notifie les bureaux et on envoie un mail aux abonnés
                    for ($i = 0; $i < count($flux); $i++) {

                        $fluxId = $flux[$i];
// Envoi des notifications
                        $notifInfos = $this->Courrier->Notifieddesktop->Notification->setNotification('ban_xnew');
                        $notifyDesktops = array(
                            $desktopId => array($fluxId)
                        );
                        $notified = $this->Courrier->Notifieddesktop->Notification->add($notifInfos['name'], $notifInfos['description'], $notifInfos['typeNotif'], $desktopAuthId, $notifyDesktops);

// Envoi des mails
                        $user_id = $this->Courrier->User->userIdByDesktop($desktopId);
                        $typeNotif = $this->Courrier->User->find(
                                'first', array(
                            'fields' => array('User.typeabonnement'),
                            'conditions' => array('User.id' => $user_id),
                            'contain' => false
                                )
                        );
                        $notificationId = $this->Courrier->Notifieddesktop->Notification->id;
                        if ($typeNotif['User']['typeabonnement'] == 'quotidien') {
                            $this->Courrier->User->saveNotif($fluxId, $user_id, $notificationId, 'aiguillage');
                        } else {
                            $this->Courrier->User->notifier($flux[$i], $user_id, $notificationId, 'aiguillage');
                        }
                    }
                }
            }


// AIGUILLAGE POUR COPIE
// Gestion des desktops auxquels sont envoyés les flux
            if (!empty($this->request->data['Send']['copy_id']) && isset($this->request->data['Send']['copy']) && $this->request->data['Send']['copy']) {
                foreach ($desktopsCopyFromManagerIds as $key => $desktopsCopy) {
                    foreach ($desktopsCopy as $c => $valueCopy) {
                        for ($i = 0; $i < count($flux); $i++) {
// Envoi des notifications pour chacun des bureaux en copie
                            $destId = array();
                            $notifInfos = $this->Courrier->Notifieddesktop->Notification->setNotification('ban_copy');
                            $desktopAuthId = $this->Session->read('Auth.User.desktop_id');
                            $fluxId = $flux[$i];

                            $notifyCopyDesktops = array(
                                $valueCopy => array($fluxId)
                            );

                            $notified = $this->Courrier->Notifieddesktop->Notification->add($notifInfos['name'], $notifInfos['description'], $notifInfos['typeNotif'], $desktopAuthId, $notifyCopyDesktops);

                            $valid[$flux[$i]] = array(
                                'add' => $this->Courrier->Bancontenu->add($valueCopy, BAN_COPY, $flux[$i])
                            );

                            $user_id = $this->Courrier->User->userIdByDesktop($valueCopy);
                            $typeNotif = $this->Courrier->User->find(
                                    'first', array(
                                'fields' => array('User.typeabonnement'),
                                'conditions' => array('User.id' => $user_id),
                                'contain' => false
                                    )
                            );
                            $notificationId = $this->Courrier->Notifieddesktop->Notification->id;
                            if ($typeNotif['User']['typeabonnement'] == 'quotidien') {
                                $this->Courrier->User->saveNotif($fluxId, $user_id, $notificationId, 'copy');
                            } else {
                                $this->Courrier->User->notifier($flux[$i], $user_id, $notificationId, 'copy');
                            }
                        }
                    }
                }
            }
        } else {
            
            $fluxChoix = $this->request->data['DispForm']['itemToLink'];
            foreach ($fluxChoix as $key => $fluxId) {
                $flux = $this->Courrier->find(
                        'first', array(
                    'fields' => array_merge(
                            $this->Courrier->fields(), $this->Courrier->Bancontenu->fields(), $this->Courrier->Desktop->fields()
                    ),
                    'conditions' => array(
                        'Courrier.id' => $fluxId
                    ),
                    'joins' => array(
                        $this->Courrier->join('Bancontenu'),
                        $this->Courrier->Bancontenu->join('Desktop')
                    ),
                    'contain' => false
                        )
                );

                $desktop_id = $this->Session->read('Auth.User.Desktop.id');
                $env = $this->Session->read('Auth.User.Env');
                if( $env['actual']['name'] == 'disp' ) {
                    $secondaryDesktops = $this->Session->read('Auth.User.SecondaryDesktops');
                    $groupId = Hash::extract($secondaryDesktops, '{n}.Group.id');
                    foreach( $secondaryDesktops as $i => $value) {
                        if( $value['Group']['id'] == 7 ) {
                            $desktop_id = $value['id'];
                        }
                    }
                }

                $isInCopy[] = $this->_inBannetteCopy($flux, $desktop_id);
            }
            if (in_array(false, $isInCopy)) {
                $cpyOnly = false;
            } else {
                $cpyOnly = true;
            }

            $this->set('cpyOnly', $cpyOnly);
            $this->set('fluxIds', $fluxIds);
            $this->set('itemList', $this->request->data);
        }
// Récupération de la liste des bureaux associés aux initiateurs et aiguilleurs uniquement
        $desktopsManagers = $this->Courrier->User->Desktop->Desktopmanager->getAllDesktopsByProfils(array(DISP_GID, INIT_GID));
//        $desktopsManagers = $this->Courrier->User->Desktop->Desktopmanager->getDesktopmanagerByService(array(DISP_GID, INIT_GID));
        $services = $desktopsManagers;
// Récupération de la liste de tous les bureaux
        $allDesktopsManagers = $this->Courrier->User->Desktop->Desktopmanager->getAllDesktopsByProfils();
//        $allDesktopsManagers = $this->Courrier->User->Desktop->Desktopmanager->getDesktopmanagerByService();
        $allDesktops = $allDesktopsManagers;

        $this->set('allDesktops', $allDesktops);
        $this->set('services', $services);
        $this->set('bannettes', $this->_bannettes);



//        debug($toto);
    }

    /**
     * Ré-aiguillage d'un flux à un aiguilleur ou un initiateur, depuis l'initiateur
     *
     * @logical-group Flux
     * @user-profile User
     * @user-profile Initiateur
     *
     * @access public
     * @return void
     */
    public function sendBackToDisp() {

// Liste des services concernés (aiguilleur + initiateur)
        $this->loadModel('Desktop');
        $this->Desktop->setDataSource(Configure::read('conn'));
        $this->set('userId', $this->Session->read('Auth.User.id'));

        $allDesktopsManagers = $this->Courrier->User->Desktop->Desktopmanager->getAllDesktopsByProfils(array(DISP_GID, INIT_GID));
//        $allDesktopsManagers = $this->Courrier->User->Desktop->Desktopmanager->getDesktopmanagerByService(array(DISP_GID, INIT_GID));
        $services = $allDesktopsManagers;
        $this->set('services', $services);


        if (!empty($this->request->data)) {

            if (!empty($this->request->data['checkItem'])) {
                $this->set('checkItem', $this->request->data);
            }

            if (!empty($this->request->data['Courrier'])) {
                $desktopManagerId = $this->request->data['Courrier']['dispInitDesktop'];
                $desktopsIds = $this->Courrier->Desktop->Desktopmanager->getDesktops($desktopManagerId);
                $flux = array();

                foreach ($this->request->data['checkItem'] as $key => $val) {
                    if ($val == true) {
                        $flux[] = $val;
                    }
                }

                foreach ($desktopsIds as $i => $desktopId) {

                    $groupId = $this->Courrier->Bancontenu->Desktop->field('Desktop.group_id', array('Desktop.id' => $desktopId));


                    $initDesktops = array_keys($this->getSessionInitDesktops());
                    $senderInitId = $initDesktops[0]; // FIXME
                    $notifyDesktops = array(
                        $desktopId => $flux
                    );

                    $bannetteType = $this->Courrier->Bancontenu->find('all', array(
                        'conditions' => array(
                            'Bancontenu.courrier_id' => $flux[$i],
                            'Bancontenu.desktop_id' => $senderInitId,
                            'Bancontenu.etat' => 1
                        ),
                        'contain' => false
                    ));
                    $typeBan = $bannetteType[0]['Bancontenu']['bannette_id'];

                    if ($groupId == DISP_GID) {
                        $valid = array();
                        for ($i = 0; $i < count($flux); $i++) {
                            $valid[$flux[$i]] = array(
                                'end' => $this->Courrier->Bancontenu->end($senderInitId, $typeBan, $flux[$i]),
                                'add' => $this->Courrier->Bancontenu->add($desktopId, BAN_AIGUILLAGE, $flux[$i])
                            );
                        }
                    } else if ($groupId == INIT_GID) {
                        $valid = array();
                        for ($i = 0; $i < count($flux); $i++) {
                            $courrier = $this->Courrier->find('first', array('conditions' => array('Courrier.id' => $flux[$i]), 'contain' => false));
                            $courrier['Courrier']['desktop_creator_id'] = $desktopId;
                            $this->Courrier->create();
                            $this->Courrier->save($courrier);
                            $valid[$flux[$i]] = array(
                                'end' => $this->Courrier->Bancontenu->end($senderInitId, $typeBan, $flux[$i]),
                                'add' => $this->Courrier->Bancontenu->add($desktopId, BAN_DOCS, $flux[$i])
                            );
                        }
                    }
//envoi des notifications
                    $notifInfos = $this->Courrier->Notifieddesktop->Notification->setNotification('ban_xnew');
                    $this->Courrier->Notifieddesktop->Notification->add($notifInfos['name'], $notifInfos['description'], $notifInfos['typeNotif'], $this->Session->read('Auth.User.Courrier.Desktop.id'), $notifyDesktops);

                    $user_id = $this->Courrier->User->userIdByDesktop($desktopId);
                    $typeMessage = '';
                    if ($groupId == DISP_GID) {
                        $typeMessage = 'aiguillage';
                    } else if ($groupId == INIT_GID) {
                        $typeMessage = 'insertion';
                    }

                    for ($j = 0; $j < count($flux); $j++) {
                        $typeNotif = $this->Courrier->User->find(
                                'first', array(
                            'fields' => array('User.typeabonnement'),
                            'conditions' => array('User.id' => $user_id),
                            'contain' => false
                                )
                        );
                        $notificationId = $this->Courrier->Notifieddesktop->Notification->id;
                        if ($typeNotif['User']['typeabonnement'] == 'quotidien') {
                            $this->Courrier->User->saveNotif($flux[$j], $user_id, $notificationId, $typeMessage);
                        } else {
                            $this->Courrier->User->notifier($flux[$j], $user_id, $notificationId, $typeMessage);
                        }
                    }
                }
                $this->Session->setFlash(__d('default', 'save.ok'), 'growl');
            }
        }
    }

    /**
     * Traitement des flux par lot, validation de flux en une seule fois
     *
     * @param type $field
     */
    public function traitementlot($cpyOnly = false) {

        $desktopsToSend = $this->Courrier->Desktop->Desktopmanager->find('list', array('conditions' => array('Desktopmanager.active' => true)));
        $this->set('desktopsToSend', $desktopsToSend);

        $isAuthVersGed = false;
        $isAuthVersGed = $this->userAclCheck(array('model' => 'User', 'foreign_key' => $this->Session->read('Auth.User.id')), 'controllers/Courriers/sendToGed');
        $this->set('isAuthVersGed', $isAuthVersGed);

        $endCircuitIsCollaborative = false;
        $this->set('endCircuitIsCollaborative', $endCircuitIsCollaborative);

        $this->set('endCircuitIsCollaborativeDerniereUtilisateur', false);

        $sendCpyCheck = $this->userAclCheck(array('model' => 'User', 'foreign_key' => $this->Session->read('Auth.User.id')), 'controllers/Courriers/sendcpy');
        $this->set('cpyOnly', $cpyOnly && $sendCpyCheck);

        $sendWkfCheck = $this->userAclCheck(array('model' => 'User', 'foreign_key' => $this->Session->read('Auth.User.id')), 'controllers/Courriers/sendwkf');

        $this->set('sendwkf', $sendWkfCheck);
        $this->set('sendcpy', $sendCpyCheck);

        $desktopUserId = $this->Session->read('Auth.User.Courrier.Desktop.id');
        if (!empty($this->request->data)) {

            if (!empty($this->request->data['checkItem'])) {

                foreach ($this->request->data['checkItem'] as $t => $fluxId) {
                    $flux = $this->Courrier->find(
                            'first', array(
                        'fields' => array(
                            'Courrier.id',
                            'Courrier.soustype_id',
                            'Courrier.name',
                            'Courrier.reference',
                            'Courrier.created',
                            'Courrier.motifrefus',
                            'Soustype.id',
                            'Soustype.circuit_id',
                            'Courrier.user_creator_id',
                            'Document.id'
                        ),
                        'conditions' => array('Courrier.id' => $fluxId),
                        'joins' => array(
                            $this->Courrier->join($this->Courrier->Soustype->alias),
                            $this->Courrier->join($this->Courrier->Document->alias)
//                                $this->Courrier->join('Document', array('type' => 'LEFT OUTER'))
                        ),
                        'contain' => false,
//                            'recursive' => -1
                            )
                    );


                    $hasSoustype = false;
                    if (!empty($flux['Soustype']['id'])) {
                        $hasSoustype = true;
                    }


                    $hasCircuit = false;
                    if (!empty($flux['Soustype']['circuit_id'])) {
                        $hasCircuit = true;
                    }

                    $hasEtapeParapheur = $this->Courrier->Traitement->Circuit->hasEtapeDelegation($flux['Soustype']['circuit_id']);
//                    $this->set( compact('hasEtapeParapheur' ) ); 

                    $isInCircuit = $this->Courrier->isInCircuit($fluxId);
//debug( $this->Courrier->Traitement->targetExists($fluxId) );
                    if (!empty($flux['Courrier']['motifrefus']) && !$this->Courrier->Traitement->targetExists($fluxId)) {
                        $isInCircuit = false;
                    }
//debug($isInCircuit);
//                    $this->set('isInCircuit', $isInCircuit);

                    $mainDoc = $this->Courrier->getLightMainDoc($fluxId);
                    $hasDoc = false;
                    if (!empty($mainDoc)) {
                        $hasDoc = true;
                    }
//debug($mainDoc);
                    $endCircuit = false;
                    if ($this->Courrier->cakeflowIsEnd($fluxId)) {
                        $endCircuit = true;
                    }


                    $reponse = false;
                    $stypeReponse = $this->Courrier->Soustype->find('first', array('conditions' => array('Soustype.parent_id' => $flux['Courrier']['soustype_id'])));
                    if (!empty($stypeReponse)) {
                        $reponse = true;
                    }
                    $desktopCurrentEtapeCircuit = false;
                    $desktopIdInWkf = $this->Courrier->Traitement->whoIs($fluxId, 'current');
                    $desktopmanagersIds = $this->Courrier->Desktop->getDesktopManager($desktopUserId);
                    if (!empty($desktopIdInWkf) && !empty($desktopmanagersIds)) {
                        foreach ($desktopIdInWkf as $t => $val) {
                            if (in_array($val, $desktopmanagersIds)) {
                                $desktopCurrentEtapeCircuit[$t] = true;
                            }
                        }
                        if (!empty($desktopCurrentEtapeCircuit)) {
                            $deskInCircuit = in_array(true, $desktopCurrentEtapeCircuit) || $desktopCurrentEtapeCircuit == true;
                            if ($deskInCircuit) {
                                $desktopCurrentEtapeCircuit = true;
                            }
                        }
                    }

                    $deletable = false;
                    $userCreatorId = $flux['Courrier']['user_creator_id'];
                    $userConnectedId = $this->Session->read('Auth.User.id');

                    if ($userCreatorId == $userConnectedId) {
                        $deletable = true;
                    }

                    // pour les flux en copie détachables
                    $detachable = false;
                    $querydata = array(
                        'conditions' => array(
                            'Bancontenu.bannette_id' => 7,
                            'Bancontenu.desktop_id' => $this->SessionTools->getDesktopList(),
                            'Bancontenu.courrier_id' => $fluxId,
                            'Bancontenu.etat' => 1
                        ),
                        'contain' => false
                    );
                    $courrierDetachable = $this->Courrier->Bancontenu->find('first', $querydata);
                    if (!empty($courrierDetachable)) {
                        $detachable = true;
                    }
                    if (isset($flux['Document']['id']) && $flux['Document']['id'] != null) {
                        $this->request->data['treatableItem']['hasDocument'][$fluxId] = true;
                    }

                    $this->request->data['treatableItem']['hasEtapeParapheur'][$fluxId] = $hasEtapeParapheur;
                    $this->request->data['treatableItem']['endCircuit'][$fluxId] = $endCircuit;
                    $this->request->data['treatableItem']['isInCircuit'][$fluxId] = $isInCircuit;
                    $this->request->data['treatableItem']['reponse'][$fluxId] = $reponse;
                    $this->request->data['treatableItem']['desktopCurrentEtapeCircuit'][$fluxId] = $desktopCurrentEtapeCircuit;

                    $this->request->data['treatableItem']['hasDoc'][$fluxId] = $hasDoc;
                    $this->request->data['treatableItem']['hasSoustype'][$fluxId] = $hasSoustype;
                    $this->request->data['treatableItem']['hasCircuit'][$fluxId] = $hasCircuit;

                    $this->request->data['treatableItem']['info'][$fluxId] = $flux;
                    $this->request->data['treatableItem']['delete'][$fluxId] = $deletable;

                    $this->request->data['treatableItem']['copy'][$fluxId] = $detachable;

                    $this->set('flux', $flux);
//                    $this->set('checkItem', $this->request->data);
                    $this->set('checkItem', $this->request->data);

                    $typeEtape[$fluxId] = $this->Courrier->Traitement->typeEtape($fluxId);
                    $this->request->data['treatableItem']['typeEtape'] = $typeEtape;
                }

                // 0 = false/false, 1 = true / false ou 2= true/true
                $hasEtapeParapheur = array_sum(($this->request->data['treatableItem']['hasEtapeParapheur']));
                $endCircuit = array_sum(($this->request->data['treatableItem']['endCircuit']));
                $isInCircuit = array_sum(($this->request->data['treatableItem']['isInCircuit']));
                $reponse = array_sum(($this->request->data['treatableItem']['reponse']));
                $desktopCurrentEtapeCircuit = array_sum(($this->request->data['treatableItem']['desktopCurrentEtapeCircuit']));
                $hasDoc = array_sum(($this->request->data['treatableItem']['hasDoc']));
                $hasSoustype = array_sum(($this->request->data['treatableItem']['hasSoustype']));
                $hasCircuit = array_sum(($this->request->data['treatableItem']['hasCircuit']));
                $nbSelected = count($this->request->data['checkItem']);

                $isDeletable = array_sum($this->request->data['treatableItem']['delete']);

                $isDetachable = array_sum($this->request->data['treatableItem']['copy']);

                $isCloturable = in_array(ETAPESIMPLE, $this->request->data['treatableItem']['typeEtape']);

//debug($isDeletable);
                $this->set(compact('isCloturable', 'hasEtapeParapheur', 'endCircuit', 'isInCircuit', 'reponse', 'desktopCurrentEtapeCircuit', 'hasDoc', 'nbSelected', 'hasSoustype', 'hasCircuit', 'isDeletable', 'isDetachable'));
            }
        }
    }

    /**
     * Actions devant être déclenchées
     * @param type $typeTraitement
     */
    public function execTraitementlot($typeTraitement, $fluxIds = array()) {
        $this->autoRender = false;
        $desktop_id = $this->Session->read('Auth.User.Courrier.Desktop.id');

        if (!empty($this->request->data['checkItem'])) {
            $fluxIds = $this->request->data['checkItem'];

            if ($typeTraitement == 'insert') {
                foreach ($fluxIds as $f => $fluxId) {
                    $ret[$f] = $this->Courrier->cakeflowInsert($fluxId, $this->Session->read('Auth.User.Courrier.Desktop.id'));
                    if ($ret[$f] === true) {
                        
                        $flux = $this->Courrier->find(
                            'first',
                            array(
                                'conditions' => array(
                                    'Courrier.id' => $fluxId
                                ),
                                'contain' => false, 
                                'recursive' => -1
                            )
                        );
                        $this->loadModel('Journalevent');
                        $datasSession = $this->Session->read('Auth.User');
                        $msg = "L'utilisateur ". $this->Session->read('Auth.User.username'). " a inséré le flux ".$flux['Courrier']['reference']." dans un circuit, le ".date('d/m/Y à H:i:s');
                        $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $flux);
                        
                        $this->Session->setFlash(__d('courrier', 'Courrier.insertlot.ok'), 'growl', array('type' => 'default'));
                    } else {
                        $this->Session->setFlash(__d('courrier', 'Courrier.insertlot.error') . ' : ' . json_decode($ret[$f]), 'growl', array('type' => 'erreur'));
                    }
                }
            } else if ($typeTraitement == 'valid') {
                foreach ($fluxIds as $f => $fluxId) {
                    
                    $secondaryDesktops = $this->Session->read('Auth.User.SecondaryDesktops');
                    $groupId = Hash::extract($secondaryDesktops, '{n}.Group.id');
                    $desktopId = Hash::extract($secondaryDesktops, '{n}.id');
                    $groupName = $this->Session->read('Auth.User.Desktop.Group');
                    // Si le bureau secondaire est de type Valideur Editeur, Valideur ou Documentaliste
                    if ( in_array( $groupId, array( 4, 5, 6 )  ) ) {
                        $desktop_id = $desktopId;
                    }
                    
                    
                    $ret[$f] = $this->Courrier->cakeflowExecuteNext($desktop_id, $fluxId, 0, null, 0);
                    if ($ret[$f] === true) {
                        $flux = $this->Courrier->find(
                            'first',
                            array(
                                'conditions' => array(
                                    'Courrier.id' => $fluxId
                                ),
                                'contain' => false, 
                                'recursive' => -1
                            )
                        );
                        $this->loadModel('Journalevent');
                        $datasSession = $this->Session->read('Auth.User');
                        $msg = "L'utilisateur ". $this->Session->read('Auth.User.username'). " a validé le flux ".$flux['Courrier']['reference']." dans un circuit, le ".date('d/m/Y à H:i:s');
                        $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $flux);
                        
                        $this->Session->setFlash(__d('courrier', 'Courrier.treatedlot.ok'), 'growl', array('type' => 'default'));
                    } else {
                        $this->Session->setFlash(__d('courrier', 'Courrier.treatedlot.error') . ' : ' . json_decode($ret[$f]), 'growl', array('type' => 'erreur'));
                    }
                }
            }
        }
    }

    /**
     * 
     * @param type $typeTraitement
     * @param type $fluxIds
     */
    public function refusparlot($typeTraitement = null, $fluxIds = array()) {
//debug($this->request->data);
//die();
        if (!empty($this->request->data['checkItem'])) {
            $fluxIds = $this->request->data['checkItem'];


            $flux = $this->Courrier->find(
                    'all', array(
                'fields' => array(
                    'Courrier.id',
                    'Courrier.reference',
                    'Courrier.name',
                    'Courrier.motifrefus',
                    'Courrier.created',
                    'Courrier.user_creator_id'
                ),
                'conditions' => array(
                    'Courrier.id' => $fluxIds
                ),
                'contain' => false
                    )
            );
//        debug($flux);
            $this->set('flux', $flux);
            $this->render('refusparlot');
        }

        if (!empty($typeTraitement)) {

            foreach ($this->request->data as $n => $notif) {
                $flux = $this->Courrier->find(
                        'all', array(
                    'fields' => array(
                        'Courrier.id',
                        'Courrier.reference',
                        'Courrier.name',
                        'Courrier.motifrefus',
                        'Courrier.created',
                        'Courrier.user_creator_id'
                    ),
                    'conditions' => array(
                        'Courrier.id' => $notif['Notification']['courrier_id']
                    ),
                    'contain' => false
                        )
                );
//                    debug($flux);
//                    die();
                foreach ($flux as $f => $courrier) {
                    $ret[$f] = $this->refus($courrier['Courrier']['id'], $notif['Notification']['message']);

                    $this->loadModel('Journalevent');
                    $datasSession = $this->Session->read('Auth.User');
                    $msg = "L'utilisateur ". $this->Session->read('Auth.User.username'). " a validé le flux ".$courrier['Courrier']['reference']." dans un circuit, le ".date('d/m/Y à H:i:s');
                    $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $courrier);

                }

                if (in_array(true, $ret)) {
                    $this->Session->setFlash(__d('courrier', 'Courrier.refuslot.ok'), 'growl', array('type' => 'default'));
                } else {
                    $this->Session->setFlash(__d('courrier', 'Courrier.refuslot.error') . ' : ' . json_decode($ret), 'growl', array('type' => 'erreur'));
                }

                $this->set('flux', $flux);
            }
        }
    }

    /**
     * 
     * @param type $typeTraitement
     * @param type $fluxIds
     */
    public function sendcopylot($typeTraitement = null, $fluxIds = array()) {
//        $allDesktopsManagers = $this->Courrier->User->Desktop->Desktopmanager->getDesktopmanagerByService();
        $allDesktopsManagers = $this->Courrier->User->Desktop->Desktopmanager->getAllDesktopsByProfils();
        $allDesktops = $allDesktopsManagers;
        $this->set('allDesktops', $allDesktops);
        if (!empty($this->request->data['checkItem'])) {

            $fluxIds = $this->request->data['checkItem'];


            $flux = $this->Courrier->find(
                    'all', array(
                'fields' => array(
                    'Courrier.id',
                    'Courrier.reference',
                    'Courrier.name',
                    'Courrier.motifrefus',
                    'Courrier.created',
                    'Courrier.user_creator_id'
                ),
                'conditions' => array(
                    'Courrier.id' => $fluxIds
                ),
                'contain' => false
                    )
            );
//        debug($flux);
            $this->set('flux', $flux);
            $this->set('fluxIds', $fluxIds);
            $this->render('sendcopylot');
        }

        if (!empty($typeTraitement)) {
            $desktopId = $this->Session->read('Auth.User.Courrier.Desktop.id');
            $flux = $this->Courrier->find(
                    'all', array(
                'fields' => array(
                    'Courrier.id',
                    'Courrier.reference',
                    'Courrier.name',
                    'Courrier.motifrefus',
                    'Courrier.created',
                    'Courrier.user_creator_id'
                ),
                'conditions' => array(
                    'Courrier.id' => $this->request->data['Send']['courrier_id']
                ),
                'contain' => false
                    )
            );

            foreach ($flux as $f => $courrier) {
                $this->Courrier->copy($desktopId, $courrier['Courrier']['id'], $this->request->data['Send']['copy_id']);
            }
            $this->set('flux', $flux);
//            }
        }
    }

    /**
     * Fonction permettant à l'utilisateur de détacher un flux d'une bannette
     * La bannette doit posséder le flux dans un état différent de traité (=0) et appartenir au bureau de l'utilisateur connecté
     * @param type $fluxId
     */
    public function detache($fluxId, $desktopId) {
        $this->autoRender = false;
        $this->Courrier->id = $fluxId;

        if (!$this->Courrier->exists()) {
            throw new NotFoundException();
        }
        $success = false;

        if (!empty($fluxId)) {
            $this->Courrier->Bancontenu->recursive = -1;
            $success = $this->Courrier->Bancontenu->updateAll(
                    array(
                'Bancontenu.etat' => 3
                    ), array(
                'Bancontenu.courrier_id' => $fluxId,
                'Bancontenu.etat <>' => 0,
                'Bancontenu.desktop_id' => $desktopId,
                'Bancontenu.bannette_id' => BAN_COPY
                    )
            );
        }

//        if (!in_array(false, $success, true)) {
        if ($success) {
            $flux = $this->Courrier->find(
                'first',
                array(
                    'conditions' => array(
                        'Courrier.id' => $fluxId
                    ),
                    'contain' => false, 
                    'recursive' => -1
                )
            );
            $this->loadModel('Journalevent');
            $datasSession = $this->Session->read('Auth.User');
            $msg = "L'utilisateur ". $this->Session->read('Auth.User.username')." a détaché le flux ".$flux['Courrier']['reference']." de sa bannette des flux en copie, le ".date('d/m/Y à H:i:s');
            $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $flux);
                
            $this->Courrier->Bancontenu->commit();
            $this->Session->setFlash(__d('courrier', 'Courrier detached', true), 'growl');
        } else {
            $this->Courrier->Bancontenu->rollback();
            $this->Session->setFlash(__d('courrier', 'Courrier was not detached', true), 'growl');
        }
        $this->redirect($_SERVER['HTTP_REFERER']);
    }

    /**
     * Fonction permettant l'ajout d'un contact (organisme et/ou contact)
     * @param type $fluxId
     */
    public function add_organisme() {

        if (!empty($this->request->data)) {
//debug($this->request->data);
            $this->Jsonmsg->init();
            $this->Courrier->Organisme->begin();
            if (!empty($this->request->data['Organisme']['banadresse'])) {
                $adressecomplete = Hash::get($this->request->data, 'Organisme.numvoie') . ' ' . Hash::get($this->request->data, 'Organisme.banadresse');
            } else {
                $adressecomplete = Hash::get($this->request->data, 'Organisme.numvoie') . ' ' . Hash::get($this->request->data, 'Organisme.nomvoie');
            }
            $this->request->data['Organisme']['adressecomplete'] = $adressecomplete;
            $this->Courrier->Organisme->create($this->request->data);
            $success = $this->Courrier->Organisme->save();

            if ($success) {
                if ($success && $this->request->data['Organisme']['infoscontact'] == 1) {
                    $this->request->data['Contact']['addressbook_id'] = $this->request->data['Organisme']['addressbook_id'];
                    $this->request->data['Contact']['organisme_id'] = $this->Courrier->Organisme->id;
                    $this->request->data['Contact']['adresse'] = $adressecomplete;
                } else {
                    $this->request->data['Contact']['addressbook_id'] = $this->request->data['Organisme']['addressbook_id'];
                    $this->request->data['Contact']['organisme_id'] = $this->Courrier->Organisme->id;
                    $this->request->data['Contact']['adresse'] = $adressecomplete;
                    $this->request->data['Contact']['name'] = ' Sans contact';
                    $this->request->data['Contact']['nom'] = '0Sans contact';
                }
                $this->Courrier->Organisme->Contact->create($this->request->data['Contact']);
                $success = $this->Courrier->Organisme->Contact->save() && $success;
            }
//debug($this->request->data);
            if ($success) {
                // on stocke qui fait quoi quand
//                $this->log( "L'utilisateur ". $this->Session->read('Auth.User.username'). " a créé l'organisme ".$this->request->data['Organisme']['name']." le ".date('d/m/Y à H:i:s'), LOG_WARNING );
                
                $this->loadModel('Journalevent');
                $datasSession = $this->Session->read('Auth.User');
                $msg = "L'utilisateur ". $this->Session->read('Auth.User.username'). " a créé l'organisme ".$this->request->data['Organisme']['name']." le ".date('d/m/Y à H:i:s');
                $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $this->request->data);
                
                $this->autoRender = false;
                $this->Courrier->Organisme->commit();
                if (empty($this->request->data['Contact']['name'])) {
                    $return = json_encode(
                            array(
                                'id' => $this->Courrier->Organisme->id,
                                'name' => $this->request->data['Organisme']['name'],
                                'contacts' => array()
                            )
                    );
                } else {
                    $return = json_encode(
                            array(
                                'id' => $this->Courrier->Organisme->id,
                                'name' => $this->request->data['Organisme']['name'],
                                'contacts' => array(
                                    'id' => $this->Courrier->Contact->id,
                                    'name' => $this->request->data['Contact']['name'],
                                )
                            )
                    );
                }

                echo $return;
            } else {
                $this->Courrier->Organisme->rollback();
            }
        }
        $this->_setOptions();
    }

    /**
     * Fonction permettant l'édition d'un contact (organisme et/ou contact)
     * @param type $fluxId
     */
    public function edit_organisme($orgId) {
        
        if (!empty($this->request->data)) {
            $this->Courrier->Organisme->begin();
            if (!empty($this->request->data['Organisme']['banadresse'])) {
                $adressecomplete = Hash::get($this->request->data, 'Organisme.numvoie') . ' ' . Hash::get($this->request->data, 'Organisme.banadresse');
            } else {
                $adressecomplete = Hash::get($this->request->data, 'Organisme.numvoie') . ' ' . Hash::get($this->request->data, 'Organisme.nomvoie');
            }
            $this->request->data['Organisme']['adressecomplete'] = $adressecomplete;
            $this->Courrier->Organisme->create($this->request->data);
            $success = $this->Courrier->Organisme->save();
            if ($success) {
                // on stocke qui fait quoi quand
//                $this->log( "L'utilisateur ". $this->Session->read('Auth.User.username'). " a modifié l'organisme ".$this->request->data['Organisme']['name']." (".$this->request->data['Organisme']['id'].") le ".date('d/m/Y à H:i:s'), LOG_WARNING );
                $this->loadModel('Journalevent');
                $datasSession = $this->Session->read('Auth.User');
                $msg = "L'utilisateur ". $this->Session->read('Auth.User.username'). " a modifié l'organisme ".$this->request->data['Organisme']['name']." (".$this->request->data['Organisme']['id'].") le ".date('d/m/Y à H:i:s');
                $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $this->request->data);
                
                
                $this->autoRender = false;
                $return = json_encode(
                        array(
                            'id' => $this->Courrier->Organisme->id,
                            'name' => $this->request->data['Organisme']['name'],
                            'contacts' => array()
                        )
                );
                echo $return;
                $this->Courrier->Organisme->commit();
            } else {
                $this->Courrier->Organisme->rollback();
            }
        } else {
            if (Configure::read('Conf.SAERP')) {
                $contain = array(
                    'Operation',
                    'Activite'
                );
            } else {
                $contain = array(
                    'Activite'
                );
            }
            $this->request->data = $this->Courrier->Organisme->find(
                    'first', array(
                'conditions' => array(
                    'Organisme.id' => $orgId,
                    'Organisme.active' => true
                ),
                'contain' => $contain,
                'recursive' => -1
                    )
            );
        }

        $this->_setOptions();
    }

    /**
     * Fonction permettant l'ajout d'un contact (organisme et/ou contact)
     * @param type $fluxId
     */
    public function add_contact($orgId) {
        if (!empty($this->request->data)) {
            $this->Courrier->Contact->begin();
            if (!empty($this->request->data['Contact']['organisme_id'])) {
                $organismeSelected = $this->Courrier->Organisme->find('first', array(
                    'fields' => array('Organisme.name', 'Organisme.addressbook_id'),
                    'conditions' => array('Organisme.id' => $this->request->data['Contact']['organisme_id'], 'Organisme.active' => true),
                    'contain' => false,
                    'recursive' => -1
                ));
                $organismeSelectedAddressbookId = $organismeSelected['Organisme']['addressbook_id'];
            }
            $this->request->data['Contact']['addressbook_id'] = $organismeSelectedAddressbookId;
            if (!empty($this->request->data['Contact']['banadresse'])) {
                $adressecomplete = Hash::get($this->request->data, 'Contact.numvoie') . ' ' . Hash::get($this->request->data, 'Contact.banadresse');
            } else {
                $adressecomplete = Hash::get($this->request->data, 'Contact.numvoie') . ' ' . Hash::get($this->request->data, 'Contact.nomvoie');
            }

            $this->request->data['Contact']['adresse'] = $adressecomplete;
            $this->Courrier->Contact->create($this->request->data);
            $success = $this->Courrier->Contact->save();
            if ($success) {
                // on stocke qui fait quoi quand
//                $this->log( "L'utilisateur ". $this->Session->read('Auth.User.username'). " a créé le contact ".$this->request->data['Contact']['name']." le ".date('d/m/Y à H:i:s'), LOG_WARNING );
                
                $this->loadModel('Journalevent');
                $datasSession = $this->Session->read('Auth.User');
                $msg = "L'utilisateur ". $this->Session->read('Auth.User.username'). " a créé le contact ".$this->request->data['Contact']['name']." le ".date('d/m/Y à H:i:s');
                $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $this->request->data);
                
                $this->autoRender = false;
                $return = json_encode(
                        array(
                            'contacts' => array(
                                'id' => $this->Courrier->Contact->id,
                                'name' => $this->request->data['Contact']['name'],
                            )
                        )
                );
                echo $return;
                $this->Courrier->Contact->commit();
            } else {
                $this->Courrier->Contact->rollback();
            }
        }
        $this->set('orgId', $orgId);
        $organisme = $this->Courrier->Contact->Organisme->find(
                'first', array(
            'conditions' => array(
                'Organisme.id' => $orgId,
                'Organisme.active' => true
            ),
            'contain' => false
                )
        );
        $this->set(compact('organisme'));
        $this->_setOptions();
    }

    /**
     * Fonction permettant l'édition d'un contact (organisme et/ou contact)
     * @param type $fluxId
     */
    public function edit_contact($contactId) {
        if (!empty($this->request->data)) {
            $this->Courrier->Contact->begin();
            if (!empty($this->request->data['Contact']['organisme_id'])) {
                $organismeSelected = $this->Courrier->Organisme->find('first', array(
                    'fields' => array('Organisme.name', 'Organisme.addressbook_id'),
                    'conditions' => array('Organisme.id' => $this->request->data['Contact']['organisme_id'], 'Organisme.active' => true),
                    'contain' => false,
                    'recursive' => -1
                ));
                $organismeSelectedAddressbookId = $organismeSelected['Organisme']['addressbook_id'];
            }
            $this->request->data['Contact']['addressbook_id'] = $organismeSelectedAddressbookId;
            if (!empty($this->request->data['Contact']['banadresse'])) {
                $adressecomplete = Hash::get($this->request->data, 'Contact.numvoie') . ' ' . Hash::get($this->request->data, 'Contact.banadresse');
            } else {
                $adressecomplete = Hash::get($this->request->data, 'Contact.numvoie') . ' ' . Hash::get($this->request->data, 'Contact.nomvoie');
            }

            $this->request->data['Contact']['adresse'] = $adressecomplete;
            $this->Courrier->Contact->create($this->request->data['Contact']);
            $success = $this->Courrier->Contact->save();
            if ($success) {

                // on stocke qui fait quoi quand
//                $this->log( "L'utilisateur ". $this->Session->read('Auth.User.username'). " a modifié le contact ".$this->request->data['Contact']['name']." (".$this->request->data['Contact']['id'].") le ".date('d/m/Y à H:i:s'), LOG_WARNING );
                
                $this->loadModel('Journalevent');
                $datasSession = $this->Session->read('Auth.User');
                $msg = "L'utilisateur ". $this->Session->read('Auth.User.username'). " a modifié le contact ".$this->request->data['Contact']['name']." (".$this->request->data['Contact']['id'].") le ".date('d/m/Y à H:i:s');
                $this->Journalevent->saveDatas( $datasSession, $this->action, $msg, 'info', $this->request->data);
                
                $this->autoRender = false;
                $return = json_encode(
                        array(
                            'contacts' => array(
                                'id' => $contactId,
                                'name' => $this->request->data['Contact']['name'],
                                'organisme_id' => $this->request->data['Contact']['organisme_id']
                            )
                        )
                );
                echo $return;

                $this->Courrier->Contact->commit();
            } else {
                $this->Courrier->Contact->rollback();
            }
        } else {
            $this->request->data = $this->Courrier->Contact->find(
                    'first', array(
                'fields' => array_merge(
                        $this->Courrier->Contact->fields(), $this->Courrier->Contact->Organisme->fields()
                ),
                'conditions' => array(
                    'Contact.id' => $contactId,
                    'Contact.active' => true
                ),
                'contain' => array(
                    'Organisme',
                    'Operation',
                    'Event'
                ),
                'recursive' => -1
                    )
            );
        }
        $this->_setOptions();
    }

    /**
     * Suppression des flux par lot
     * @param $fluxIds
     */
    public function deletelot($fluxIds = array()) {
        $this->autoRender = false;
        $desktop_id = $this->Session->read('Auth.User.Courrier.Desktop.id');

        if (!empty($this->request->data['checkItem'])) {
            $fluxIds = $this->request->data['checkItem'];

            $deleteAll = array();
            $bancontenus = array_keys($this->Courrier->Bancontenu->find('list', array('conditions' => array('Bancontenu.courrier_id' => $fluxIds))));
            $this->Courrier->begin();

            $comments = $this->_getComments($fluxIds);

            if (!empty($comments)) {
                foreach ($comments as $types) {
                    foreach ($types as $c => $comment) {
                        $commentId = $comment['Comment']['id'];
                        $deleteAll[] = $this->Courrier->Comment->delete($commentId);
                    }
                }
            }

            for ($i = 0; $i < count($bancontenus); $i++) {
                $deleteAll[] = $this->Courrier->Bancontenu->delete($bancontenus[$i]);
            }
            $deleteAll[] = $this->Courrier->delete($fluxIds);

            if (!in_array(false, $deleteAll, true)) {
                $this->Courrier->commit();
                $this->Session->setFlash(__d('courrier', 'Courrier deleted', true), 'growl');
            } else {
                $this->Courrier->rollback();
                $this->Session->setFlash(__d('courrier', 'Courrier was not deleted', true), 'growl');
            }
        }
    }

    /**
     * Fonction utilisée uniquement par la SAERP
     * @param type $field
     * @return type
     * 
     */
    public function ajaxformtype($field = null) {
        if ($field == 'marcheid') {
            $marcheOperation = array();
            $this->autoRender = false;
            if (!empty($this->request->data['Courrier']['marche_id'])) {
                $marche = $this->Courrier->Marche->find(
                        'first', array(
                    'fields' => array_merge(
                            $this->Courrier->Marche->fields(), $this->Courrier->Marche->Operation->fields(), $this->Courrier->Marche->Operation->Type->fields()
                    ),
                    'conditions' => array(
                        'Marche.id' => $this->request->data['Courrier']['marche_id']
                    ),
                    'joins' => array(
                        $this->Courrier->Marche->join('Operation'),
                        $this->Courrier->Marche->Operation->join('Type')
                    ),
                    'contain' => false
                        )
                );
                $marcheOperation = $marche['Type']['id'];
            }
        }

        return $marcheOperation;
    }

    /**
     * Fonction permettant à l'utilisateur de détacher par lots des flux de sa bannette  des flux en copie
     * La bannette doit posséder le flux dans un état différent de 3 et appartenir au bureau de l'utilisateur connecté
     * @param type $fluxId
     */
    public function detachelot($typeTraitement = null, $fluxIds = array()) {
//        $desktopId = $this->Session->read('Auth.User.Courrier.Desktop.id');

        $this->autoRender = false;
        $profil = $this->Session->read('Auth.User.Env.actual.name');

        if ($profil == 'disp') {
            $unlinkCourriers = $this->request->data['DispForm']['itemToLink'];
            $desktopId = $this->request->data['DispForm']['checkDesktop'];
//            $desktopId = $this->Session->read('Auth.User.Desktop.id' );
        } else {
            $unlinkCourriers = $this->request->data['checkItem'];
            $desktopId = $this->request->data['checkDesktop'];
        }
        
        if (!empty($unlinkCourriers)) {
            foreach ($unlinkCourriers as $fluxId) {

                $success = array();
                $this->Courrier->Bancontenu->recursive = -1;
                $success[] = $this->Courrier->Bancontenu->updateAll(
                    array(
                        'Bancontenu.etat' => 3
                    ),
                    array(
                        'Bancontenu.courrier_id' => $fluxId,
                        'Bancontenu.etat <>' => 0,
                        'Bancontenu.desktop_id' => $desktopId,
                        'Bancontenu.bannette_id' => 7
                    )
                );
            }

            if (!in_array(false, $success, true)) {
                $this->Courrier->Bancontenu->commit();
                $this->Session->setFlash(__d('courrier', 'Courriers detached', true), 'growl');
            } else {
                $this->Courrier->Bancontenu->rollback();
                $this->Session->setFlash(__d('courrier', 'Courriers were not detached', true), 'growl');
            }
        }
    }

    /**
     * Indique si le flux est en copie
     */
    public function isInCopy() {
        $this->autoRender = false;
//debug($this->request->data);
        if( !empty($this->request->data['InCopy']) || !empty($this->request->data['fluxChoix']) ) {
            if( !empty($this->request->data['fluxChoix'])) {
                $fluxChoix = $this->request->data['fluxChoix'];
            }
            else {
                $fluxChoix = $this->request->data['InCopy'];
            }
            foreach ($fluxChoix as $key => $fluxId) {
                $flux = $this->Courrier->find(
                        'first', array(
                    'fields' => array_merge(
                            $this->Courrier->fields(), $this->Courrier->Bancontenu->fields(), $this->Courrier->Desktop->fields()
                    ),
                    'conditions' => array(
                        'Courrier.id' => $fluxId
                    ),
                    'joins' => array(
                        $this->Courrier->join('Bancontenu'),
                        $this->Courrier->Bancontenu->join('Desktop')
                    ),
                    'contain' => false
                        )
                );

                $desktop_id = $this->Session->read('Auth.User.Desktop.id');
                $env = $this->Session->read('Auth.User.Env');
                if( $env['actual']['name'] == 'disp' ) {
                    $secondaryDesktops = $this->Session->read('Auth.User.SecondaryDesktops');
                    $groupId = Hash::extract($secondaryDesktops, '{n}.Group.id');
                    foreach( $secondaryDesktops as $i => $value) {
                        if( $value['Group']['id'] == 7 ) {
                            $desktop_id = $value['id'];
                        }
                    }
                }

                $isInCopy[] = $this->_inBannetteCopy($flux, $desktop_id);
            }
            if (in_array(false, $isInCopy)) {
                $res = false;
            } else {
                $res = true;
            }
        }
        else {
            $fluxChoix = array();
            $res = false;
        }
        return json_encode(array('incopy' => $res));
    }

    
    function getFluxPreview($reference) {
        $this->autoRender = false;
        $courrier = $this->Courrier->find('first', array(
            'conditions' => array(
                'Courrier.reference' => $reference
            ),
            'contain' => array(
                'Document' => array(
                    'conditions' => array(
                        'Document.main_doc' => true
                    )
                )
            )
        ));
        $documentId = null;
        if (!empty($courrier['Document'])) {
            $documentId = $courrier['Document'][0]['id'];
        }
        return json_encode(array('documentId' => $documentId));
    }

    function __getType($array) {
        return $array['Type'];
    }

    function __getSousType($array) {
        return $array['Soustype'];
    }

    function __getOrganisme($array) {
        return $array['Organisme'];
    }

    function __getContact($array) {
        return $array['Contact'];
    }

    function updateContext($fluxId, $desktopId) {
        $this->Courrier->recursive = -1;
        $qdCourrier = array(
            'fields' => array_merge(
                    $this->Courrier->fields(), $this->Courrier->Soustype->fields()
            ),
            'conditions' => array(
                'Courrier.id' => $fluxId
            ),
            'joins' => array(
                $this->Courrier->join('Soustype')
            ),
            'recursive' => -1
        );
        $courrier = $this->Courrier->find('first', $qdCourrier);

        $parent = array();
        if (!empty($courrier['Courrier']['parent_id'])) {
            $qdParent = array(
                'fields' => array(
                    'Courrier.id',
                    'Courrier.name'
                ),
                'conditions' => array(
                    'Courrier.id' => $courrier['Courrier']['parent_id']
                ),
                'recursive' => -1
            );
            $parent = $this->Courrier->find('first', $qdParent);
        }

        $sortant = false;
        if (isset($courrier['Soustype']['entrant']) && $courrier['Soustype']['entrant'] == 0) {
            $sortant = true;
        }

        $userDesktops = $this->getSessionAllDesktops();
        if (in_array($desktopId, array_keys($userDesktops))) {
            $this->Session->write('Auth.User.Courrier.Desktop.id', $desktopId);
            $aro = array('model' => 'Desktop', 'foreign_key' => $desktopId);
        } else {
            $aro = array('model' => 'Desktop', 'foreign_key' => $this->Session->read('Auth.User.Desktop.id'));
        } 
        $rights = array(
            'getInfos' => $this->Acl->check($aro, 'controllers/Courriers/getInfos'),
            'getMeta' => $this->Acl->check($aro, 'controllers/Courriers/getMeta'),
            'getTache' => $this->Acl->check($aro, 'controllers/Courriers/getTache'),
            'getAffaire' => $this->Acl->check($aro, 'controllers/Courriers/getAffaire'),
            'getFlowControls' => $this->Acl->check($aro, 'controllers/Courriers/getFlowControls'),
            'setInfos' => $this->Acl->check($aro, 'controllers/Courriers/setInfos'),
            'setMeta' => $this->Acl->check($aro, 'controllers/Courriers/setMeta'),
            'setTache' => $this->Acl->check($aro, 'controllers/Courriers/setTache'),
            'setAffaire' => $this->Acl->check($aro, 'controllers/Courriers/setAffaire'),
            'getArs' => $this->Acl->check($aro, 'controllers/Courriers/getArs'),
            'getRelements' => $this->Acl->check($aro, 'controllers/Courriers/getRelements'),
            'getDocuments' => $this->Acl->check($aro, 'controllers/Courriers/getDocuments'),
            'getCircuit' => $this->Acl->check($aro, 'controllers/Courriers/getCircuit'),
            'edit' => true
        );
        if (!$rights['setInfos'] && !$rights['setMeta'] && !$rights['setTache'] && !$rights['setAffaire']) {
            $rights['edit'] = false;
        }

        $this->set('mainDoc', $this->Courrier->getLightMainDoc($fluxId));
        $this->set('fluxId', $fluxId);
        $this->set('sortant', $sortant);
        $this->set('parent', $parent);
        $this->set('rights', $rights);
    }

}

?>